<?php

/**
 * @file
 * Contains \Drupal\geotimezone\RegionTimezone.
 */

namespace Drupal\geotimezone;

/**
 * Holds the list of time zone based on region code and region name.
 *
 * @package Drupal\geotimezone
 */
final class RegionTimezone implements TimezoneInterface {
  /**
   * List of time zone based on region name.
   *
   * @var array $listIdentifier
   */
  private static $listName;

  /**
   * List of time zone based on region code.
   *
   * @var array $listCode
   */
  private static $listCode;

  /**
   * Queried time zone identifier.
   *
   * @var string $identifier
   */
  private $identifier;

  /**
   * Queried time zone offset.
   *
   * @var string $offset
   */
  private $offset;

  /**
   * RegionTimezone constructor.
   *
   * @param array $location
   *   Location details in associative array with expected array keys of:
   *   regionCode
   *   region
   *   countryCode
   *   Required keys to have values are: countryCode and either of regionCode or
   *   region.
   */
  public function __construct($location) {
    if (isset($location['countryCode']) && !empty($location['countryCode'])) {
      if (isset($location['regionCode']) && !empty($location['regionCode'])) {
        static::$listCode = $this->loadRegionCodeList();
        $this->identifier = static::$listCode[$location['countryCode']][$location['regionCode']];
      }
      elseif (isset($location['region']) && !empty($location['region'])) {
        static::$listName = $this->loadRegionNameList();
        $this->identifier = static::$listName[$location['countryCode']][$location['region']];
      }
      if (!empty($this->identifier)) {
        // Convert to time zone offset
        $time = new \DateTime('now', new \DateTimeZone($this->identifier));
        $this->offset = $time->format('P');
      }
    }
    else {
      $this->identifier = '';
      $this->offset     = '';
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getIdentifier() {
    return $this->identifier;
  }

  /**
   * {@inheritdoc}
   */
  public function getOffset() {
    return $this->offset;
  }

  /**
   * Loads the list of time zone based on region name.
   *
   * @return array
   *   List of time zone based on region name.
   */
  private function loadRegionNameList() {
    return [
      'AD' => [
        'Canillo' => 'Europe/Andorra',
        'Encamp' => 'Europe/Andorra',
        'La Massana' => 'Europe/Andorra',
        'Ordino' => 'Europe/Andorra',
        'Sant Julia de Loria' => 'Europe/Andorra',
        'Andorra la Vella' => 'Europe/Andorra',
        'Escaldes-Engordany' => 'Europe/Andorra',
      ],
      'AE' => [
        'Abu Dhabi' => 'Asia/Dubai',
        'Ajman' => 'Asia/Dubai',
        'Dubai' => 'Asia/Dubai',
        'Fujairah' => 'Asia/Dubai',
        'Ras Al Khaimah' => 'Asia/Dubai',
        'Sharjah' => 'Asia/Dubai',
        'Umm Al Quwain' => 'Asia/Dubai',
      ],
      'AF' => [
        'Badakhshan' => 'Asia/Kabul',
        'Badghis' => 'Asia/Kabul',
        'Baghlan' => 'Asia/Kabul',
        'Bamian' => 'Asia/Kabul',
        'Farah' => 'Asia/Kabul',
        'Faryab' => 'Asia/Kabul',
        'Ghazni' => 'Asia/Kabul',
        'Ghowr' => 'Asia/Kabul',
        'Helmand' => 'Asia/Kabul',
        'Herat' => 'Asia/Kabul',
        'Kabol' => 'Asia/Kabul',
        'Kapisa' => 'Asia/Kabul',
        'Lowgar' => 'Asia/Kabul',
        'Nangarhar' => 'Asia/Kabul',
        'Nimruz' => 'Asia/Kabul',
        'Kandahar' => 'Asia/Kabul',
        'Kondoz' => 'Asia/Kabul',
        'Takhar' => 'Asia/Kabul',
        'Vardak' => 'Asia/Kabul',
        'Zabol' => 'Asia/Kabul',
        'Paktika' => 'Asia/Kabul',
        'Balkh' => 'Asia/Kabul',
        'Jowzjan' => 'Asia/Kabul',
        'Samangan' => 'Asia/Kabul',
        'Sar-e Pol' => 'Asia/Kabul',
        'Konar' => 'Asia/Kabul',
        'Laghman' => 'Asia/Kabul',
        'Paktia' => 'Asia/Kabul',
        'Khowst' => 'Asia/Kabul',
        'Nurestan' => 'Asia/Kabul',
        'Oruzgan' => 'Asia/Kabul',
        'Parvan' => 'Asia/Kabul',
        'Daykondi' => 'Asia/Kabul',
        'Panjshir' => 'Asia/Kabul',
      ],
      'AG' => [
        'Barbuda' => 'America/Antigua',
        'Saint George' => 'America/Antigua',
        'Saint John' => 'America/Antigua',
        'Saint Mary' => 'America/Antigua',
        'Saint Paul' => 'America/Antigua',
        'Saint Peter' => 'America/Antigua',
        'Saint Philip' => 'America/Antigua',
        'Redonda' => 'America/Antigua',
      ],
      'AL' => [
        'Berat' => 'Europe/Tirane',
        'Diber' => 'Europe/Tirane',
        'Durres' => 'Europe/Tirane',
        'Elbasan' => 'Europe/Tirane',
        'Fier' => 'Europe/Tirane',
        'Gjirokaster' => 'Europe/Tirane',
        'Korce' => 'Europe/Tirane',
        'Kukes' => 'Europe/Tirane',
        'Lezhe' => 'Europe/Tirane',
        'Shkoder' => 'Europe/Tirane',
        'Tirane' => 'Europe/Tirane',
        'Vlore' => 'Europe/Tirane',
      ],
      'AM' => [
        'Aragatsotn' => 'Asia/Yerevan',
        'Ararat' => 'Asia/Yerevan',
        'Armavir' => 'Asia/Yerevan',
        "Geghark'unik'" => 'Asia/Yerevan',
        "Kotayk'" => 'Asia/Yerevan',
        'Lorri' => 'Asia/Yerevan',
        'Shirak' => 'Asia/Yerevan',
        "Syunik'" => 'Asia/Yerevan',
        'Tavush' => 'Asia/Yerevan',
        "Vayots' Dzor" => 'Asia/Yerevan',
        'Yerevan' => 'Asia/Yerevan',
      ],
      'AO' => [
        'Benguela' => 'Africa/Luanda',
        'Bie' => 'Africa/Luanda',
        'Cabinda' => 'Africa/Luanda',
        'Cuando Cubango' => 'Africa/Luanda',
        'Cuanza Norte' => 'Africa/Luanda',
        'Cuanza Sul' => 'Africa/Luanda',
        'Cunene' => 'Africa/Luanda',
        'Huambo' => 'Africa/Luanda',
        'Huila' => 'Africa/Luanda',
        'Malanje' => 'Africa/Luanda',
        'Namibe' => 'Africa/Luanda',
        'Moxico' => 'Africa/Luanda',
        'Uige' => 'Africa/Luanda',
        'Zaire' => 'Africa/Luanda',
        'Lunda Norte' => 'Africa/Luanda',
        'Lunda Sul' => 'Africa/Luanda',
        'Bengo' => 'Africa/Luanda',
        'Luanda' => 'Africa/Luanda',
      ],
      'AR' => [
        'Buenos Aires' => 'America/Argentina/Buenos_Aires',
        'Catamarca' => 'America/Argentina/Catamarca',
        'Chaco' => 'America/Argentina/Tucuman',
        'Chubut' => 'America/Argentina/Rio_Gallegos',
        'Cordoba' => 'America/Argentina/Cordoba',
        'Corrientes' => 'America/Argentina/Tucuman',
        'Distrito Federal' => 'America/Argentina/Buenos_Aires',
        'Entre Rios' => 'America/Argentina/Buenos_Aires',
        'Formosa' => 'America/Argentina/Tucuman',
        'Jujuy' => 'America/Argentina/Jujuy',
        'La Pampa' => 'America/Argentina/San_Luis',
        'La Rioja' => 'America/Argentina/La_Rioja',
        'Mendoza' => 'America/Argentina/Mendoza',
        'Misiones' => 'America/Argentina/Buenos_Aires',
        'Neuquen' => 'America/Argentina/San_Luis',
        'Rio Negro' => 'America/Argentina/Buenos_Aires',
        'Salta' => 'America/Argentina/Salta',
        'San Juan' => 'America/Argentina/San_Juan',
        'San Luis' => 'America/Argentina/San_Luis',
        'Santa Cruz' => 'America/Argentina/Rio_Gallegos',
        'Santa Fe' => 'America/Argentina/Buenos_Aires',
        'Santiago del Estero' => 'America/Argentina/Catamarca',
        'Tierra del Fuego' => 'America/Argentina/Ushuaia',
        'Tucuman' => 'America/Argentina/Tucuman',
      ],
      'AT' => [
        'Burgenland' => 'Europe/Vienna',
        'Karnten' => 'Europe/Vienna',
        'Niederosterreich' => 'Europe/Vienna',
        'Oberosterreich' => 'Europe/Vienna',
        'Salzburg' => 'Europe/Vienna',
        'Steiermark' => 'Europe/Vienna',
        'Tirol' => 'Europe/Vienna',
        'Vorarlberg' => 'Europe/Vienna',
        'Wien' => 'Europe/Vienna',
      ],
      'AU' => [
        'Australian Capital Territory' => 'Australia/Sydney',
        'New South Wales' => 'Australia/Sydney',
        'Northern Territory' => 'Australia/Darwin',
        'Queensland' => 'Australia/Brisbane',
        'South Australia' => 'Australia/Adelaide',
        'Tasmania' => 'Australia/Hobart',
        'Victoria' => 'Australia/Melbourne',
        'Western Australia' => 'Australia/Perth',
      ],
      'AZ' => [
        'Abseron' => 'Asia/Baku',
        'Agcabadi' => 'Asia/Baku',
        'Agdam' => 'Asia/Baku',
        'Agdas' => 'Asia/Baku',
        'Agstafa' => 'Asia/Baku',
        'Agsu' => 'Asia/Baku',
        'Ali Bayramli' => 'Asia/Baku',
        'Astara' => 'Asia/Baku',
        'Baki' => 'Asia/Baku',
        'Balakan' => 'Asia/Baku',
        'Barda' => 'Asia/Baku',
        'Beylaqan' => 'Asia/Baku',
        'Bilasuvar' => 'Asia/Baku',
        'Cabrayil' => 'Asia/Baku',
        'Calilabad' => 'Asia/Baku',
        'Daskasan' => 'Asia/Baku',
        'Davaci' => 'Asia/Baku',
        'Fuzuli' => 'Asia/Baku',
        'Gadabay' => 'Asia/Baku',
        'Ganca' => 'Asia/Baku',
        'Goranboy' => 'Asia/Baku',
        'Goycay' => 'Asia/Baku',
        'Haciqabul' => 'Asia/Baku',
        'Imisli' => 'Asia/Baku',
        'Ismayilli' => 'Asia/Baku',
        'Kalbacar' => 'Asia/Baku',
        'Kurdamir' => 'Asia/Baku',
        'Lacin' => 'Asia/Baku',
        'Lankaran' => 'Asia/Baku',
        'Lerik' => 'Asia/Baku',
        'Masalli' => 'Asia/Baku',
        'Mingacevir' => 'Asia/Baku',
        'Naftalan' => 'Asia/Baku',
        'Naxcivan' => 'Asia/Baku',
        'Neftcala' => 'Asia/Baku',
        'Oguz' => 'Asia/Baku',
        'Qabala' => 'Asia/Baku',
        'Qax' => 'Asia/Baku',
        'Qazax' => 'Asia/Baku',
        'Qobustan' => 'Asia/Baku',
        'Quba' => 'Asia/Baku',
        'Qubadli' => 'Asia/Baku',
        'Qusar' => 'Asia/Baku',
        'Saatli' => 'Asia/Baku',
        'Sabirabad' => 'Asia/Baku',
        'Saki' => 'Asia/Baku',
        'Salyan' => 'Asia/Baku',
        'Samaxi' => 'Asia/Baku',
        'Samkir' => 'Asia/Baku',
        'Samux' => 'Asia/Baku',
        'Siyazan' => 'Asia/Baku',
        'Sumqayit' => 'Asia/Baku',
        'Susa' => 'Asia/Baku',
        'Tartar' => 'Asia/Baku',
        'Tovuz' => 'Asia/Baku',
        'Ucar' => 'Asia/Baku',
        'Xacmaz' => 'Asia/Baku',
        'Xankandi' => 'Asia/Baku',
        'Xanlar' => 'Asia/Baku',
        'Xizi' => 'Asia/Baku',
        'Xocali' => 'Asia/Baku',
        'Xocavand' => 'Asia/Baku',
        'Yardimli' => 'Asia/Baku',
        'Yevlax' => 'Asia/Baku',
        'Zangilan' => 'Asia/Baku',
        'Zaqatala' => 'Asia/Baku',
        'Zardab' => 'Asia/Baku',
      ],
      'BA' => [
        'Federation of Bosnia and Herzegovina' => 'Europe/Sarajevo',
        'Brcko District' => 'Europe/Sarajevo',
        'Republika Srpska' => 'Europe/Sarajevo',
      ],
      'BB' => [
        'Christ Church' => 'America/Barbados',
        'Saint Andrew' => 'America/Barbados',
        'Saint George' => 'America/Barbados',
        'Saint James' => 'America/Barbados',
        'Saint John' => 'America/Barbados',
        'Saint Joseph' => 'America/Barbados',
        'Saint Lucy' => 'America/Barbados',
        'Saint Michael' => 'America/Barbados',
        'Saint Peter' => 'America/Barbados',
        'Saint Philip' => 'America/Barbados',
        'Saint Thomas' => 'America/Barbados',
      ],
      'BD' => [
        'Dhaka' => 'Asia/Dhaka',
        'Khulna' => 'Asia/Dhaka',
        'Rajshahi' => 'Asia/Dhaka',
        'Chittagong' => 'Asia/Dhaka',
        'Barisal' => 'Asia/Dhaka',
        'Sylhet' => 'Asia/Dhaka',
        'Rangpur' => 'Asia/Dhaka',
      ],
      'BE' => [
        'Antwerpen' => 'Europe/Brussels',
        'Hainaut' => 'Europe/Brussels',
        'Liege' => 'Europe/Brussels',
        'Limburg' => 'Europe/Brussels',
        'Luxembourg' => 'Europe/Brussels',
        'Namur' => 'Europe/Brussels',
        'Oost-Vlaanderen' => 'Europe/Brussels',
        'West-Vlaanderen' => 'Europe/Brussels',
        'Brabant Wallon' => 'Europe/Brussels',
        'Brussels Hoofdstedelijk Gewest' => 'Europe/Brussels',
        'Vlaams-Brabant' => 'Europe/Brussels',
        'Flanders' => 'Europe/Brussels',
        'Wallonia' => 'Europe/Brussels',
      ],
      'BF' => [
        'Bam' => 'Africa/Ouagadougou',
        'Boulkiemde' => 'Africa/Ouagadougou',
        'Ganzourgou' => 'Africa/Ouagadougou',
        'Gnagna' => 'Africa/Ouagadougou',
        'Kouritenga' => 'Africa/Ouagadougou',
        'Oudalan' => 'Africa/Ouagadougou',
        'Passore' => 'Africa/Ouagadougou',
        'Sanguie' => 'Africa/Ouagadougou',
        'Soum' => 'Africa/Ouagadougou',
        'Tapoa' => 'Africa/Ouagadougou',
        'Zoundweogo' => 'Africa/Ouagadougou',
        'Bale' => 'Africa/Ouagadougou',
        'Banwa' => 'Africa/Ouagadougou',
        'Bazega' => 'Africa/Ouagadougou',
        'Bougouriba' => 'Africa/Ouagadougou',
        'Boulgou' => 'Africa/Ouagadougou',
        'Gourma' => 'Africa/Ouagadougou',
        'Houet' => 'Africa/Ouagadougou',
        'Ioba' => 'Africa/Ouagadougou',
        'Kadiogo' => 'Africa/Ouagadougou',
        'Kenedougou' => 'Africa/Ouagadougou',
        'Komoe' => 'Africa/Ouagadougou',
        'Komondjari' => 'Africa/Ouagadougou',
        'Kompienga' => 'Africa/Ouagadougou',
        'Kossi' => 'Africa/Ouagadougou',
        'Koulpelogo' => 'Africa/Ouagadougou',
        'Kourweogo' => 'Africa/Ouagadougou',
        'Leraba' => 'Africa/Ouagadougou',
        'Loroum' => 'Africa/Ouagadougou',
        'Mouhoun' => 'Africa/Ouagadougou',
        'Namentenga' => 'Africa/Ouagadougou',
        'Naouri' => 'Africa/Ouagadougou',
        'Nayala' => 'Africa/Ouagadougou',
        'Noumbiel' => 'Africa/Ouagadougou',
        'Oubritenga' => 'Africa/Ouagadougou',
        'Poni' => 'Africa/Ouagadougou',
        'Sanmatenga' => 'Africa/Ouagadougou',
        'Seno' => 'Africa/Ouagadougou',
        'Sissili' => 'Africa/Ouagadougou',
        'Sourou' => 'Africa/Ouagadougou',
        'Tuy' => 'Africa/Ouagadougou',
        'Yagha' => 'Africa/Ouagadougou',
        'Yatenga' => 'Africa/Ouagadougou',
        'Ziro' => 'Africa/Ouagadougou',
        'Zondoma' => 'Africa/Ouagadougou',
      ],
      'BG' => [
        'Mikhaylovgrad' => 'Europe/Sofia',
        'Blagoevgrad' => 'Europe/Sofia',
        'Burgas' => 'Europe/Sofia',
        'Dobrich' => 'Europe/Sofia',
        'Gabrovo' => 'Europe/Sofia',
        'Grad Sofiya' => 'Europe/Sofia',
        'Khaskovo' => 'Europe/Sofia',
        'Kurdzhali' => 'Europe/Sofia',
        'Kyustendil' => 'Europe/Sofia',
        'Lovech' => 'Europe/Sofia',
        'Montana' => 'Europe/Sofia',
        'Pazardzhik' => 'Europe/Sofia',
        'Pernik' => 'Europe/Sofia',
        'Pleven' => 'Europe/Sofia',
        'Plovdiv' => 'Europe/Sofia',
        'Razgrad' => 'Europe/Sofia',
        'Ruse' => 'Europe/Sofia',
        'Shumen' => 'Europe/Sofia',
        'Silistra' => 'Europe/Sofia',
        'Sliven' => 'Europe/Sofia',
        'Smolyan' => 'Europe/Sofia',
        'Sofiya' => 'Europe/Sofia',
        'Stara Zagora' => 'Europe/Sofia',
        'Turgovishte' => 'Europe/Sofia',
        'Varna' => 'Europe/Sofia',
        'Veliko Turnovo' => 'Europe/Sofia',
        'Vidin' => 'Europe/Sofia',
        'Vratsa' => 'Europe/Sofia',
        'Yambol' => 'Europe/Sofia',
      ],
      'BH' => [
        'Al Hadd' => 'Asia/Bahrain',
        'Al Manamah' => 'Asia/Bahrain',
        'Jidd Hafs' => 'Asia/Bahrain',
        'Sitrah' => 'Asia/Bahrain',
        'Al Mintaqah al Gharbiyah' => 'Asia/Bahrain',
        'Mintaqat Juzur Hawar' => 'Asia/Bahrain',
        'Al Mintaqah ash Shamaliyah' => 'Asia/Bahrain',
        'Al Mintaqah al Wusta' => 'Asia/Bahrain',
        'Madinat' => 'Asia/Bahrain',
        'Ar Rifa' => 'Asia/Bahrain',
        'Madinat Hamad' => 'Asia/Bahrain',
        'Al Muharraq' => 'Asia/Bahrain',
        'Al Asimah' => 'Asia/Bahrain',
        'Al Janubiyah' => 'Asia/Bahrain',
        'Ash Shamaliyah' => 'Asia/Bahrain',
        'Al Wusta' => 'Asia/Bahrain',
      ],
      'BI' => [
        'Bujumbura' => 'Africa/Bujumbura',
        'Bubanza' => 'Africa/Bujumbura',
        'Bururi' => 'Africa/Bujumbura',
        'Cankuzo' => 'Africa/Bujumbura',
        'Cibitoke' => 'Africa/Bujumbura',
        'Gitega' => 'Africa/Bujumbura',
        'Karuzi' => 'Africa/Bujumbura',
        'Kayanza' => 'Africa/Bujumbura',
        'Kirundo' => 'Africa/Bujumbura',
        'Makamba' => 'Africa/Bujumbura',
        'Muyinga' => 'Africa/Bujumbura',
        'Ngozi' => 'Africa/Bujumbura',
        'Rutana' => 'Africa/Bujumbura',
        'Ruyigi' => 'Africa/Bujumbura',
        'Muramvya' => 'Africa/Bujumbura',
        'Mwaro' => 'Africa/Bujumbura',
      ],
      'BJ' => [
        'Alibori' => 'Africa/Porto-Novo',
        'Atakora' => 'Africa/Porto-Novo',
        'Atlanyique' => 'Africa/Porto-Novo',
        'Borgou' => 'Africa/Porto-Novo',
        'Collines' => 'Africa/Porto-Novo',
        'Kouffo' => 'Africa/Porto-Novo',
        'Donga' => 'Africa/Porto-Novo',
        'Littoral' => 'Africa/Porto-Novo',
        'Mono' => 'Africa/Porto-Novo',
        'Oueme' => 'Africa/Porto-Novo',
        'Plateau' => 'Africa/Porto-Novo',
        'Zou' => 'Africa/Porto-Novo',
      ],
      'BM' => [
        'Devonshire' => 'Atlantic/Bermuda',
        'Hamilton' => 'Atlantic/Bermuda',
        'Paget' => 'Atlantic/Bermuda',
        'Pembroke' => 'Atlantic/Bermuda',
        'Saint George' => 'Atlantic/Bermuda',
        "Saint George's" => 'Atlantic/Bermuda',
        'Sandys' => 'Atlantic/Bermuda',
        'Smiths' => 'Atlantic/Bermuda',
        'Southampton' => 'Atlantic/Bermuda',
        'Warwick' => 'Atlantic/Bermuda',
      ],
      'BN' => [
        'Alibori' => 'Asia/Brunei',
        'Belait' => 'Asia/Brunei',
        'Brunei and Muara' => 'Asia/Brunei',
        'Temburong' => 'Asia/Brunei',
        'Collines' => 'Asia/Brunei',
        'Kouffo' => 'Asia/Brunei',
        'Donga' => 'Asia/Brunei',
        'Littoral' => 'Asia/Brunei',
        'Tutong' => 'Asia/Brunei',
        'Oueme' => 'Asia/Brunei',
        'Plateau' => 'Asia/Brunei',
        'Zou' => 'Asia/Brunei',
      ],
      'BO' => [
        'Chuquisaca' => 'America/La_Paz',
        'Cochabamba' => 'America/La_Paz',
        'El Beni' => 'America/La_Paz',
        'La Paz' => 'America/La_Paz',
        'Oruro' => 'America/La_Paz',
        'Pando' => 'America/La_Paz',
        'Potosi' => 'America/La_Paz',
        'Santa Cruz' => 'America/La_Paz',
        'Tarija' => 'America/La_Paz',
      ],
      'BR' => [
        'Acre' => 'America/Rio_Branco',
        'Alagoas' => 'America/Maceio',
        'Amapa' => 'America/Sao_Paulo',
        'Amazonas' => 'America/Manaus',
        'Bahia' => 'America/Bahia',
        'Ceara' => 'America/Fortaleza',
        'Distrito Federal' => 'America/Sao_Paulo',
        'Espirito Santo' => 'America/Sao_Paulo',
        'Mato Grosso do Sul' => 'America/Campo_Grande',
        'Maranhao' => 'America/Belem',
        'Mato Grosso' => 'America/Cuiaba',
        'Minas Gerais' => 'America/Sao_Paulo',
        'Para' => 'America/Belem',
        'Paraiba' => 'America/Recife',
        'Parana' => 'America/Sao_Paulo',
        'Piaui' => 'America/Fortaleza',
        'Rio de Janeiro' => 'America/Sao_Paulo',
        'Rio Grande do Norte' => 'America/Recife',
        'Rio Grande do Sul' => 'America/Sao_Paulo',
        'Rondonia' => 'America/Porto_Velho',
        'Roraima' => 'America/Boa_Vista',
        'Santa Catarina' => 'America/Sao_Paulo',
        'Sao Paulo' => 'America/Sao_Paulo',
        'Sergipe' => 'America/Maceio',
        'Goias' => 'America/Sao_Paulo',
        'Pernambuco' => 'America/Recife',
        'Tocantins' => 'America/Araguaina',
      ],
      'BS' => [
        'Bimini' => 'America/Nassau',
        'Cat Island' => 'America/Nassau',
        'Exuma' => 'America/Nassau',
        'Inagua' => 'America/Nassau',
        'Long Island' => 'America/Nassau',
        'Mayaguana' => 'America/Nassau',
        'Ragged Island' => 'America/Nassau',
        'Harbour Island' => 'America/Nassau',
        'New Providence' => 'America/Nassau',
        'Acklins and Crooked Islands' => 'America/Nassau',
        'Freeport' => 'America/Nassau',
        'Fresh Creek' => 'America/Nassau',
        "Governor's Harbour" => 'America/Nassau',
        'Green Turtle Cay' => 'America/Nassau',
        'High Rock' => 'America/Nassau',
        'Kemps Bay' => 'America/Nassau',
        'Marsh Harbour' => 'America/Nassau',
        'Nichollstown and Berry Islands' => 'America/Nassau',
        'Rock Sound' => 'America/Nassau',
        'Sandy Point' => 'America/Nassau',
        'San Salvador and Rum Cay' => 'America/Nassau',
      ],
      'BT' => [
        'Bumthang' => 'Asia/Thimphu',
        'Chhukha' => 'Asia/Thimphu',
        'Chirang' => 'Asia/Thimphu',
        'Daga' => 'Asia/Thimphu',
        'Geylegphug' => 'Asia/Thimphu',
        'Ha' => 'Asia/Thimphu',
        'Lhuntshi' => 'Asia/Thimphu',
        'Mongar' => 'Asia/Thimphu',
        'Paro' => 'Asia/Thimphu',
        'Pemagatsel' => 'Asia/Thimphu',
        'Punakha' => 'Asia/Thimphu',
        'Samchi' => 'Asia/Thimphu',
        'Samdrup' => 'Asia/Thimphu',
        'Shemgang' => 'Asia/Thimphu',
        'Tashigang' => 'Asia/Thimphu',
        'Thimphu' => 'Asia/Thimphu',
        'Tongsa' => 'Asia/Thimphu',
        'Wangdi Phodrang' => 'Asia/Thimphu',
      ],
      'BW' => [
        'Central' => 'Africa/Gaborone',
        'Ghanzi' => 'Africa/Gaborone',
        'Kgalagadi' => 'Africa/Gaborone',
        'Kgatleng' => 'Africa/Gaborone',
        'Kweneng' => 'Africa/Gaborone',
        'North-East' => 'Africa/Gaborone',
        'South-East' => 'Africa/Gaborone',
        'Southern' => 'Africa/Gaborone',
        'North-West' => 'Africa/Gaborone',
      ],
      'BY' => [
        "Brestskaya Voblasts'" => 'Europe/Minsk',
        "Homyel'skaya Voblasts'" => 'Europe/Minsk',
        "Hrodzyenskaya Voblasts'" => 'Europe/Minsk',
        'Minsk' => 'Europe/Minsk',
        "Minskaya Voblasts'" => 'Europe/Minsk',
        "Mahilyowskaya Voblasts'" => 'Europe/Minsk',
        "Vitsyebskaya Voblasts'" => 'Europe/Minsk',
      ],
      'BZ' => [
        'Belize' => 'America/Belize',
        'Cayo' => 'America/Belize',
        'Corozal' => 'America/Belize',
        'Orange Walk' => 'America/Belize',
        'Stann Creek' => 'America/Belize',
        'Toledo' => 'America/Belize',
      ],
      'CA' => [
        'Alberta' => 'America/Edmonton',
        'British Columbia' => 'America/Vancouver',
        'Manitoba' => 'America/Winnipeg',
        'New Brunswick' => 'America/Halifax',
        'Newfoundland' => 'America/St_Johns',
        'Nova Scotia' => 'America/Halifax',
        'Northwest Territories' => 'America/Yellowknife',
        'Nunavut' => 'America/Rankin_Inlet',
        'Ontario' => 'America/Toronto',
        'Prince Edward Island' => 'America/Halifax',
        'Quebec' => 'America/Montreal',
        'Saskatchewan' => 'America/Regina',
        'Yukon Territory' => 'America/Whitehorse',
      ],
      'CD' => [
        'Bandundu' => 'Africa/Kinshasa',
        'Equateur' => 'Africa/Kinshasa',
        'Kasai-Oriental' => 'Africa/Lubumbashi',
        'Katanga' => 'Africa/Lubumbashi',
        'Kinshasa' => 'Africa/Kinshasa',
        'Bas-Congo' => 'Africa/Kinshasa',
        'Orientale' => 'Africa/Lubumbashi',
        'Maniema' => 'Africa/Lubumbashi',
        'Nord-Kivu' => 'Africa/Lubumbashi',
        'Sud-Kivu' => 'Africa/Lubumbashi',
      ],
      'CF' => [
        'Bamingui-Bangoran' => 'Africa/Bangui',
        'Basse-Kotto' => 'Africa/Bangui',
        'Haute-Kotto' => 'Africa/Bangui',
        'Mambere-Kadei' => 'Africa/Bangui',
        'Haut-Mbomou' => 'Africa/Bangui',
        'Kemo' => 'Africa/Bangui',
        'Lobaye' => 'Africa/Bangui',
        'Mbomou' => 'Africa/Bangui',
        'Nana-Mambere' => 'Africa/Bangui',
        'Ouaka' => 'Africa/Bangui',
        'Ouham' => 'Africa/Bangui',
        'Ouham-Pende' => 'Africa/Bangui',
        'Cuvette-Ouest' => 'Africa/Bangui',
        'Nana-Grebizi' => 'Africa/Bangui',
        'Sangha-Mbaere' => 'Africa/Bangui',
        'Ombella-Mpoko' => 'Africa/Bangui',
        'Bangui' => 'Africa/Bangui',
      ],
      'CG' => [
        'Bouenza' => 'Africa/Brazzaville',
        'Kouilou' => 'Africa/Brazzaville',
        'Lekoumou' => 'Africa/Brazzaville',
        'Likouala' => 'Africa/Brazzaville',
        'Niari' => 'Africa/Brazzaville',
        'Plateaux' => 'Africa/Brazzaville',
        'Sangha' => 'Africa/Brazzaville',
        'Pool' => 'Africa/Brazzaville',
        'Brazzaville' => 'Africa/Brazzaville',
        'Cuvette' => 'Africa/Brazzaville',
        'Cuvette-Ouest' => 'Africa/Brazzaville',
      ],
      'CH' => [
        'Aargau' => 'Europe/Zurich',
        'Ausser-Rhoden' => 'Europe/Zurich',
        'Basel-Landschaft' => 'Europe/Zurich',
        'Basel-Stadt' => 'Europe/Zurich',
        'Bern' => 'Europe/Zurich',
        'Fribourg' => 'Europe/Zurich',
        'Geneve' => 'Europe/Zurich',
        'Glarus' => 'Europe/Zurich',
        'Graubunden' => 'Europe/Zurich',
        'Inner-Rhoden' => 'Europe/Zurich',
        'Luzern' => 'Europe/Zurich',
        'Neuchatel' => 'Europe/Zurich',
        'Nidwalden' => 'Europe/Zurich',
        'Obwalden' => 'Europe/Zurich',
        'Sankt Gallen' => 'Europe/Zurich',
        'Schaffhausen' => 'Europe/Zurich',
        'Schwyz' => 'Europe/Zurich',
        'Solothurn' => 'Europe/Zurich',
        'Thurgau' => 'Europe/Zurich',
        'Ticino' => 'Europe/Zurich',
        'Uri' => 'Europe/Zurich',
        'Valais' => 'Europe/Zurich',
        'Vaud' => 'Europe/Zurich',
        'Zug' => 'Europe/Zurich',
        'Zurich' => 'Europe/Zurich',
        'Jura' => 'Europe/Zurich',
      ],
      'CI' => [
        'Agneby' => 'Africa/Abidjan',
        'Bafing' => 'Africa/Abidjan',
        'Bas-Sassandra' => 'Africa/Abidjan',
        'Denguele' => 'Africa/Abidjan',
        'Dix-Huit Montagnes' => 'Africa/Abidjan',
        'Fromager' => 'Africa/Abidjan',
        'Haut-Sassandra' => 'Africa/Abidjan',
        'Lacs' => 'Africa/Abidjan',
        'Lagunes' => 'Africa/Abidjan',
        'Marahoue' => 'Africa/Abidjan',
        'Moyen-Cavally' => 'Africa/Abidjan',
        'Moyen-Comoe' => 'Africa/Abidjan',
        "N'zi-Comoe" => 'Africa/Abidjan',
        'Savanes' => 'Africa/Abidjan',
        'Sud-Bandama' => 'Africa/Abidjan',
        'Sud-Comoe' => 'Africa/Abidjan',
        'Vallee du Bandama' => 'Africa/Abidjan',
        'Worodougou' => 'Africa/Abidjan',
        'Zanzan' => 'Africa/Abidjan',
      ],
      'CL' => [
        'Valparaiso' => 'America/Santiago',
        'Aisen del General Carlos Ibanez del Campo' => 'America/Santiago',
        'Antofagasta' => 'America/Santiago',
        'Araucania' => 'America/Santiago',
        'Atacama' => 'America/Santiago',
        'Bio-Bio' => 'America/Santiago',
        'Coquimbo' => 'America/Santiago',
        "Libertador General Bernardo O'Higgins" => 'America/Santiago',
        'Los Lagos' => 'America/Santiago',
        'Magallanes y de la Antartica Chilena' => 'America/Santiago',
        'Maule' => 'America/Santiago',
        'Region Metropolitana' => 'America/Santiago',
        'Tarapaca' => 'America/Santiago',
        'Arica y Parinacota' => 'America/Santiago',
        'Los Rios' => 'America/Santiago',
      ],
      'CM' => [
        'Est' => 'Africa/Lagos',
        'Littoral' => 'Africa/Lagos',
        'Nord-Ouest' => 'Africa/Lagos',
        'Ouest' => 'Africa/Lagos',
        'Sud-Ouest' => 'Africa/Lagos',
        'Adamaoua' => 'Africa/Lagos',
        'Centre' => 'Africa/Lagos',
        'Extreme-Nord' => 'Africa/Lagos',
        'Nord' => 'Africa/Lagos',
        'Sud' => 'Africa/Lagos',
      ],
      'CN' => [
        'Anhui' => 'Asia/Shanghai',
        'Zhejiang' => 'Asia/Shanghai',
        'Jiangxi' => 'Asia/Shanghai',
        'Jiangsu' => 'Asia/Shanghai',
        'Jilin' => 'Asia/Harbin',
        'Qinghai' => 'Asia/Chongqing',
        'Fujian' => 'Asia/Shanghai',
        'Heilongjiang' => 'Asia/Harbin',
        'Henan' => 'Asia/Shanghai',
        'Hebei' => 'Asia/Shanghai',
        'Hunan' => 'Asia/Chongqing',
        'Hubei' => 'Asia/Shanghai',
        'Xinjiang' => 'Asia/Urumqi',
        'Xizang' => 'Asia/Chongqing',
        'Gansu' => 'Asia/Chongqing',
        'Guangxi' => 'Asia/Chongqing',
        'Guizhou' => 'Asia/Chongqing',
        'Liaoning' => 'Asia/Harbin',
        'Nei Mongol' => 'Asia/Harbin',
        'Ningxia' => 'Asia/Chongqing',
        'Beijing' => 'Asia/Harbin',
        'Shanghai' => 'Asia/Shanghai',
        'Shanxi' => 'Asia/Chongqing',
        'Shandong' => 'Asia/Shanghai',
        'Shaanxi' => 'Asia/Chongqing',
        'Tianjin' => 'Asia/Shanghai',
        'Yunnan' => 'Asia/Chongqing',
        'Guangdong' => 'Asia/Chongqing',
        'Hainan' => 'Asia/Chongqing',
        'Sichuan' => 'Asia/Chongqing',
        'Chongqing' => 'Asia/Chongqing',
      ],
      'CO' => [
        'Amazonas' => 'America/Bogota',
        'Antioquia' => 'America/Bogota',
        'Arauca' => 'America/Bogota',
        'Atlantico' => 'America/Bogota',
        'Caqueta' => 'America/Bogota',
        'Cauca' => 'America/Bogota',
        'Cesar' => 'America/Bogota',
        'Choco' => 'America/Bogota',
        'Cordoba' => 'America/Bogota',
        'Guaviare' => 'America/Bogota',
        'Guainia' => 'America/Bogota',
        'Huila' => 'America/Bogota',
        'La Guajira' => 'America/Bogota',
        'Meta' => 'America/Bogota',
        'Narino' => 'America/Bogota',
        'Norte de Santander' => 'America/Bogota',
        'Putumayo' => 'America/Bogota',
        'Quindio' => 'America/Bogota',
        'Risaralda' => 'America/Bogota',
        'San Andres y Providencia' => 'America/Bogota',
        'Santander' => 'America/Bogota',
        'Sucre' => 'America/Bogota',
        'Tolima' => 'America/Bogota',
        'Valle del Cauca' => 'America/Bogota',
        'Vaupes' => 'America/Bogota',
        'Vichada' => 'America/Bogota',
        'Casanare' => 'America/Bogota',
        'Cundinamarca' => 'America/Bogota',
        'Distrito Especial' => 'America/Bogota',
        'Bolivar' => 'America/Bogota',
        'Boyaca' => 'America/Bogota',
        'Caldas' => 'America/Bogota',
        'Magdalena' => 'America/Bogota',
      ],
      'CR' => [
        'Alajuela' => 'America/Costa_Rica',
        'Cartago' => 'America/Costa_Rica',
        'Guanacaste' => 'America/Costa_Rica',
        'Heredia' => 'America/Costa_Rica',
        'Limon' => 'America/Costa_Rica',
        'Puntarenas' => 'America/Costa_Rica',
        'San Jose' => 'America/Costa_Rica',
      ],
      'CU' => [
        'Pinar del Rio' => 'America/Havana',
        'Ciudad de la Habana' => 'America/Havana',
        'Matanzas' => 'America/Havana',
        'Isla de la Juventud' => 'America/Havana',
        'Camaguey' => 'America/Havana',
        'Ciego de Avila' => 'America/Havana',
        'Cienfuegos' => 'America/Havana',
        'Granma' => 'America/Havana',
        'Guantanamo' => 'America/Havana',
        'La Habana' => 'America/Havana',
        'Holguin' => 'America/Havana',
        'Las Tunas' => 'America/Havana',
        'Sancti Spiritus' => 'America/Havana',
        'Santiago de Cuba' => 'America/Havana',
        'Villa Clara' => 'America/Havana',
      ],
      'CV' => [
        'Boa Vista' => 'Atlantic/Cape_Verde',
        'Brava' => 'Atlantic/Cape_Verde',
        'Maio' => 'Atlantic/Cape_Verde',
        'Paul' => 'Atlantic/Cape_Verde',
        'Ribeira Grande' => 'Atlantic/Cape_Verde',
        'Sal' => 'Atlantic/Cape_Verde',
        'Sao Nicolau' => 'Atlantic/Cape_Verde',
        'Sao Vicente' => 'Atlantic/Cape_Verde',
        'Mosteiros' => 'Atlantic/Cape_Verde',
        'Praia' => 'Atlantic/Cape_Verde',
        'Santa Catarina' => 'Atlantic/Cape_Verde',
        'Santa Cruz' => 'Atlantic/Cape_Verde',
        'Sao Domingos' => 'Atlantic/Cape_Verde',
        'Sao Filipe' => 'Atlantic/Cape_Verde',
        'Sao Miguel' => 'Atlantic/Cape_Verde',
        'Tarrafal' => 'Atlantic/Cape_Verde',
      ],
      'CY' => [
        'Famagusta' => 'Asia/Nicosia',
        'Kyrenia' => 'Asia/Nicosia',
        'Larnaca' => 'Asia/Nicosia',
        'Nicosia' => 'Asia/Nicosia',
        'Limassol' => 'Asia/Nicosia',
        'Paphos' => 'Asia/Nicosia',
      ],
      'CZ' => [
        'Hlavni mesto Praha' => 'Europe/Prague',
        'Jihomoravsky kraj' => 'Europe/Prague',
        'Jihocesky kraj' => 'Europe/Prague',
        'Vysocina' => 'Europe/Prague',
        'Karlovarsky kraj' => 'Europe/Prague',
        'Kralovehradecky kraj' => 'Europe/Prague',
        'Liberecky kraj' => 'Europe/Prague',
        'Olomoucky kraj' => 'Europe/Prague',
        'Moravskoslezsky kraj' => 'Europe/Prague',
        'Pardubicky kraj' => 'Europe/Prague',
        'Plzensky kraj' => 'Europe/Prague',
        'Stredocesky kraj' => 'Europe/Prague',
        'Ustecky kraj' => 'Europe/Prague',
        'Zlinsky kraj' => 'Europe/Prague',
      ],
      'DE' => [
        'Baden-Wurttemberg' => 'Europe/Berlin',
        'Bayern' => 'Europe/Berlin',
        'Bremen' => 'Europe/Berlin',
        'Hamburg' => 'Europe/Berlin',
        'Hessen' => 'Europe/Berlin',
        'Niedersachsen' => 'Europe/Berlin',
        'Nordrhein-Westfalen' => 'Europe/Berlin',
        'Rheinland-Pfalz' => 'Europe/Berlin',
        'Saarland' => 'Europe/Berlin',
        'Schleswig-Holstein' => 'Europe/Berlin',
        'Brandenburg' => 'Europe/Berlin',
        'Mecklenburg-Vorpommern' => 'Europe/Berlin',
        'Sachsen' => 'Europe/Berlin',
        'Sachsen-Anhalt' => 'Europe/Berlin',
        'Thuringen' => 'Europe/Berlin',
        'Berlin' => 'Europe/Berlin',
      ],
      'DJ' => [
        'Ali Sabieh' => 'Africa/Djibouti',
        'Obock' => 'Africa/Djibouti',
        'Tadjoura' => 'Africa/Djibouti',
        'Dikhil' => 'Africa/Djibouti',
        'Djibouti' => 'Africa/Djibouti',
        'Arta' => 'Africa/Djibouti',
      ],
      'DK' => [
        'Hovedstaden' => 'Europe/Copenhagen',
        'Midtjylland' => 'Europe/Copenhagen',
        'Nordjylland' => 'Europe/Copenhagen',
        'Sjelland' => 'Europe/Copenhagen',
        'Syddanmark' => 'Europe/Copenhagen',
      ],
      'DM' => [
        'Saint Andrew' => 'America/Dominica',
        'Saint David' => 'America/Dominica',
        'Saint George' => 'America/Dominica',
        'Saint John' => 'America/Dominica',
        'Saint Joseph' => 'America/Dominica',
        'Saint Luke' => 'America/Dominica',
        'Saint Mark' => 'America/Dominica',
        'Saint Patrick' => 'America/Dominica',
        'Saint Paul' => 'America/Dominica',
        'Saint Peter' => 'America/Dominica',
      ],
      'DO' => [
        'Azua' => 'America/Santo_Domingo',
        'Baoruco' => 'America/Santo_Domingo',
        'Barahona' => 'America/Santo_Domingo',
        'Dajabon' => 'America/Santo_Domingo',
        'Distrito Nacional' => 'America/Santo_Domingo',
        'Duarte' => 'America/Santo_Domingo',
        'Espaillat' => 'America/Santo_Domingo',
        'Independencia' => 'America/Santo_Domingo',
        'La Altagracia' => 'America/Santo_Domingo',
        'Elias Pina' => 'America/Santo_Domingo',
        'La Romana' => 'America/Santo_Domingo',
        'Maria Trinidad Sanchez' => 'America/Santo_Domingo',
        'Monte Cristi' => 'America/Santo_Domingo',
        'Pedernales' => 'America/Santo_Domingo',
        'Peravia' => 'America/Santo_Domingo',
        'Puerto Plata' => 'America/Santo_Domingo',
        'Salcedo' => 'America/Santo_Domingo',
        'Samana' => 'America/Santo_Domingo',
        'Sanchez Ramirez' => 'America/Santo_Domingo',
        'San Juan' => 'America/Santo_Domingo',
        'San Pedro De Macoris' => 'America/Santo_Domingo',
        'Santiago' => 'America/Santo_Domingo',
        'Santiago Rodriguez' => 'America/Santo_Domingo',
        'Valverde' => 'America/Santo_Domingo',
        'El Seibo' => 'America/Santo_Domingo',
        'Hato Mayor' => 'America/Santo_Domingo',
        'La Vega' => 'America/Santo_Domingo',
        'Monsenor Nouel' => 'America/Santo_Domingo',
        'Monte Plata' => 'America/Santo_Domingo',
        'San Cristobal' => 'America/Santo_Domingo',
        'San Jose de Ocoa' => 'America/Santo_Domingo',
        'Santo Domingo' => 'America/Santo_Domingo',
      ],
      'DZ' => [
        'Alger' => 'Africa/Algiers',
        'Batna' => 'Africa/Algiers',
        'Constantine' => 'Africa/Algiers',
        'Medea' => 'Africa/Algiers',
        'Mostaganem' => 'Africa/Algiers',
        'Oran' => 'Africa/Algiers',
        'Saida' => 'Africa/Algiers',
        'Setif' => 'Africa/Algiers',
        'Tiaret' => 'Africa/Algiers',
        'Tizi Ouzou' => 'Africa/Algiers',
        'Tlemcen' => 'Africa/Algiers',
        'Bejaia' => 'Africa/Algiers',
        'Biskra' => 'Africa/Algiers',
        'Blida' => 'Africa/Algiers',
        'Bouira' => 'Africa/Algiers',
        'Djelfa' => 'Africa/Algiers',
        'Guelma' => 'Africa/Algiers',
        'Jijel' => 'Africa/Algiers',
        'Laghouat' => 'Africa/Algiers',
        'Mascara' => 'Africa/Algiers',
        "M'sila" => 'Africa/Algiers',
        'Oum el Bouaghi' => 'Africa/Algiers',
        'Sidi Bel Abbes' => 'Africa/Algiers',
        'Skikda' => 'Africa/Algiers',
        'Tebessa' => 'Africa/Algiers',
        'Adrar' => 'Africa/Algiers',
        'Ain Defla' => 'Africa/Algiers',
        'Ain Temouchent' => 'Africa/Algiers',
        'Annaba' => 'Africa/Algiers',
        'Bechar' => 'Africa/Algiers',
        'Bordj Bou Arreridj' => 'Africa/Algiers',
        'Boumerdes' => 'Africa/Algiers',
        'Chlef' => 'Africa/Algiers',
        'El Bayadh' => 'Africa/Algiers',
        'El Oued' => 'Africa/Algiers',
        'El Tarf' => 'Africa/Algiers',
        'Ghardaia' => 'Africa/Algiers',
        'Illizi' => 'Africa/Algiers',
        'Khenchela' => 'Africa/Algiers',
        'Mila' => 'Africa/Algiers',
        'Naama' => 'Africa/Algiers',
        'Ouargla' => 'Africa/Algiers',
        'Relizane' => 'Africa/Algiers',
        'Souk Ahras' => 'Africa/Algiers',
        'Tamanghasset' => 'Africa/Algiers',
        'Tindouf' => 'Africa/Algiers',
        'Tipaza' => 'Africa/Algiers',
        'Tissemsilt' => 'Africa/Algiers',
      ],
      'EC' => [
        'Galapagos' => 'Pacific/Galapagos',
        'Azuay' => 'America/Guayaquil',
        'Bolivar' => 'America/Guayaquil',
        'Canar' => 'America/Guayaquil',
        'Carchi' => 'America/Guayaquil',
        'Chimborazo' => 'America/Guayaquil',
        'Cotopaxi' => 'America/Guayaquil',
        'El Oro' => 'America/Guayaquil',
        'Esmeraldas' => 'America/Guayaquil',
        'Guayas' => 'America/Guayaquil',
        'Imbabura' => 'America/Guayaquil',
        'Loja' => 'America/Guayaquil',
        'Los Rios' => 'America/Guayaquil',
        'Manabi' => 'America/Guayaquil',
        'Morona-Santiago' => 'America/Guayaquil',
        'Pastaza' => 'America/Guayaquil',
        'Pichincha' => 'America/Guayaquil',
        'Tungurahua' => 'America/Guayaquil',
        'Zamora-Chinchipe' => 'America/Guayaquil',
        'Sucumbios' => 'America/Guayaquil',
        'Napo' => 'America/Guayaquil',
        'Orellana' => 'America/Guayaquil',
      ],
      'EE' => [
        'Harjumaa' => 'Europe/Tallinn',
        'Hiiumaa' => 'Europe/Tallinn',
        'Ida-Virumaa' => 'Europe/Tallinn',
        'Jarvamaa' => 'Europe/Tallinn',
        'Jogevamaa' => 'Europe/Tallinn',
        'Kohtla-Jarve' => 'Europe/Tallinn',
        'Laanemaa' => 'Europe/Tallinn',
        'Laane-Virumaa' => 'Europe/Tallinn',
        'Narva' => 'Europe/Tallinn',
        'Parnu' => 'Europe/Tallinn',
        'Parnumaa' => 'Europe/Tallinn',
        'Polvamaa' => 'Europe/Tallinn',
        'Raplamaa' => 'Europe/Tallinn',
        'Saaremaa' => 'Europe/Tallinn',
        'Sillamae' => 'Europe/Tallinn',
        'Tallinn' => 'Europe/Tallinn',
        'Tartu' => 'Europe/Tallinn',
        'Tartumaa' => 'Europe/Tallinn',
        'Valgamaa' => 'Europe/Tallinn',
        'Viljandimaa' => 'Europe/Tallinn',
        'Vorumaa' => 'Europe/Tallinn',
      ],
      'EG' => [
        'Ad Daqahliyah' => 'Africa/Cairo',
        'Al Bahr al Ahmar' => 'Africa/Cairo',
        'Al Buhayrah' => 'Africa/Cairo',
        'Al Fayyum' => 'Africa/Cairo',
        'Al Gharbiyah' => 'Africa/Cairo',
        'Al Iskandariyah' => 'Africa/Cairo',
        "Al Isma'iliyah" => 'Africa/Cairo',
        'Al Jizah' => 'Africa/Cairo',
        'Al Minufiyah' => 'Africa/Cairo',
        'Al Minya' => 'Africa/Cairo',
        'Al Qahirah' => 'Africa/Cairo',
        'Al Qalyubiyah' => 'Africa/Cairo',
        'Al Wadi al Jadid' => 'Africa/Cairo',
        'Ash Sharqiyah' => 'Africa/Cairo',
        'As Suways' => 'Africa/Cairo',
        'Aswan' => 'Africa/Cairo',
        'Asyut' => 'Africa/Cairo',
        'Bani Suwayf' => 'Africa/Cairo',
        "Bur Sa'id" => 'Africa/Cairo',
        'Dumyat' => 'Africa/Cairo',
        'Kafr ash Shaykh' => 'Africa/Cairo',
        'Matruh' => 'Africa/Cairo',
        'Qina' => 'Africa/Cairo',
        'Suhaj' => 'Africa/Cairo',
        "Janub Sina'" => 'Africa/Cairo',
        "Shamal Sina'" => 'Africa/Cairo',
        'Al Uqsur' => 'Africa/Cairo',
      ],
      'ER' => [
        'Anseba' => 'Africa/Asmara',
        'Debub' => 'Africa/Asmara',
        "Debubawi K'eyih Bahri" => 'Africa/Asmara',
        'Gash Barka' => 'Africa/Asmara',
        "Ma'akel" => 'Africa/Asmara',
        "Semenawi K'eyih Bahri" => 'Africa/Asmara',
      ],
      'ES' => [
        'Islas Baleares' => 'Europe/Madrid',
        'La Rioja' => 'Europe/Madrid',
        'Madrid' => 'Europe/Madrid',
        'Murcia' => 'Europe/Madrid',
        'Navarra' => 'Europe/Madrid',
        'Asturias' => 'Europe/Madrid',
        'Cantabria' => 'Europe/Madrid',
        'Andalucia' => 'Africa/Ceuta',
        'Aragon' => 'Europe/Madrid',
        'Canarias' => 'Atlantic/Canary',
        'Castilla-La Mancha' => 'Europe/Madrid',
        'Castilla y Leon' => 'Europe/Madrid',
        'Catalonia' => 'Europe/Madrid',
        'Extremadura' => 'Europe/Madrid',
        'Galicia' => 'Europe/Madrid',
        'Pais Vasco' => 'Europe/Madrid',
        'Comunidad Valenciana' => 'Europe/Madrid',
      ],
      'ET' => [
        'Adis Abeba' => 'Africa/Addis_Ababa',
        'Afar' => 'Africa/Addis_Ababa',
        'Amara' => 'Africa/Addis_Ababa',
        'Binshangul Gumuz' => 'Africa/Addis_Ababa',
        'Dire Dawa' => 'Africa/Addis_Ababa',
        'Gambela Hizboch' => 'Africa/Addis_Ababa',
        'Hareri Hizb' => 'Africa/Addis_Ababa',
        'Oromiya' => 'Africa/Addis_Ababa',
        'Sumale' => 'Africa/Addis_Ababa',
        'Tigray' => 'Africa/Addis_Ababa',
        'YeDebub Biheroch Bihereseboch na Hizboch' => 'Africa/Addis_Ababa',
      ],
      'FI' => [
        'Aland' => 'Europe/Helsinki',
        'Lapland' => 'Europe/Helsinki',
        'Oulu' => 'Europe/Helsinki',
        'Southern Finland' => 'Europe/Helsinki',
        'Eastern Finland' => 'Europe/Helsinki',
        'Western Finland' => 'Europe/Helsinki',
      ],
      'FJ' => [
        'Central' => 'Pacific/Fiji',
        'Eastern' => 'Pacific/Fiji',
        'Northern' => 'Pacific/Fiji',
        'Rotuma' => 'Pacific/Fiji',
        'Western' => 'Pacific/Fiji',
      ],
      'FM' => [
        'Kosrae' => 'Pacific/Pohnpei',
        'Pohnpei' => 'Pacific/Pohnpei',
        'Chuuk' => 'Pacific/Pohnpei',
        'Yap' => 'Pacific/Pohnpei',
      ],
      'FR' => [
        'Aquitaine' => 'Europe/Paris',
        'Auvergne' => 'Europe/Paris',
        'Basse-Normandie' => 'Europe/Paris',
        'Bourgogne' => 'Europe/Paris',
        'Bretagne' => 'Europe/Paris',
        'Centre' => 'Europe/Paris',
        'Champagne-Ardenne' => 'Europe/Paris',
        'Corse' => 'Europe/Paris',
        'Franche-Comte' => 'Europe/Paris',
        'Haute-Normandie' => 'Europe/Paris',
        'Ile-de-France' => 'Europe/Paris',
        'Languedoc-Roussillon' => 'Europe/Paris',
        'Limousin' => 'Europe/Paris',
        'Lorraine' => 'Europe/Paris',
        'Midi-Pyrenees' => 'Europe/Paris',
        'Nord-Pas-de-Calais' => 'Europe/Paris',
        'Pays de la Loire' => 'Europe/Paris',
        'Picardie' => 'Europe/Paris',
        'Poitou-Charentes' => 'Europe/Paris',
        "Provence-Alpes-Cote d'Azur" => 'Europe/Paris',
        'Rhone-Alpes' => 'Europe/Paris',
        'Alsace' => 'Europe/Paris',
      ],
      'GA' => [
        'Estuaire' => 'Africa/Libreville',
        'Haut-Ogooue' => 'Africa/Libreville',
        'Moyen-Ogooue' => 'Africa/Libreville',
        'Ngounie' => 'Africa/Libreville',
        'Nyanga' => 'Africa/Libreville',
        'Ogooue-Ivindo' => 'Africa/Libreville',
        'Ogooue-Lolo' => 'Africa/Libreville',
        'Ogooue-Maritime' => 'Africa/Libreville',
        'Woleu-Ntem' => 'Africa/Libreville',
      ],
      'GB' => [
        'Barking and Dagenham' => 'Europe/London',
        'Barnet' => 'Europe/London',
        'Barnsley' => 'Europe/London',
        'Bath and North East Somerset' => 'Europe/London',
        'Bedfordshire' => 'Europe/London',
        'Bexley' => 'Europe/London',
        'Birmingham' => 'Europe/London',
        'Blackburn with Darwen' => 'Europe/London',
        'Blackpool' => 'Europe/London',
        'Bolton' => 'Europe/London',
        'Bournemouth' => 'Europe/London',
        'Bracknell Forest' => 'Europe/London',
        'Bradford' => 'Europe/London',
        'Brent' => 'Europe/London',
        'Brighton and Hove' => 'Europe/London',
        'Bristol, City of' => 'Europe/London',
        'Bromley' => 'Europe/London',
        'Buckinghamshire' => 'Europe/London',
        'Bury' => 'Europe/London',
        'Calderdale' => 'Europe/London',
        'Cambridgeshire' => 'Europe/London',
        'Camden' => 'Europe/London',
        'Cheshire' => 'Europe/London',
        'Cornwall' => 'Europe/London',
        'Coventry' => 'Europe/London',
        'Croydon' => 'Europe/London',
        'Cumbria' => 'Europe/London',
        'Darlington' => 'Europe/London',
        'Derby' => 'Europe/London',
        'Derbyshire' => 'Europe/London',
        'Devon' => 'Europe/London',
        'Doncaster' => 'Europe/London',
        'Dorset' => 'Europe/London',
        'Dudley' => 'Europe/London',
        'Durham' => 'Europe/London',
        'Ealing' => 'Europe/London',
        'East Riding of Yorkshire' => 'Europe/London',
        'East Sussex' => 'Europe/London',
        'Enfield' => 'Europe/London',
        'Essex' => 'Europe/London',
        'Gateshead' => 'Europe/London',
        'Gloucestershire' => 'Europe/London',
        'Greenwich' => 'Europe/London',
        'Hackney' => 'Europe/London',
        'Halton' => 'Europe/London',
        'Hammersmith and Fulham' => 'Europe/London',
        'Hampshire' => 'Europe/London',
        'Haringey' => 'Europe/London',
        'Harrow' => 'Europe/London',
        'Hartlepool' => 'Europe/London',
        'Havering' => 'Europe/London',
        'Herefordshire' => 'Europe/London',
        'Hertford' => 'Europe/London',
        'Hillingdon' => 'Europe/London',
        'Hounslow' => 'Europe/London',
        'Isle of Wight' => 'Europe/London',
        'Islington' => 'Europe/London',
        'Kensington and Chelsea' => 'Europe/London',
        'Kent' => 'Europe/London',
        'Kingston upon Hull, City of' => 'Europe/London',
        'Kingston upon Thames' => 'Europe/London',
        'Kirklees' => 'Europe/London',
        'Knowsley' => 'Europe/London',
        'Lambeth' => 'Europe/London',
        'Lancashire' => 'Europe/London',
        'Leeds' => 'Europe/London',
        'Leicester' => 'Europe/London',
        'Leicestershire' => 'Europe/London',
        'Lewisham' => 'Europe/London',
        'Lincolnshire' => 'Europe/London',
        'Liverpool' => 'Europe/London',
        'London, City of' => 'Europe/London',
        'Luton' => 'Europe/London',
        'Manchester' => 'Europe/London',
        'Medway' => 'Europe/London',
        'Merton' => 'Europe/London',
        'Middlesbrough' => 'Europe/London',
        'Milton Keynes' => 'Europe/London',
        'Newcastle upon Tyne' => 'Europe/London',
        'Newham' => 'Europe/London',
        'Norfolk' => 'Europe/London',
        'Northamptonshire' => 'Europe/London',
        'North East Lincolnshire' => 'Europe/London',
        'North Lincolnshire' => 'Europe/London',
        'North Somerset' => 'Europe/London',
        'North Tyneside' => 'Europe/London',
        'Northumberland' => 'Europe/London',
        'North Yorkshire' => 'Europe/London',
        'Nottingham' => 'Europe/London',
        'Nottinghamshire' => 'Europe/London',
        'Oldham' => 'Europe/London',
        'Oxfordshire' => 'Europe/London',
        'Peterborough' => 'Europe/London',
        'Plymouth' => 'Europe/London',
        'Poole' => 'Europe/London',
        'Portsmouth' => 'Europe/London',
        'Reading' => 'Europe/London',
        'Redbridge' => 'Europe/London',
        'Redcar and Cleveland' => 'Europe/London',
        'Richmond upon Thames' => 'Europe/London',
        'Rochdale' => 'Europe/London',
        'Rotherham' => 'Europe/London',
        'Rutland' => 'Europe/London',
        'Salford' => 'Europe/London',
        'Shropshire' => 'Europe/London',
        'Sandwell' => 'Europe/London',
        'Sefton' => 'Europe/London',
        'Sheffield' => 'Europe/London',
        'Slough' => 'Europe/London',
        'Solihull' => 'Europe/London',
        'Somerset' => 'Europe/London',
        'Southampton' => 'Europe/London',
        'Southend-on-Sea' => 'Europe/London',
        'South Gloucestershire' => 'Europe/London',
        'South Tyneside' => 'Europe/London',
        'Southwark' => 'Europe/London',
        'Staffordshire' => 'Europe/London',
        'St. Helens' => 'Europe/London',
        'Stockport' => 'Europe/London',
        'Stockton-on-Tees' => 'Europe/London',
        'Stoke-on-Trent' => 'Europe/London',
        'Suffolk' => 'Europe/London',
        'Sunderland' => 'Europe/London',
        'Surrey' => 'Europe/London',
        'Sutton' => 'Europe/London',
        'Swindon' => 'Europe/London',
        'Tameside' => 'Europe/London',
        'Telford and Wrekin' => 'Europe/London',
        'Thurrock' => 'Europe/London',
        'Torbay' => 'Europe/London',
        'Tower Hamlets' => 'Europe/London',
        'Trafford' => 'Europe/London',
        'Wakefield' => 'Europe/London',
        'Walsall' => 'Europe/London',
        'Waltham Forest' => 'Europe/London',
        'Wandsworth' => 'Europe/London',
        'Warrington' => 'Europe/London',
        'Warwickshire' => 'Europe/London',
        'West Berkshire' => 'Europe/London',
        'Westminster' => 'Europe/London',
        'West Sussex' => 'Europe/London',
        'Wigan' => 'Europe/London',
        'Wiltshire' => 'Europe/London',
        'Windsor and Maidenhead' => 'Europe/London',
        'Wirral' => 'Europe/London',
        'Wokingham' => 'Europe/London',
        'Wolverhampton' => 'Europe/London',
        'Worcestershire' => 'Europe/London',
        'York' => 'Europe/London',
        'Antrim' => 'Europe/London',
        'Ards' => 'Europe/London',
        'Armagh' => 'Europe/London',
        'Ballymena' => 'Europe/London',
        'Ballymoney' => 'Europe/London',
        'Banbridge' => 'Europe/London',
        'Belfast' => 'Europe/London',
        'Carrickfergus' => 'Europe/London',
        'Castlereagh' => 'Europe/London',
        'Coleraine' => 'Europe/London',
        'Cookstown' => 'Europe/London',
        'Craigavon' => 'Europe/London',
        'Down' => 'Europe/London',
        'Dungannon' => 'Europe/London',
        'Fermanagh' => 'Europe/London',
        'Larne' => 'Europe/London',
        'Limavady' => 'Europe/London',
        'Lisburn' => 'Europe/London',
        'Derry' => 'Europe/London',
        'Magherafelt' => 'Europe/London',
        'Moyle' => 'Europe/London',
        'Newry and Mourne' => 'Europe/London',
        'Newtownabbey' => 'Europe/London',
        'North Down' => 'Europe/London',
        'Omagh' => 'Europe/London',
        'Strabane' => 'Europe/London',
        'Aberdeen City' => 'Europe/London',
        'Aberdeenshire' => 'Europe/London',
        'Angus' => 'Europe/London',
        'Argyll and Bute' => 'Europe/London',
        'Scottish Borders, The' => 'Europe/London',
        'Clackmannanshire' => 'Europe/London',
        'Dumfries and Galloway' => 'Europe/London',
        'Dundee City' => 'Europe/London',
        'East Ayrshire' => 'Europe/London',
        'East Dunbartonshire' => 'Europe/London',
        'East Lothian' => 'Europe/London',
        'East Renfrewshire' => 'Europe/London',
        'Edinburgh, City of' => 'Europe/London',
        'Falkirk' => 'Europe/London',
        'Fife' => 'Europe/London',
        'Glasgow City' => 'Europe/London',
        'Highland' => 'Europe/London',
        'Inverclyde' => 'Europe/London',
        'Midlothian' => 'Europe/London',
        'Moray' => 'Europe/London',
        'North Ayrshire' => 'Europe/London',
        'North Lanarkshire' => 'Europe/London',
        'Orkney' => 'Europe/London',
        'Perth and Kinross' => 'Europe/London',
        'Renfrewshire' => 'Europe/London',
        'Shetland Islands' => 'Europe/London',
        'South Ayrshire' => 'Europe/London',
        'South Lanarkshire' => 'Europe/London',
        'Stirling' => 'Europe/London',
        'West Dunbartonshire' => 'Europe/London',
        'Eilean Siar' => 'Europe/London',
        'West Lothian' => 'Europe/London',
        'Isle of Anglesey' => 'Europe/London',
        'Blaenau Gwent' => 'Europe/London',
        'Bridgend' => 'Europe/London',
        'Caerphilly' => 'Europe/London',
        'Cardiff' => 'Europe/London',
        'Ceredigion' => 'Europe/London',
        'Carmarthenshire' => 'Europe/London',
        'Conwy' => 'Europe/London',
        'Denbighshire' => 'Europe/London',
        'Flintshire' => 'Europe/London',
        'Gwynedd' => 'Europe/London',
        'Merthyr Tydfil' => 'Europe/London',
        'Monmouthshire' => 'Europe/London',
        'Neath Port Talbot' => 'Europe/London',
        'Newport' => 'Europe/London',
        'Pembrokeshire' => 'Europe/London',
        'Powys' => 'Europe/London',
        'Rhondda Cynon Taff' => 'Europe/London',
        'Swansea' => 'Europe/London',
        'Torfaen' => 'Europe/London',
        'Vale of Glamorgan, The' => 'Europe/London',
        'Wrexham' => 'Europe/London',
        'Central Bedfordshire' => 'Europe/London',
        'Cheshire East' => 'Europe/London',
        'Cheshire West and Chester' => 'Europe/London',
        'Isles of Scilly' => 'Europe/London',
      ],
      'GD' => [
        'Saint Andrew' => 'America/Grenada',
        'Saint David' => 'America/Grenada',
        'Saint George' => 'America/Grenada',
        'Saint John' => 'America/Grenada',
        'Saint Mark' => 'America/Grenada',
        'Saint Patrick' => 'America/Grenada',
      ],
      'GE' => [
        'Abashis Raioni' => 'Asia/Tbilisi',
        'Abkhazia' => 'Asia/Tbilisi',
        'Adigenis Raioni' => 'Asia/Tbilisi',
        'Ajaria' => 'Asia/Tbilisi',
        'Akhalgoris Raioni' => 'Asia/Tbilisi',
        "Akhalk'alak'is Raioni" => 'Asia/Tbilisi',
        "Akhalts'ikhis Raioni" => 'Asia/Tbilisi',
        'Akhmetis Raioni' => 'Asia/Tbilisi',
        'Ambrolauris Raioni' => 'Asia/Tbilisi',
        'Aspindzis Raioni' => 'Asia/Tbilisi',
        "Baghdat'is Raioni" => 'Asia/Tbilisi',
        'Bolnisis Raioni' => 'Asia/Tbilisi',
        'Borjomis Raioni' => 'Asia/Tbilisi',
        "Chiat'ura" => 'Asia/Tbilisi',
        "Ch'khorotsqus Raioni" => 'Asia/Tbilisi',
        "Ch'okhatauris Raioni" => 'Asia/Tbilisi',
        "Dedop'listsqaros Raioni" => 'Asia/Tbilisi',
        'Dmanisis Raioni' => 'Asia/Tbilisi',
        "Dushet'is Raioni" => 'Asia/Tbilisi',
        'Gardabanis Raioni' => 'Asia/Tbilisi',
        'Gori' => 'Asia/Tbilisi',
        'Goris Raioni' => 'Asia/Tbilisi',
        'Gurjaanis Raioni' => 'Asia/Tbilisi',
        'Javis Raioni' => 'Asia/Tbilisi',
        "K'arelis Raioni" => 'Asia/Tbilisi',
        'Kaspis Raioni' => 'Asia/Tbilisi',
        'Kharagaulis Raioni' => 'Asia/Tbilisi',
        'Khashuris Raioni' => 'Asia/Tbilisi',
        'Khobis Raioni' => 'Asia/Tbilisi',
        'Khonis Raioni' => 'Asia/Tbilisi',
        "K'ut'aisi" => 'Asia/Tbilisi',
        'Lagodekhis Raioni' => 'Asia/Tbilisi',
        "Lanch'khut'is Raioni" => 'Asia/Tbilisi',
        'Lentekhis Raioni' => 'Asia/Tbilisi',
        'Marneulis Raioni' => 'Asia/Tbilisi',
        'Martvilis Raioni' => 'Asia/Tbilisi',
        'Mestiis Raioni' => 'Asia/Tbilisi',
        "Mts'khet'is Raioni" => 'Asia/Tbilisi',
        'Ninotsmindis Raioni' => 'Asia/Tbilisi',
        'Onis Raioni' => 'Asia/Tbilisi',
        "Ozurget'is Raioni" => 'Asia/Tbilisi',
        "P'ot'i" => 'Asia/Tbilisi',
        'Qazbegis Raioni' => 'Asia/Tbilisi',
        'Qvarlis Raioni' => 'Asia/Tbilisi',
        "Rust'avi" => 'Asia/Tbilisi',
        "Sach'kheris Raioni" => 'Asia/Tbilisi',
        'Sagarejos Raioni' => 'Asia/Tbilisi',
        'Samtrediis Raioni' => 'Asia/Tbilisi',
        'Senakis Raioni' => 'Asia/Tbilisi',
        'Sighnaghis Raioni' => 'Asia/Tbilisi',
        "T'bilisi" => 'Asia/Tbilisi',
        "T'elavis Raioni" => 'Asia/Tbilisi',
        "T'erjolis Raioni" => 'Asia/Tbilisi',
        "T'et'ritsqaros Raioni" => 'Asia/Tbilisi',
        "T'ianet'is Raioni" => 'Asia/Tbilisi',
        'Tqibuli' => 'Asia/Tbilisi',
        "Ts'ageris Raioni" => 'Asia/Tbilisi',
        'Tsalenjikhis Raioni' => 'Asia/Tbilisi',
        'Tsalkis Raioni' => 'Asia/Tbilisi',
        'Tsqaltubo' => 'Asia/Tbilisi',
        'Vanis Raioni' => 'Asia/Tbilisi',
        "Zestap'onis Raioni" => 'Asia/Tbilisi',
        'Zugdidi' => 'Asia/Tbilisi',
        'Zugdidis Raioni' => 'Asia/Tbilisi',
      ],
      'GH' => [
        'Greater Accra' => 'Africa/Accra',
        'Ashanti' => 'Africa/Accra',
        'Brong-Ahafo' => 'Africa/Accra',
        'Central' => 'Africa/Accra',
        'Eastern' => 'Africa/Accra',
        'Northern' => 'Africa/Accra',
        'Volta' => 'Africa/Accra',
        'Western' => 'Africa/Accra',
        'Upper East' => 'Africa/Accra',
        'Upper West' => 'Africa/Accra',
      ],
      'GL' => [
        'Nordgronland' => 'America/Thule',
        'Ostgronland' => 'America/Godthab',
        'Vestgronland' => 'America/Godthab',
      ],
      'GM' => [
        'Banjul' => 'Africa/Banjul',
        'Lower River' => 'Africa/Banjul',
        'Central River' => 'Africa/Banjul',
        'Upper River' => 'Africa/Banjul',
        'Western' => 'Africa/Banjul',
        'North Bank' => 'Africa/Banjul',
      ],
      'GN' => [
        'Beyla' => 'Africa/Conakry',
        'Boffa' => 'Africa/Conakry',
        'Boke' => 'Africa/Conakry',
        'Conakry' => 'Africa/Conakry',
        'Dabola' => 'Africa/Conakry',
        'Dalaba' => 'Africa/Conakry',
        'Dinguiraye' => 'Africa/Conakry',
        'Faranah' => 'Africa/Conakry',
        'Forecariah' => 'Africa/Conakry',
        'Fria' => 'Africa/Conakry',
        'Gaoual' => 'Africa/Conakry',
        'Gueckedou' => 'Africa/Conakry',
        'Kerouane' => 'Africa/Conakry',
        'Kindia' => 'Africa/Conakry',
        'Kissidougou' => 'Africa/Conakry',
        'Koundara' => 'Africa/Conakry',
        'Kouroussa' => 'Africa/Conakry',
        'Macenta' => 'Africa/Conakry',
        'Mali' => 'Africa/Conakry',
        'Mamou' => 'Africa/Conakry',
        'Pita' => 'Africa/Conakry',
        'Telimele' => 'Africa/Conakry',
        'Tougue' => 'Africa/Conakry',
        'Yomou' => 'Africa/Conakry',
        'Coyah' => 'Africa/Conakry',
        'Dubreka' => 'Africa/Conakry',
        'Kankan' => 'Africa/Conakry',
        'Koubia' => 'Africa/Conakry',
        'Labe' => 'Africa/Conakry',
        'Lelouma' => 'Africa/Conakry',
        'Lola' => 'Africa/Conakry',
        'Mandiana' => 'Africa/Conakry',
        'Nzerekore' => 'Africa/Conakry',
        'Siguiri' => 'Africa/Conakry',
      ],
      'GQ' => [
        'Annobon' => 'Africa/Malabo',
        'Bioko Norte' => 'Africa/Malabo',
        'Bioko Sur' => 'Africa/Malabo',
        'Centro Sur' => 'Africa/Malabo',
        'Kie-Ntem' => 'Africa/Malabo',
        'Litoral' => 'Africa/Malabo',
        'Wele-Nzas' => 'Africa/Malabo',
      ],
      'GR' => [
        'Evros' => 'Europe/Athens',
        'Rodhopi' => 'Europe/Athens',
        'Xanthi' => 'Europe/Athens',
        'Drama' => 'Europe/Athens',
        'Serrai' => 'Europe/Athens',
        'Kilkis' => 'Europe/Athens',
        'Pella' => 'Europe/Athens',
        'Florina' => 'Europe/Athens',
        'Kastoria' => 'Europe/Athens',
        'Grevena' => 'Europe/Athens',
        'Kozani' => 'Europe/Athens',
        'Imathia' => 'Europe/Athens',
        'Thessaloniki' => 'Europe/Athens',
        'Kavala' => 'Europe/Athens',
        'Khalkidhiki' => 'Europe/Athens',
        'Pieria' => 'Europe/Athens',
        'Ioannina' => 'Europe/Athens',
        'Thesprotia' => 'Europe/Athens',
        'Preveza' => 'Europe/Athens',
        'Arta' => 'Europe/Athens',
        'Larisa' => 'Europe/Athens',
        'Trikala' => 'Europe/Athens',
        'Kardhitsa' => 'Europe/Athens',
        'Magnisia' => 'Europe/Athens',
        'Kerkira' => 'Europe/Athens',
        'Levkas' => 'Europe/Athens',
        'Kefallinia' => 'Europe/Athens',
        'Zakinthos' => 'Europe/Athens',
        'Fthiotis' => 'Europe/Athens',
        'Evritania' => 'Europe/Athens',
        'Aitolia kai Akarnania' => 'Europe/Athens',
        'Fokis' => 'Europe/Athens',
        'Voiotia' => 'Europe/Athens',
        'Evvoia' => 'Europe/Athens',
        'Attiki' => 'Europe/Athens',
        'Argolis' => 'Europe/Athens',
        'Korinthia' => 'Europe/Athens',
        'Akhaia' => 'Europe/Athens',
        'Ilia' => 'Europe/Athens',
        'Messinia' => 'Europe/Athens',
        'Arkadhia' => 'Europe/Athens',
        'Lakonia' => 'Europe/Athens',
        'Khania' => 'Europe/Athens',
        'Rethimni' => 'Europe/Athens',
        'Iraklion' => 'Europe/Athens',
        'Lasithi' => 'Europe/Athens',
        'Dhodhekanisos' => 'Europe/Athens',
        'Samos' => 'Europe/Athens',
        'Kikladhes' => 'Europe/Athens',
        'Khios' => 'Europe/Athens',
        'Lesvos' => 'Europe/Athens',
      ],
      'GT' => [
        'Alta Verapaz' => 'America/Guatemala',
        'Baja Verapaz' => 'America/Guatemala',
        'Chimaltenango' => 'America/Guatemala',
        'Chiquimula' => 'America/Guatemala',
        'El Progreso' => 'America/Guatemala',
        'Escuintla' => 'America/Guatemala',
        'Guatemala' => 'America/Guatemala',
        'Huehuetenango' => 'America/Guatemala',
        'Izabal' => 'America/Guatemala',
        'Jalapa' => 'America/Guatemala',
        'Jutiapa' => 'America/Guatemala',
        'Peten' => 'America/Guatemala',
        'Quetzaltenango' => 'America/Guatemala',
        'Quiche' => 'America/Guatemala',
        'Retalhuleu' => 'America/Guatemala',
        'Sacatepequez' => 'America/Guatemala',
        'San Marcos' => 'America/Guatemala',
        'Santa Rosa' => 'America/Guatemala',
        'Solola' => 'America/Guatemala',
        'Suchitepequez' => 'America/Guatemala',
        'Totonicapan' => 'America/Guatemala',
        'Zacapa' => 'America/Guatemala',
      ],
      'GW' => [
        'Bafata' => 'Africa/Bissau',
        'Quinara' => 'Africa/Bissau',
        'Oio' => 'Africa/Bissau',
        'Bolama' => 'Africa/Bissau',
        'Cacheu' => 'Africa/Bissau',
        'Tombali' => 'Africa/Bissau',
        'Gabu' => 'Africa/Bissau',
        'Bissau' => 'Africa/Bissau',
        'Biombo' => 'Africa/Bissau',
      ],
      'GY' => [
        'Barima-Waini' => 'America/Guyana',
        'Cuyuni-Mazaruni' => 'America/Guyana',
        'Demerara-Mahaica' => 'America/Guyana',
        'East Berbice-Corentyne' => 'America/Guyana',
        'Essequibo Islands-West Demerara' => 'America/Guyana',
        'Mahaica-Berbice' => 'America/Guyana',
        'Pomeroon-Supenaam' => 'America/Guyana',
        'Potaro-Siparuni' => 'America/Guyana',
        'Upper Demerara-Berbice' => 'America/Guyana',
        'Upper Takutu-Upper Essequibo' => 'America/Guyana',
      ],
      'HN' => [
        'Atlantida' => 'America/Tegucigalpa',
        'Choluteca' => 'America/Tegucigalpa',
        'Colon' => 'America/Tegucigalpa',
        'Comayagua' => 'America/Tegucigalpa',
        'Copan' => 'America/Tegucigalpa',
        'Cortes' => 'America/Tegucigalpa',
        'El Paraiso' => 'America/Tegucigalpa',
        'Francisco Morazan' => 'America/Tegucigalpa',
        'Gracias a Dios' => 'America/Tegucigalpa',
        'Intibuca' => 'America/Tegucigalpa',
        'Islas de la Bahia' => 'America/Tegucigalpa',
        'La Paz' => 'America/Tegucigalpa',
        'Lempira' => 'America/Tegucigalpa',
        'Ocotepeque' => 'America/Tegucigalpa',
        'Olancho' => 'America/Tegucigalpa',
        'Santa Barbara' => 'America/Tegucigalpa',
        'Valle' => 'America/Tegucigalpa',
        'Yoro' => 'America/Tegucigalpa',
      ],
      'HR' => [
        'Bjelovarsko-Bilogorska' => 'Europe/Zagreb',
        'Brodsko-Posavska' => 'Europe/Zagreb',
        'Dubrovacko-Neretvanska' => 'Europe/Zagreb',
        'Istarska' => 'Europe/Zagreb',
        'Karlovacka' => 'Europe/Zagreb',
        'Koprivnicko-Krizevacka' => 'Europe/Zagreb',
        'Krapinsko-Zagorska' => 'Europe/Zagreb',
        'Licko-Senjska' => 'Europe/Zagreb',
        'Medimurska' => 'Europe/Zagreb',
        'Osjecko-Baranjska' => 'Europe/Zagreb',
        'Pozesko-Slavonska' => 'Europe/Zagreb',
        'Primorsko-Goranska' => 'Europe/Zagreb',
        'Sibensko-Kninska' => 'Europe/Zagreb',
        'Sisacko-Moslavacka' => 'Europe/Zagreb',
        'Splitsko-Dalmatinska' => 'Europe/Zagreb',
        'Varazdinska' => 'Europe/Zagreb',
        'Viroviticko-Podravska' => 'Europe/Zagreb',
        'Vukovarsko-Srijemska' => 'Europe/Zagreb',
        'Zadarska' => 'Europe/Zagreb',
        'Zagrebacka' => 'Europe/Zagreb',
        'Grad Zagreb' => 'Europe/Zagreb',
      ],
      'HT' => [
        'Nord-Ouest' => 'America/Port-au-Prince',
        'Artibonite' => 'America/Port-au-Prince',
        'Centre' => 'America/Port-au-Prince',
        'Nord' => 'America/Port-au-Prince',
        'Nord-Est' => 'America/Port-au-Prince',
        'Ouest' => 'America/Port-au-Prince',
        'Sud' => 'America/Port-au-Prince',
        'Sud-Est' => 'America/Port-au-Prince',
        "Grand' Anse" => 'America/Port-au-Prince',
        'Nippes' => 'America/Port-au-Prince',
      ],
      'HU' => [
        'Bacs-Kiskun' => 'Europe/Budapest',
        'Baranya' => 'Europe/Budapest',
        'Bekes' => 'Europe/Budapest',
        'Borsod-Abauj-Zemplen' => 'Europe/Budapest',
        'Budapest' => 'Europe/Budapest',
        'Csongrad' => 'Europe/Budapest',
        'Debrecen' => 'Europe/Budapest',
        'Fejer' => 'Europe/Budapest',
        'Gyor-Moson-Sopron' => 'Europe/Budapest',
        'Hajdu-Bihar' => 'Europe/Budapest',
        'Heves' => 'Europe/Budapest',
        'Komarom-Esztergom' => 'Europe/Budapest',
        'Miskolc' => 'Europe/Budapest',
        'Nograd' => 'Europe/Budapest',
        'Pecs' => 'Europe/Budapest',
        'Pest' => 'Europe/Budapest',
        'Somogy' => 'Europe/Budapest',
        'Szabolcs-Szatmar-Bereg' => 'Europe/Budapest',
        'Szeged' => 'Europe/Budapest',
        'Jasz-Nagykun-Szolnok' => 'Europe/Budapest',
        'Tolna' => 'Europe/Budapest',
        'Vas' => 'Europe/Budapest',
        'Veszprem' => 'Europe/Budapest',
        'Zala' => 'Europe/Budapest',
        'Gyor' => 'Europe/Budapest',
        'Bekescsaba' => 'Europe/Budapest',
        'Dunaujvaros' => 'Europe/Budapest',
        'Eger' => 'Europe/Budapest',
        'Hodmezovasarhely' => 'Europe/Budapest',
        'Kaposvar' => 'Europe/Budapest',
        'Kecskemet' => 'Europe/Budapest',
        'Nagykanizsa' => 'Europe/Budapest',
        'Nyiregyhaza' => 'Europe/Budapest',
        'Sopron' => 'Europe/Budapest',
        'Szekesfehervar' => 'Europe/Budapest',
        'Szolnok' => 'Europe/Budapest',
        'Szombathely' => 'Europe/Budapest',
        'Tatabanya' => 'Europe/Budapest',
        'Zalaegerszeg' => 'Europe/Budapest',
        'Salgotarjan' => 'Europe/Budapest',
        'Szekszard' => 'Europe/Budapest',
        'Erd' => 'Europe/Budapest',
      ],
      'ID' => [
        'Aceh' => 'Asia/Pontianak',
        'Bali' => 'Asia/Makassar',
        'Bengkulu' => 'Asia/Jakarta',
        'Jakarta Raya' => 'Asia/Jakarta',
        'Jambi' => 'Asia/Jakarta',
        'Jawa Tengah' => 'Asia/Jakarta',
        'Jawa Timur' => 'Asia/Jakarta',
        'Yogyakarta' => 'Asia/Jakarta',
        'Kalimantan Barat' => 'Asia/Pontianak',
        'Kalimantan Selatan' => 'Asia/Makassar',
        'Kalimantan Tengah' => 'Asia/Makassar',
        'Kalimantan Timur' => 'Asia/Makassar',
        'Lampung' => 'Asia/Jakarta',
        'Nusa Tenggara Barat' => 'Asia/Makassar',
        'Nusa Tenggara Timur' => 'Asia/Makassar',
        'Sulawesi Tengah' => 'Asia/Makassar',
        'Sulawesi Tenggara' => 'Asia/Makassar',
        'Sumatera Barat' => 'Asia/Jakarta',
        'Sumatera Utara' => 'Asia/Pontianak',
        'Maluku' => 'Asia/Jayapura',
        'Maluku Utara' => 'Asia/Makassar',
        'Jawa Barat' => 'Asia/Jakarta',
        'Sulawesi Utara' => 'Asia/Makassar',
        'Sumatera Selatan' => 'Asia/Jakarta',
        'Banten' => 'Asia/Jakarta',
        'Gorontalo' => 'Asia/Makassar',
        'Kepulauan Bangka Belitung' => 'Asia/Pontianak',
        'Papua' => 'Asia/Jayapura',
        'Riau' => 'Asia/Pontianak',
        'Sulawesi Selatan' => 'Asia/Makassar',
        'Irian Jaya Barat' => 'Asia/Jayapura',
        'Kepulauan Riau' => 'Asia/Pontianak',
        'Sulawesi Barat' => 'Asia/Makassar',
      ],
      'IE' => [
        'Carlow' => 'Europe/Dublin',
        'Cavan' => 'Europe/Dublin',
        'Clare' => 'Europe/Dublin',
        'Cork' => 'Europe/Dublin',
        'Donegal' => 'Europe/Dublin',
        'Dublin' => 'Europe/Dublin',
        'Galway' => 'Europe/Dublin',
        'Kerry' => 'Europe/Dublin',
        'Kildare' => 'Europe/Dublin',
        'Kilkenny' => 'Europe/Dublin',
        'Leitrim' => 'Europe/Dublin',
        'Laois' => 'Europe/Dublin',
        'Limerick' => 'Europe/Dublin',
        'Longford' => 'Europe/Dublin',
        'Louth' => 'Europe/Dublin',
        'Mayo' => 'Europe/Dublin',
        'Meath' => 'Europe/Dublin',
        'Monaghan' => 'Europe/Dublin',
        'Offaly' => 'Europe/Dublin',
        'Roscommon' => 'Europe/Dublin',
        'Sligo' => 'Europe/Dublin',
        'Tipperary' => 'Europe/Dublin',
        'Waterford' => 'Europe/Dublin',
        'Westmeath' => 'Europe/Dublin',
        'Wexford' => 'Europe/Dublin',
        'Wicklow' => 'Europe/Dublin',
      ],
      'IL' => [
        'HaDarom' => 'Asia/Jerusalem',
        'HaMerkaz' => 'Asia/Jerusalem',
        'HaZafon' => 'Asia/Jerusalem',
        'Hefa' => 'Asia/Jerusalem',
        'Tel Aviv' => 'Asia/Jerusalem',
        'Yerushalayim' => 'Asia/Jerusalem',
      ],
      'IN' => [
        'Andaman and Nicobar Islands' => 'Asia/Kolkata',
        'Andhra Pradesh' => 'Asia/Kolkata',
        'Assam' => 'Asia/Kolkata',
        'Chandigarh' => 'Asia/Kolkata',
        'Dadra and Nagar Haveli' => 'Asia/Kolkata',
        'Delhi' => 'Asia/Kolkata',
        'Gujarat' => 'Asia/Kolkata',
        'Haryana' => 'Asia/Kolkata',
        'Himachal Pradesh' => 'Asia/Kolkata',
        'Jammu and Kashmir' => 'Asia/Kolkata',
        'Kerala' => 'Asia/Kolkata',
        'Lakshadweep' => 'Asia/Kolkata',
        'Maharashtra' => 'Asia/Kolkata',
        'Manipur' => 'Asia/Kolkata',
        'Meghalaya' => 'Asia/Kolkata',
        'Karnataka' => 'Asia/Kolkata',
        'Nagaland' => 'Asia/Kolkata',
        'Orissa' => 'Asia/Kolkata',
        'Puducherry' => 'Asia/Kolkata',
        'Punjab' => 'Asia/Kolkata',
        'Rajasthan' => 'Asia/Kolkata',
        'Tamil Nadu' => 'Asia/Kolkata',
        'Tripura' => 'Asia/Kolkata',
        'West Bengal' => 'Asia/Kolkata',
        'Sikkim' => 'Asia/Kolkata',
        'Arunachal Pradesh' => 'Asia/Kolkata',
        'Mizoram' => 'Asia/Kolkata',
        'Daman and Diu' => 'Asia/Kolkata',
        'Goa' => 'Asia/Kolkata',
        'Bihar' => 'Asia/Kolkata',
        'Madhya Pradesh' => 'Asia/Kolkata',
        'Uttar Pradesh' => 'Asia/Kolkata',
        'Chhattisgarh' => 'Asia/Kolkata',
        'Jharkhand' => 'Asia/Kolkata',
        'Uttarakhand' => 'Asia/Kolkata',
      ],
      'IQ' => [
        'Al Anbar' => 'Asia/Baghdad',
        'Al Basrah' => 'Asia/Baghdad',
        'Al Muthanna' => 'Asia/Baghdad',
        'Al Qadisiyah' => 'Asia/Baghdad',
        'As Sulaymaniyah' => 'Asia/Baghdad',
        'Babil' => 'Asia/Baghdad',
        'Baghdad' => 'Asia/Baghdad',
        'Dahuk' => 'Asia/Baghdad',
        'Dhi Qar' => 'Asia/Baghdad',
        'Diyala' => 'Asia/Baghdad',
        'Arbil' => 'Asia/Baghdad',
        "Karbala'" => 'Asia/Baghdad',
        "At Ta'mim" => 'Asia/Baghdad',
        'Maysan' => 'Asia/Baghdad',
        'Ninawa' => 'Asia/Baghdad',
        'Wasit' => 'Asia/Baghdad',
        'An Najaf' => 'Asia/Baghdad',
        'Salah ad Din' => 'Asia/Baghdad',
      ],
      'IR' => [
        'Azarbayjan-e Bakhtari' => 'Asia/Tehran',
        'Chahar Mahall va Bakhtiari' => 'Asia/Tehran',
        'Sistan va Baluchestan' => 'Asia/Tehran',
        'Kohkiluyeh va Buyer Ahmadi' => 'Asia/Tehran',
        'Fars' => 'Asia/Tehran',
        'Gilan' => 'Asia/Tehran',
        'Hamadan' => 'Asia/Tehran',
        'Ilam' => 'Asia/Tehran',
        'Hormozgan' => 'Asia/Tehran',
        'Kerman' => 'Asia/Tehran',
        'Bakhtaran' => 'Asia/Tehran',
        'Khuzestan' => 'Asia/Tehran',
        'Kordestan' => 'Asia/Tehran',
        'Mazandaran' => 'Asia/Tehran',
        'Semnan Province' => 'Asia/Tehran',
        'Markazi' => 'Asia/Tehran',
        'Zanjan' => 'Asia/Tehran',
        'Bushehr' => 'Asia/Tehran',
        'Lorestan' => 'Asia/Tehran',
        'Semnan' => 'Asia/Tehran',
        'Tehran' => 'Asia/Tehran',
        'Esfahan' => 'Asia/Tehran',
        'Khorasan' => 'Asia/Tehran',
        'Yazd' => 'Asia/Tehran',
        'Ardabil' => 'Asia/Tehran',
        'East Azarbaijan' => 'Asia/Tehran',
        'Golestan' => 'Asia/Tehran',
        'Qazvin' => 'Asia/Tehran',
        'Qom' => 'Asia/Tehran',
        'Khorasan-e Janubi' => 'Asia/Tehran',
        'Khorasan-e Razavi' => 'Asia/Tehran',
        'Khorasan-e Shemali' => 'Asia/Tehran',
        'Alborz' => 'Asia/Tehran',
      ],
      'IS' => [
        'Arnessysla' => 'Atlantic/Reykjavik',
        'Austur-Hunavatnssysla' => 'Atlantic/Reykjavik',
        'Austur-Skaftafellssysla' => 'Atlantic/Reykjavik',
        'Borgarfjardarsysla' => 'Atlantic/Reykjavik',
        'Eyjafjardarsysla' => 'Atlantic/Reykjavik',
        'Gullbringusysla' => 'Atlantic/Reykjavik',
        'Kjosarsysla' => 'Atlantic/Reykjavik',
        'Myrasysla' => 'Atlantic/Reykjavik',
        'Nordur-Mulasysla' => 'Atlantic/Reykjavik',
        'Nordur-Tingeyjarsysla' => 'Atlantic/Reykjavik',
        'Rangarvallasysla' => 'Atlantic/Reykjavik',
        'Skagafjardarsysla' => 'Atlantic/Reykjavik',
        'Snafellsnes- og Hnappadalssysla' => 'Atlantic/Reykjavik',
        'Strandasysla' => 'Atlantic/Reykjavik',
        'Sudur-Mulasysla' => 'Atlantic/Reykjavik',
        'Sudur-Tingeyjarsysla' => 'Atlantic/Reykjavik',
        'Vestur-Bardastrandarsysla' => 'Atlantic/Reykjavik',
        'Vestur-Hunavatnssysla' => 'Atlantic/Reykjavik',
        'Vestur-Isafjardarsysla' => 'Atlantic/Reykjavik',
        'Vestur-Skaftafellssysla' => 'Atlantic/Reykjavik',
        'Austurland' => 'Atlantic/Reykjavik',
        'Hofuoborgarsvaoio' => 'Atlantic/Reykjavik',
        'Norourland Eystra' => 'Atlantic/Reykjavik',
        'Norourland Vestra' => 'Atlantic/Reykjavik',
        'Suourland' => 'Atlantic/Reykjavik',
        'Suournes' => 'Atlantic/Reykjavik',
        'Vestfiroir' => 'Atlantic/Reykjavik',
        'Vesturland' => 'Atlantic/Reykjavik',
      ],
      'IT' => [
        'Abruzzi' => 'Europe/Rome',
        'Basilicata' => 'Europe/Rome',
        'Calabria' => 'Europe/Rome',
        'Campania' => 'Europe/Rome',
        'Emilia-Romagna' => 'Europe/Rome',
        'Friuli-Venezia Giulia' => 'Europe/Rome',
        'Lazio' => 'Europe/Rome',
        'Liguria' => 'Europe/Rome',
        'Lombardia' => 'Europe/Rome',
        'Marche' => 'Europe/Rome',
        'Molise' => 'Europe/Rome',
        'Piemonte' => 'Europe/Rome',
        'Puglia' => 'Europe/Rome',
        'Sardegna' => 'Europe/Rome',
        'Sicilia' => 'Europe/Rome',
        'Toscana' => 'Europe/Rome',
        'Trentino-Alto Adige' => 'Europe/Rome',
        'Umbria' => 'Europe/Rome',
        "Valle d'Aosta" => 'Europe/Rome',
        'Veneto' => 'Europe/Rome',
      ],
      'JM' => [
        'Clarendon' => 'America/Jamaica',
        'Hanover' => 'America/Jamaica',
        'Manchester' => 'America/Jamaica',
        'Portland' => 'America/Jamaica',
        'Saint Andrew' => 'America/Jamaica',
        'Saint Ann' => 'America/Jamaica',
        'Saint Catherine' => 'America/Jamaica',
        'Saint Elizabeth' => 'America/Jamaica',
        'Saint James' => 'America/Jamaica',
        'Saint Mary' => 'America/Jamaica',
        'Saint Thomas' => 'America/Jamaica',
        'Trelawny' => 'America/Jamaica',
        'Westmoreland' => 'America/Jamaica',
        'Kingston' => 'America/Jamaica',
      ],
      'JO' => [
        "Al Balqa'" => 'Asia/Amman',
        'Al Karak' => 'Asia/Amman',
        'At Tafilah' => 'Asia/Amman',
        'Al Mafraq' => 'Asia/Amman',
        'Amman' => 'Asia/Amman',
        'Az Zaraqa' => 'Asia/Amman',
        'Irbid' => 'Asia/Amman',
        "Ma'an" => 'Asia/Amman',
        'Ajlun' => 'Asia/Amman',
        'Al Aqabah' => 'Asia/Amman',
        'Jarash' => 'Asia/Amman',
        'Madaba' => 'Asia/Amman',
      ],
      'JP' => [
        'Aichi' => 'Asia/Tokyo',
        'Akita' => 'Asia/Tokyo',
        'Aomori' => 'Asia/Tokyo',
        'Chiba' => 'Asia/Tokyo',
        'Ehime' => 'Asia/Tokyo',
        'Fukui' => 'Asia/Tokyo',
        'Fukuoka' => 'Asia/Tokyo',
        'Fukushima' => 'Asia/Tokyo',
        'Gifu' => 'Asia/Tokyo',
        'Gumma' => 'Asia/Tokyo',
        'Hiroshima' => 'Asia/Tokyo',
        'Hokkaido' => 'Asia/Tokyo',
        'Hyogo' => 'Asia/Tokyo',
        'Ibaraki' => 'Asia/Tokyo',
        'Ishikawa' => 'Asia/Tokyo',
        'Iwate' => 'Asia/Tokyo',
        'Kagawa' => 'Asia/Tokyo',
        'Kagoshima' => 'Asia/Tokyo',
        'Kanagawa' => 'Asia/Tokyo',
        'Kochi' => 'Asia/Tokyo',
        'Kumamoto' => 'Asia/Tokyo',
        'Kyoto' => 'Asia/Tokyo',
        'Mie' => 'Asia/Tokyo',
        'Miyagi' => 'Asia/Tokyo',
        'Miyazaki' => 'Asia/Tokyo',
        'Nagano' => 'Asia/Tokyo',
        'Nagasaki' => 'Asia/Tokyo',
        'Nara' => 'Asia/Tokyo',
        'Niigata' => 'Asia/Tokyo',
        'Oita' => 'Asia/Tokyo',
        'Okayama' => 'Asia/Tokyo',
        'Osaka' => 'Asia/Tokyo',
        'Saga' => 'Asia/Tokyo',
        'Saitama' => 'Asia/Tokyo',
        'Shiga' => 'Asia/Tokyo',
        'Shimane' => 'Asia/Tokyo',
        'Shizuoka' => 'Asia/Tokyo',
        'Tochigi' => 'Asia/Tokyo',
        'Tokushima' => 'Asia/Tokyo',
        'Tokyo' => 'Asia/Tokyo',
        'Tottori' => 'Asia/Tokyo',
        'Toyama' => 'Asia/Tokyo',
        'Wakayama' => 'Asia/Tokyo',
        'Yamagata' => 'Asia/Tokyo',
        'Yamaguchi' => 'Asia/Tokyo',
        'Yamanashi' => 'Asia/Tokyo',
        'Okinawa' => 'Asia/Tokyo',
      ],
      'KE' => [
        'Central' => 'Africa/Nairobi',
        'Coast' => 'Africa/Nairobi',
        'Eastern' => 'Africa/Nairobi',
        'Nairobi Area' => 'Africa/Nairobi',
        'North-Eastern' => 'Africa/Nairobi',
        'Nyanza' => 'Africa/Nairobi',
        'Rift Valley' => 'Africa/Nairobi',
        'Western' => 'Africa/Nairobi',
      ],
      'KG' => [
        'Bishkek' => 'Asia/Bishkek',
        'Chuy' => 'Asia/Bishkek',
        'Jalal-Abad' => 'Asia/Bishkek',
        'Naryn' => 'Asia/Bishkek',
        'Osh' => 'Asia/Bishkek',
        'Talas' => 'Asia/Bishkek',
        'Ysyk-Kol' => 'Asia/Bishkek',
        'Batken' => 'Asia/Bishkek',
      ],
      'KH' => [
        'Batdambang' => 'Asia/Phnom_Penh',
        'Kampong Cham' => 'Asia/Phnom_Penh',
        'Kampong Chhnang' => 'Asia/Phnom_Penh',
        'Kampong Speu' => 'Asia/Phnom_Penh',
        'Kampong Thum' => 'Asia/Phnom_Penh',
        'Kampot' => 'Asia/Phnom_Penh',
        'Kandal' => 'Asia/Phnom_Penh',
        'Koh Kong' => 'Asia/Phnom_Penh',
        'Kracheh' => 'Asia/Phnom_Penh',
        'Mondulkiri' => 'Asia/Phnom_Penh',
        'Phnum Penh' => 'Asia/Phnom_Penh',
        'Pursat' => 'Asia/Phnom_Penh',
        'Preah Vihear' => 'Asia/Phnom_Penh',
        'Prey Veng' => 'Asia/Phnom_Penh',
        'Ratanakiri Kiri' => 'Asia/Phnom_Penh',
        'Siem Reap' => 'Asia/Phnom_Penh',
        'Stung Treng' => 'Asia/Phnom_Penh',
        'Svay Rieng' => 'Asia/Phnom_Penh',
        'Takeo' => 'Asia/Phnom_Penh',
        'Ratanakiri' => 'Asia/Phnom_Penh',
        'Banteay Meanchey' => 'Asia/Phnom_Penh',
        'Preah Seihanu' => 'Asia/Phnom_Penh',
        'Pailin' => 'Asia/Phnom_Penh',
      ],
      'KI' => [
        'Gilbert Islands' => 'Pacific/Tarawa',
        'Line Islands' => 'Pacific/Tarawa',
        'Phoenix Islands' => 'Pacific/Tarawa',
      ],
      'KM' => [
        'Anjouan' => 'Indian/Comoro',
        'Grande Comore' => 'Indian/Comoro',
        'Moheli' => 'Indian/Comoro',
      ],
      'KN' => [
        'Christ Church Nichola Town' => 'America/St_Kitts',
        'Saint Anne Sandy Point' => 'America/St_Kitts',
        'Saint George Basseterre' => 'America/St_Kitts',
        'Saint George Gingerland' => 'America/St_Kitts',
        'Saint James Windward' => 'America/St_Kitts',
        'Saint John Capisterre' => 'America/St_Kitts',
        'Saint John Figtree' => 'America/St_Kitts',
        'Saint Mary Cayon' => 'America/St_Kitts',
        'Saint Paul Capisterre' => 'America/St_Kitts',
        'Saint Paul Charlestown' => 'America/St_Kitts',
        'Saint Peter Basseterre' => 'America/St_Kitts',
        'Saint Thomas Lowland' => 'America/St_Kitts',
        'Saint Thomas Middle Island' => 'America/St_Kitts',
        'Trinity Palmetto Point' => 'America/St_Kitts',
      ],
      'KP' => [
        'Chagang-do' => 'Asia/Pyongyang',
        'Hamgyong-namdo' => 'Asia/Pyongyang',
        'Hwanghae-namdo' => 'Asia/Pyongyang',
        'Hwanghae-bukto' => 'Asia/Pyongyang',
        'Kaesong-si' => 'Asia/Pyongyang',
        'Kangwon-do' => 'Asia/Pyongyang',
        "P'yongan-bukto" => 'Asia/Pyongyang',
        "P'yongyang-si" => 'Asia/Pyongyang',
        'Yanggang-do' => 'Asia/Pyongyang',
        "Namp'o-si" => 'Asia/Pyongyang',
        "P'yongan-namdo" => 'Asia/Pyongyang',
        'Hamgyong-bukto' => 'Asia/Pyongyang',
        'Najin Sonbong-si' => 'Asia/Pyongyang',
      ],
      'KR' => [
        'Cheju-do' => 'Asia/Seoul',
        'Cholla-bukto' => 'Asia/Seoul',
        "Ch'ungch'ong-bukto" => 'Asia/Seoul',
        'Kangwon-do' => 'Asia/Seoul',
        'Pusan-jikhalsi' => 'Asia/Seoul',
        "Seoul-t'ukpyolsi" => 'Asia/Seoul',
        "Inch'on-jikhalsi" => 'Asia/Seoul',
        'Kyonggi-do' => 'Asia/Seoul',
        'Kyongsang-bukto' => 'Asia/Seoul',
        'Taegu-jikhalsi' => 'Asia/Seoul',
        'Cholla-namdo' => 'Asia/Seoul',
        "Ch'ungch'ong-namdo" => 'Asia/Seoul',
        'Kwangju-jikhalsi' => 'Asia/Seoul',
        'Taejon-jikhalsi' => 'Asia/Seoul',
        'Kyongsang-namdo' => 'Asia/Seoul',
        'Ulsan-gwangyoksi' => 'Asia/Seoul',
      ],
      'KW' => [
        'Al Ahmadi' => 'Asia/Kuwait',
        'Al Kuwayt' => 'Asia/Kuwait',
        'Al Jahra' => 'Asia/Kuwait',
        'Al Farwaniyah' => 'Asia/Kuwait',
        'Hawalli' => 'Asia/Kuwait',
        'Mubarak al Kabir' => 'Asia/Kuwait',
      ],
      'KY' => [
        'Creek' => 'America/Cayman',
        'Eastern' => 'America/Cayman',
        'Midland' => 'America/Cayman',
        'South Town' => 'America/Cayman',
        'Spot Bay' => 'America/Cayman',
        'Stake Bay' => 'America/Cayman',
        'West End' => 'America/Cayman',
        'Western' => 'America/Cayman',
      ],
      'KZ' => [
        'Almaty' => 'Asia/Almaty',
        'Almaty City' => 'Asia/Almaty',
        'Aqmola' => 'Asia/Qyzylorda',
        'Aqtobe' => 'Asia/Aqtobe',
        'Astana' => 'Asia/Qyzylorda',
        'Atyrau' => 'Asia/Aqtau',
        'West Kazakhstan' => 'Asia/Oral',
        'Bayqonyr' => 'Asia/Qyzylorda',
        'Mangghystau' => 'Asia/Aqtau',
        'South Kazakhstan' => 'Asia/Qyzylorda',
        'Pavlodar' => 'Asia/Almaty',
        'Qaraghandy' => 'Asia/Qyzylorda',
        'Qostanay' => 'Asia/Aqtobe',
        'Qyzylorda' => 'Asia/Qyzylorda',
        'East Kazakhstan' => 'Asia/Almaty',
        'North Kazakhstan' => 'Asia/Aqtobe',
        'Zhambyl' => 'Asia/Almaty',
      ],
      'LA' => [
        'Attapu' => 'Asia/Vientiane',
        'Champasak' => 'Asia/Vientiane',
        'Houaphan' => 'Asia/Vientiane',
        'Khammouan' => 'Asia/Vientiane',
        'Louang Namtha' => 'Asia/Vientiane',
        'Oudomxai' => 'Asia/Vientiane',
        'Phongsali' => 'Asia/Vientiane',
        'Saravan' => 'Asia/Vientiane',
        'Savannakhet' => 'Asia/Vientiane',
        'Vientiane' => 'Asia/Vientiane',
        'Xaignabouri' => 'Asia/Vientiane',
        'Xiangkhoang' => 'Asia/Vientiane',
        'Louangphrabang' => 'Asia/Vientiane',
      ],
      'LB' => [
        'Beqaa' => 'Asia/Beirut',
        'Al Janub' => 'Asia/Beirut',
        'Liban-Nord' => 'Asia/Beirut',
        'Beyrouth' => 'Asia/Beirut',
        'Mont-Liban' => 'Asia/Beirut',
        'Liban-Sud' => 'Asia/Beirut',
        'Nabatiye' => 'Asia/Beirut',
        'Aakk,r' => 'Asia/Beirut',
        'Baalbek-Hermel' => 'Asia/Beirut',
      ],
      'LC' => [
        'Anse-la-Raye' => 'America/St_Lucia',
        'Dauphin' => 'America/St_Lucia',
        'Castries' => 'America/St_Lucia',
        'Choiseul' => 'America/St_Lucia',
        'Dennery' => 'America/St_Lucia',
        'Gros-Islet' => 'America/St_Lucia',
        'Laborie' => 'America/St_Lucia',
        'Micoud' => 'America/St_Lucia',
        'Soufriere' => 'America/St_Lucia',
        'Vieux-Fort' => 'America/St_Lucia',
        'Praslin' => 'America/St_Lucia',
      ],
      'LI' => [
        'Balzers' => 'Europe/Vaduz',
        'Eschen' => 'Europe/Vaduz',
        'Gamprin' => 'Europe/Vaduz',
        'Mauren' => 'Europe/Vaduz',
        'Planken' => 'Europe/Vaduz',
        'Ruggell' => 'Europe/Vaduz',
        'Schaan' => 'Europe/Vaduz',
        'Schellenberg' => 'Europe/Vaduz',
        'Triesen' => 'Europe/Vaduz',
        'Triesenberg' => 'Europe/Vaduz',
        'Vaduz' => 'Europe/Vaduz',
        'Gbarpolu' => 'Europe/Vaduz',
        'River Gee' => 'Europe/Vaduz',
      ],
      'LK' => [
        'Central' => 'Asia/Colombo',
        'North Central' => 'Asia/Colombo',
        'North Western' => 'Asia/Colombo',
        'Sabaragamuwa' => 'Asia/Colombo',
        'Southern' => 'Asia/Colombo',
        'Uva' => 'Asia/Colombo',
        'Western' => 'Asia/Colombo',
        'Eastern' => 'Asia/Colombo',
        'Northern' => 'Asia/Colombo',
      ],
      'LR' => [
        'Bong' => 'Africa/Monrovia',
        'Grand Cape Mount' => 'Africa/Monrovia',
        'Lofa' => 'Africa/Monrovia',
        'Maryland' => 'Africa/Monrovia',
        'Monrovia' => 'Africa/Monrovia',
        'Nimba' => 'Africa/Monrovia',
        'Sino' => 'Africa/Monrovia',
        'Grand Bassa' => 'Africa/Monrovia',
        'Montserrado' => 'Africa/Monrovia',
        'Margibi' => 'Africa/Monrovia',
        'River Cess' => 'Africa/Monrovia',
        'Grand Gedeh' => 'Africa/Monrovia',
        'Gbarpolu' => 'Africa/Monrovia',
        'River Gee' => 'Africa/Monrovia',
      ],
      'LS' => [
        'Berea' => 'Africa/Maseru',
        'Butha-Buthe' => 'Africa/Maseru',
        'Leribe' => 'Africa/Maseru',
        'Mafeteng' => 'Africa/Maseru',
        'Maseru' => 'Africa/Maseru',
        'Mohales Hoek' => 'Africa/Maseru',
        'Mokhotlong' => 'Africa/Maseru',
        'Qachas Nek' => 'Africa/Maseru',
        'Quthing' => 'Africa/Maseru',
        'Thaba-Tseka' => 'Africa/Maseru',
      ],
      'LT' => [
        'Alytaus Apskritis' => 'Europe/Vilnius',
        'Kauno Apskritis' => 'Europe/Vilnius',
        'Klaipedos Apskritis' => 'Europe/Vilnius',
        'Marijampoles Apskritis' => 'Europe/Vilnius',
        'Panevezio Apskritis' => 'Europe/Vilnius',
        'Siauliu Apskritis' => 'Europe/Vilnius',
        'Taurages Apskritis' => 'Europe/Vilnius',
        'Telsiu Apskritis' => 'Europe/Vilnius',
        'Utenos Apskritis' => 'Europe/Vilnius',
        'Vilniaus Apskritis' => 'Europe/Vilnius',
      ],
      'LU' => [
        'Diekirch' => 'Europe/Luxembourg',
        'Grevenmacher' => 'Europe/Luxembourg',
        'Luxembourg' => 'Europe/Luxembourg',
      ],
      'LV' => [
        'Aizkraukles' => 'Europe/Riga',
        'Aluksnes' => 'Europe/Riga',
        'Balvu' => 'Europe/Riga',
        'Bauskas' => 'Europe/Riga',
        'Cesu' => 'Europe/Riga',
        'Daugavpils' => 'Europe/Riga',
        'Dobeles' => 'Europe/Riga',
        'Gulbenes' => 'Europe/Riga',
        'Jekabpils' => 'Europe/Riga',
        'Jelgava' => 'Europe/Riga',
        'Jelgavas' => 'Europe/Riga',
        'Jurmala' => 'Europe/Riga',
        'Kraslavas' => 'Europe/Riga',
        'Kuldigas' => 'Europe/Riga',
        'Liepaja' => 'Europe/Riga',
        'Liepajas' => 'Europe/Riga',
        'Limbazu' => 'Europe/Riga',
        'Ludzas' => 'Europe/Riga',
        'Madonas' => 'Europe/Riga',
        'Ogres' => 'Europe/Riga',
        'Preilu' => 'Europe/Riga',
        'Rezekne' => 'Europe/Riga',
        'Rezeknes' => 'Europe/Riga',
        'Riga' => 'Europe/Riga',
        'Rigas' => 'Europe/Riga',
        'Saldus' => 'Europe/Riga',
        'Talsu' => 'Europe/Riga',
        'Tukuma' => 'Europe/Riga',
        'Valkas' => 'Europe/Riga',
        'Valmieras' => 'Europe/Riga',
        'Ventspils' => 'Europe/Riga',
      ],
      'LY' => [
        'Al Aziziyah' => 'Africa/Tripoli',
        'Al Jufrah' => 'Africa/Tripoli',
        'Al Kufrah' => 'Africa/Tripoli',
        "Ash Shati'" => 'Africa/Tripoli',
        'Murzuq' => 'Africa/Tripoli',
        'Sabha' => 'Africa/Tripoli',
        'Tarhunah' => 'Africa/Tripoli',
        'Tubruq' => 'Africa/Tripoli',
        'Zlitan' => 'Africa/Tripoli',
        'Ajdabiya' => 'Africa/Tripoli',
        'Al Fatih' => 'Africa/Tripoli',
        'Al Jabal al Akhdar' => 'Africa/Tripoli',
        'Al Khums' => 'Africa/Tripoli',
        'An Nuqat al Khams' => 'Africa/Tripoli',
        'Awbari' => 'Africa/Tripoli',
        'Az Zawiyah' => 'Africa/Tripoli',
        'Banghazi' => 'Africa/Tripoli',
        'Darnah' => 'Africa/Tripoli',
        'Ghadamis' => 'Africa/Tripoli',
        'Gharyan' => 'Africa/Tripoli',
        'Misratah' => 'Africa/Tripoli',
        'Sawfajjin' => 'Africa/Tripoli',
        'Surt' => 'Africa/Tripoli',
        'Tarabulus' => 'Africa/Tripoli',
        'Yafran' => 'Africa/Tripoli',
      ],
      'MA' => [
        'Grand Casablanca' => 'Africa/Casablanca',
        'Fes-Boulemane' => 'Africa/Casablanca',
        'Marrakech-Tensift-Al Haouz' => 'Africa/Casablanca',
        'Meknes-Tafilalet' => 'Africa/Casablanca',
        'Rabat-Sale-Zemmour-Zaer' => 'Africa/Casablanca',
        'Chaouia-Ouardigha' => 'Africa/Casablanca',
        'Doukkala-Abda' => 'Africa/Casablanca',
        'Gharb-Chrarda-Beni Hssen' => 'Africa/Casablanca',
        'Guelmim-Es Smara' => 'Africa/Casablanca',
        'Oriental' => 'Africa/Casablanca',
        'Souss-Massa-Dr,a' => 'Africa/Casablanca',
        'Tadla-Azilal' => 'Africa/Casablanca',
        'Tanger-Tetouan' => 'Africa/Casablanca',
        'Taza-Al Hoceima-Taounate' => 'Africa/Casablanca',
        'La,youne-Boujdour-Sakia El Hamra' => 'Africa/Casablanca',
      ],
      'MC' => [
        'La Condamine' => 'Europe/Monaco',
        'Monaco' => 'Europe/Monaco',
        'Monte-Carlo' => 'Europe/Monaco',
      ],
      'MD' => [
        'Gagauzia' => 'Europe/Chisinau',
        'Chisinau' => 'Europe/Chisinau',
        'Stinga Nistrului' => 'Europe/Chisinau',
        'Anenii Noi' => 'Europe/Chisinau',
        'Balti' => 'Europe/Chisinau',
        'Basarabeasca' => 'Europe/Chisinau',
        'Bender' => 'Europe/Chisinau',
        'Briceni' => 'Europe/Chisinau',
        'Cahul' => 'Europe/Chisinau',
        'Cantemir' => 'Europe/Chisinau',
        'Calarasi' => 'Europe/Chisinau',
        'Causeni' => 'Europe/Chisinau',
        'Cimislia' => 'Europe/Chisinau',
        'Criuleni' => 'Europe/Chisinau',
        'Donduseni' => 'Europe/Chisinau',
        'Drochia' => 'Europe/Chisinau',
        'Dubasari' => 'Europe/Chisinau',
        'Edinet' => 'Europe/Chisinau',
        'Falesti' => 'Europe/Chisinau',
        'Floresti' => 'Europe/Chisinau',
        'Glodeni' => 'Europe/Chisinau',
        'Hincesti' => 'Europe/Chisinau',
        'Ialoveni' => 'Europe/Chisinau',
        'Leova' => 'Europe/Chisinau',
        'Nisporeni' => 'Europe/Chisinau',
        'Ocnita' => 'Europe/Chisinau',
        'Orhei' => 'Europe/Chisinau',
        'Rezina' => 'Europe/Chisinau',
        'Riscani' => 'Europe/Chisinau',
        'Singerei' => 'Europe/Chisinau',
        'Soldanesti' => 'Europe/Chisinau',
        'Soroca' => 'Europe/Chisinau',
        'Stefan-Voda' => 'Europe/Chisinau',
        'Straseni' => 'Europe/Chisinau',
        'Taraclia' => 'Europe/Chisinau',
        'Telenesti' => 'Europe/Chisinau',
        'Ungheni' => 'Europe/Chisinau',
      ],
      'MG' => [
        'Antsiranana' => 'Indian/Antananarivo',
        'Fianarantsoa' => 'Indian/Antananarivo',
        'Mahajanga' => 'Indian/Antananarivo',
        'Toamasina' => 'Indian/Antananarivo',
        'Antananarivo' => 'Indian/Antananarivo',
        'Toliara' => 'Indian/Antananarivo',
      ],
      'MK' => [
        'Aracinovo' => 'Europe/Skopje',
        'Bac' => 'Europe/Skopje',
        'Belcista' => 'Europe/Skopje',
        'Berovo' => 'Europe/Skopje',
        'Bistrica' => 'Europe/Skopje',
        'Bitola' => 'Europe/Skopje',
        'Blatec' => 'Europe/Skopje',
        'Bogdanci' => 'Europe/Skopje',
        'Bogomila' => 'Europe/Skopje',
        'Bogovinje' => 'Europe/Skopje',
        'Bosilovo' => 'Europe/Skopje',
        'Brvenica' => 'Europe/Skopje',
        'Cair' => 'Europe/Skopje',
        'Capari' => 'Europe/Skopje',
        'Caska' => 'Europe/Skopje',
        'Cegrane' => 'Europe/Skopje',
        'Centar' => 'Europe/Skopje',
        'Centar Zupa' => 'Europe/Skopje',
        'Cesinovo' => 'Europe/Skopje',
        'Cucer-Sandevo' => 'Europe/Skopje',
        'Debar' => 'Europe/Skopje',
        'Delcevo' => 'Europe/Skopje',
        'Delogozdi' => 'Europe/Skopje',
        'Demir Hisar' => 'Europe/Skopje',
        'Demir Kapija' => 'Europe/Skopje',
        'Dobrusevo' => 'Europe/Skopje',
        'Dolna Banjica' => 'Europe/Skopje',
        'Dolneni' => 'Europe/Skopje',
        'Dorce Petrov' => 'Europe/Skopje',
        'Drugovo' => 'Europe/Skopje',
        'Dzepciste' => 'Europe/Skopje',
        'Gazi Baba' => 'Europe/Skopje',
        'Gevgelija' => 'Europe/Skopje',
        'Gostivar' => 'Europe/Skopje',
        'Gradsko' => 'Europe/Skopje',
        'Ilinden' => 'Europe/Skopje',
        'Izvor' => 'Europe/Skopje',
        'Jegunovce' => 'Europe/Skopje',
        'Kamenjane' => 'Europe/Skopje',
        'Karbinci' => 'Europe/Skopje',
        'Karpos' => 'Europe/Skopje',
        'Kavadarci' => 'Europe/Skopje',
        'Kicevo' => 'Europe/Skopje',
        'Kisela Voda' => 'Europe/Skopje',
        'Klecevce' => 'Europe/Skopje',
        'Kocani' => 'Europe/Skopje',
        'Konce' => 'Europe/Skopje',
        'Kondovo' => 'Europe/Skopje',
        'Konopiste' => 'Europe/Skopje',
        'Kosel' => 'Europe/Skopje',
        'Kratovo' => 'Europe/Skopje',
        'Kriva Palanka' => 'Europe/Skopje',
        'Krivogastani' => 'Europe/Skopje',
        'Krusevo' => 'Europe/Skopje',
        'Kuklis' => 'Europe/Skopje',
        'Kukurecani' => 'Europe/Skopje',
        'Kumanovo' => 'Europe/Skopje',
        'Labunista' => 'Europe/Skopje',
        'Lipkovo' => 'Europe/Skopje',
        'Lozovo' => 'Europe/Skopje',
        'Lukovo' => 'Europe/Skopje',
        'Makedonska Kamenica' => 'Europe/Skopje',
        'Makedonski Brod' => 'Europe/Skopje',
        'Mavrovi Anovi' => 'Europe/Skopje',
        'Meseista' => 'Europe/Skopje',
        'Miravci' => 'Europe/Skopje',
        'Mogila' => 'Europe/Skopje',
        'Murtino' => 'Europe/Skopje',
        'Negotino' => 'Europe/Skopje',
        'Negotino-Polosko' => 'Europe/Skopje',
        'Novaci' => 'Europe/Skopje',
        'Novo Selo' => 'Europe/Skopje',
        'Oblesevo' => 'Europe/Skopje',
        'Ohrid' => 'Europe/Skopje',
        'Orasac' => 'Europe/Skopje',
        'Orizari' => 'Europe/Skopje',
        'Oslomej' => 'Europe/Skopje',
        'Pehcevo' => 'Europe/Skopje',
        'Petrovec' => 'Europe/Skopje',
        'Plasnica' => 'Europe/Skopje',
        'Podares' => 'Europe/Skopje',
        'Prilep' => 'Europe/Skopje',
        'Probistip' => 'Europe/Skopje',
        'Radovis' => 'Europe/Skopje',
        'Rankovce' => 'Europe/Skopje',
        'Resen' => 'Europe/Skopje',
        'Rosoman' => 'Europe/Skopje',
        'Rostusa' => 'Europe/Skopje',
        'Samokov' => 'Europe/Skopje',
        'Saraj' => 'Europe/Skopje',
        'Sipkovica' => 'Europe/Skopje',
        'Sopiste' => 'Europe/Skopje',
        'Sopotnica' => 'Europe/Skopje',
        'Srbinovo' => 'Europe/Skopje',
        'Staravina' => 'Europe/Skopje',
        'Star Dojran' => 'Europe/Skopje',
        'Staro Nagoricane' => 'Europe/Skopje',
        'Stip' => 'Europe/Skopje',
        'Struga' => 'Europe/Skopje',
        'Strumica' => 'Europe/Skopje',
        'Studenicani' => 'Europe/Skopje',
        'Suto Orizari' => 'Europe/Skopje',
        'Sveti Nikole' => 'Europe/Skopje',
        'Tearce' => 'Europe/Skopje',
        'Tetovo' => 'Europe/Skopje',
        'Topolcani' => 'Europe/Skopje',
        'Valandovo' => 'Europe/Skopje',
        'Vasilevo' => 'Europe/Skopje',
        'Veles' => 'Europe/Skopje',
        'Velesta' => 'Europe/Skopje',
        'Vevcani' => 'Europe/Skopje',
        'Vinica' => 'Europe/Skopje',
        'Vitoliste' => 'Europe/Skopje',
        'Vranestica' => 'Europe/Skopje',
        'Vrapciste' => 'Europe/Skopje',
        'Vratnica' => 'Europe/Skopje',
        'Vrutok' => 'Europe/Skopje',
        'Zajas' => 'Europe/Skopje',
        'Zelenikovo' => 'Europe/Skopje',
        'Zelino' => 'Europe/Skopje',
        'Zitose' => 'Europe/Skopje',
        'Zletovo' => 'Europe/Skopje',
        'Zrnovci' => 'Europe/Skopje',
        'Dojran' => 'Europe/Skopje',
        'Aerodrom' => 'Europe/Skopje',
      ],
      'ML' => [
        'Bamako' => 'Africa/Bamako',
        'Kayes' => 'Africa/Bamako',
        'Mopti' => 'Africa/Bamako',
        'Segou' => 'Africa/Bamako',
        'Sikasso' => 'Africa/Bamako',
        'Koulikoro' => 'Africa/Bamako',
        'Tombouctou' => 'Africa/Bamako',
        'Gao' => 'Africa/Bamako',
        'Kidal' => 'Africa/Bamako',
      ],
      'MM' => [
        'Rakhine State' => 'Asia/Rangoon',
        'Chin State' => 'Asia/Rangoon',
        'Irrawaddy' => 'Asia/Rangoon',
        'Kachin State' => 'Asia/Rangoon',
        'Karan State' => 'Asia/Rangoon',
        'Kayah State' => 'Asia/Rangoon',
        'Magwe' => 'Asia/Rangoon',
        'Mandalay' => 'Asia/Rangoon',
        'Pegu' => 'Asia/Rangoon',
        'Sagaing' => 'Asia/Rangoon',
        'Shan State' => 'Asia/Rangoon',
        'Tenasserim' => 'Asia/Rangoon',
        'Mon State' => 'Asia/Rangoon',
        'Rangoon' => 'Asia/Rangoon',
        'Yangon' => 'Asia/Rangoon',
      ],
      'MN' => [
        'Arhangay' => 'Asia/Ulaanbaatar',
        'Bayanhongor' => 'Asia/Ulaanbaatar',
        'Bayan-Olgiy' => 'Asia/Hovd',
        'Darhan' => 'Asia/Ulaanbaatar',
        'Dornod' => 'Asia/Choibalsan',
        'Dornogovi' => 'Asia/Ulaanbaatar',
        'Dundgovi' => 'Asia/Ulaanbaatar',
        'Dzavhan' => 'Asia/Hovd',
        'Govi-Altay' => 'Asia/Hovd',
        'Hentiy' => 'Asia/Ulaanbaatar',
        'Hovd' => 'Asia/Hovd',
        'Hovsgol' => 'Asia/Ulaanbaatar',
        'Omnogovi' => 'Asia/Ulaanbaatar',
        'Ovorhangay' => 'Asia/Ulaanbaatar',
        'Selenge' => 'Asia/Ulaanbaatar',
        'Suhbaatar' => 'Asia/Choibalsan',
        'Tov' => 'Asia/Ulaanbaatar',
        'Uvs' => 'Asia/Hovd',
        'Ulaanbaatar' => 'Asia/Ulaanbaatar',
        'Bulgan' => 'Asia/Ulaanbaatar',
        'Erdenet' => 'Asia/Ulaanbaatar',
        'Darhan-Uul' => 'Asia/Ulaanbaatar',
        'Govisumber' => 'Asia/Ulaanbaatar',
        'Orhon' => 'Asia/Ulaanbaatar',
      ],
      'MO' => [
        'Ilhas' => 'Asia/Macau',
        'Macau' => 'Asia/Macau',
      ],
      'MR' => [
        'Hodh Ech Chargui' => 'Africa/Nouakchott',
        'Hodh El Gharbi' => 'Africa/Nouakchott',
        'Assaba' => 'Africa/Nouakchott',
        'Gorgol' => 'Africa/Nouakchott',
        'Brakna' => 'Africa/Nouakchott',
        'Trarza' => 'Africa/Nouakchott',
        'Adrar' => 'Africa/Nouakchott',
        'Dakhlet Nouadhibou' => 'Africa/Nouakchott',
        'Tagant' => 'Africa/Nouakchott',
        'Guidimaka' => 'Africa/Nouakchott',
        'Tiris Zemmour' => 'Africa/Nouakchott',
        'Inchiri' => 'Africa/Nouakchott',
      ],
      'MS' => [
        'Saint Anthony' => 'America/Montserrat',
        'Saint Georges' => 'America/Montserrat',
        'Saint Peter' => 'America/Montserrat',
      ],
      'MU' => [
        'Black River' => 'Indian/Mauritius',
        'Flacq' => 'Indian/Mauritius',
        'Grand Port' => 'Indian/Mauritius',
        'Moka' => 'Indian/Mauritius',
        'Pamplemousses' => 'Indian/Mauritius',
        'Plaines Wilhems' => 'Indian/Mauritius',
        'Port Louis' => 'Indian/Mauritius',
        'Riviere du Rempart' => 'Indian/Mauritius',
        'Savanne' => 'Indian/Mauritius',
        'Agalega Islands' => 'Indian/Mauritius',
        'Cargados Carajos' => 'Indian/Mauritius',
        'Rodrigues' => 'Indian/Mauritius',
      ],
      'MV' => [
        'Seenu' => 'Indian/Maldives',
        'Laamu' => 'Indian/Maldives',
        'Alifu' => 'Indian/Maldives',
        'Baa' => 'Indian/Maldives',
        'Dhaalu' => 'Indian/Maldives',
        'Faafu ' => 'Indian/Maldives',
        'Gaafu Alifu' => 'Indian/Maldives',
        'Gaafu Dhaalu' => 'Indian/Maldives',
        'Haa Alifu' => 'Indian/Maldives',
        'Haa Dhaalu' => 'Indian/Maldives',
        'Kaafu' => 'Indian/Maldives',
        'Lhaviyani' => 'Indian/Maldives',
        'Maale' => 'Indian/Maldives',
        'Meemu' => 'Indian/Maldives',
        'Gnaviyani' => 'Indian/Maldives',
        'Noonu' => 'Indian/Maldives',
        'Raa' => 'Indian/Maldives',
        'Shaviyani' => 'Indian/Maldives',
        'Thaa' => 'Indian/Maldives',
        'Vaavu' => 'Indian/Maldives',
      ],
      'MW' => [
        'Chikwawa' => 'Africa/Blantyre',
        'Chiradzulu' => 'Africa/Blantyre',
        'Chitipa' => 'Africa/Blantyre',
        'Thyolo' => 'Africa/Blantyre',
        'Dedza' => 'Africa/Blantyre',
        'Dowa' => 'Africa/Blantyre',
        'Karonga' => 'Africa/Blantyre',
        'Kasungu' => 'Africa/Blantyre',
        'Lilongwe' => 'Africa/Blantyre',
        'Mangochi' => 'Africa/Blantyre',
        'Mchinji' => 'Africa/Blantyre',
        'Mzimba' => 'Africa/Blantyre',
        'Ntcheu' => 'Africa/Blantyre',
        'Nkhata Bay' => 'Africa/Blantyre',
        'Nkhotakota' => 'Africa/Blantyre',
        'Nsanje' => 'Africa/Blantyre',
        'Ntchisi' => 'Africa/Blantyre',
        'Rumphi' => 'Africa/Blantyre',
        'Salima' => 'Africa/Blantyre',
        'Zomba' => 'Africa/Blantyre',
        'Blantyre' => 'Africa/Blantyre',
        'Mwanza' => 'Africa/Blantyre',
        'Balaka' => 'Africa/Blantyre',
        'Likoma' => 'Africa/Blantyre',
        'Machinga' => 'Africa/Blantyre',
        'Mulanje' => 'Africa/Blantyre',
        'Phalombe' => 'Africa/Blantyre',
      ],
      'MX' => [
        'Aguascalientes' => 'America/Mexico_City',
        'Baja California' => 'America/Tijuana',
        'Baja California Sur' => 'America/Hermosillo',
        'Campeche' => 'America/Merida',
        'Chiapas' => 'America/Mexico_City',
        'Chihuahua' => 'America/Chihuahua',
        'Coahuila de Zaragoza' => 'America/Monterrey',
        'Colima' => 'America/Mexico_City',
        'Distrito Federal' => 'America/Mexico_City',
        'Durango' => 'America/Mazatlan',
        'Guanajuato' => 'America/Mexico_City',
        'Guerrero' => 'America/Mexico_City',
        'Hidalgo' => 'America/Mexico_City',
        'Jalisco' => 'America/Mazatlan',
        'Mexico' => 'America/Chihuahua',
        'Michoacan de Ocampo' => 'America/Mexico_City',
        'Morelos' => 'America/Mexico_City',
        'Nayarit' => 'America/Mazatlan',
        'Nuevo Leon' => 'America/Monterrey',
        'Oaxaca' => 'America/Mexico_City',
        'Puebla' => 'America/Mexico_City',
        'Queretaro de Arteaga' => 'America/Mexico_City',
        'Quintana Roo' => 'America/Cancun',
        'San Luis Potosi' => 'America/Mexico_City',
        'Sinaloa' => 'America/Mazatlan',
        'Sonora' => 'America/Hermosillo',
        'Tabasco' => 'America/Merida',
        'Tamaulipas' => 'America/Monterrey',
        'Tlaxcala' => 'America/Mexico_City',
        'Veracruz-Llave' => 'America/Mexico_City',
        'Yucatan' => 'America/Merida',
        'Zacatecas' => 'America/Monterrey',
      ],
      'MY' => [
        'Johor' => 'Asia/Kuala_Lumpur',
        'Kedah' => 'Asia/Kuala_Lumpur',
        'Kelantan' => 'Asia/Kuala_Lumpur',
        'Melaka' => 'Asia/Kuala_Lumpur',
        'Negeri Sembilan' => 'Asia/Kuala_Lumpur',
        'Pahang' => 'Asia/Kuala_Lumpur',
        'Perak' => 'Asia/Kuala_Lumpur',
        'Perlis' => 'Asia/Kuala_Lumpur',
        'Pulau Pinang' => 'Asia/Kuala_Lumpur',
        'Sarawak' => 'Asia/Kuching',
        'Selangor' => 'Asia/Kuala_Lumpur',
        'Terengganu' => 'Asia/Kuala_Lumpur',
        'Kuala Lumpur' => 'Asia/Kuala_Lumpur',
        'Labuan' => 'Asia/Kuching',
        'Sabah' => 'Asia/Kuching',
        'Putrajaya' => 'Asia/Kuala_Lumpur',
      ],
      'MZ' => [
        'Cabo Delgado' => 'Africa/Maputo',
        'Gaza' => 'Africa/Maputo',
        'Inhambane' => 'Africa/Maputo',
        'Maputo' => 'Africa/Maputo',
        'Sofala' => 'Africa/Maputo',
        'Nampula' => 'Africa/Maputo',
        'Niassa' => 'Africa/Maputo',
        'Tete' => 'Africa/Maputo',
        'Zambezia' => 'Africa/Maputo',
        'Manica' => 'Africa/Maputo',
      ],
      'NA' => [
        'Bethanien' => 'Africa/Windhoek',
        'Caprivi Oos' => 'Africa/Windhoek',
        'Boesmanland' => 'Africa/Windhoek',
        'Gobabis' => 'Africa/Windhoek',
        'Grootfontein' => 'Africa/Windhoek',
        'Kaokoland' => 'Africa/Windhoek',
        'Karibib' => 'Africa/Windhoek',
        'Keetmanshoop' => 'Africa/Windhoek',
        'Luderitz' => 'Africa/Windhoek',
        'Maltahohe' => 'Africa/Windhoek',
        'Okahandja' => 'Africa/Windhoek',
        'Omaruru' => 'Africa/Windhoek',
        'Otjiwarongo' => 'Africa/Windhoek',
        'Outjo' => 'Africa/Windhoek',
        'Owambo' => 'Africa/Windhoek',
        'Rehoboth' => 'Africa/Windhoek',
        'Swakopmund' => 'Africa/Windhoek',
        'Tsumeb' => 'Africa/Windhoek',
        'Karasburg' => 'Africa/Windhoek',
        'Windhoek' => 'Africa/Windhoek',
        'Damaraland' => 'Africa/Windhoek',
        'Hereroland Oos' => 'Africa/Windhoek',
        'Hereroland Wes' => 'Africa/Windhoek',
        'Kavango' => 'Africa/Windhoek',
        'Mariental' => 'Africa/Windhoek',
        'Namaland' => 'Africa/Windhoek',
        'Caprivi' => 'Africa/Windhoek',
        'Erongo' => 'Africa/Windhoek',
        'Hardap' => 'Africa/Windhoek',
        'Karas' => 'Africa/Windhoek',
        'Kunene' => 'Africa/Windhoek',
        'Ohangwena' => 'Africa/Windhoek',
        'Okavango' => 'Africa/Windhoek',
        'Omaheke' => 'Africa/Windhoek',
        'Omusati' => 'Africa/Windhoek',
        'Oshana' => 'Africa/Windhoek',
        'Oshikoto' => 'Africa/Windhoek',
        'Otjozondjupa' => 'Africa/Windhoek',
      ],
      'NE' => [
        'Agadez' => 'Africa/Niamey',
        'Diffa' => 'Africa/Niamey',
        'Dosso' => 'Africa/Niamey',
        'Maradi' => 'Africa/Niamey',
        'Niamey' => 'Africa/Niamey',
        'Tahoua' => 'Africa/Niamey',
        'Zinder' => 'Africa/Niamey',
      ],
      'NG' => [
        'Lagos' => 'Africa/Lagos',
        'Federal Capital Territory' => 'Africa/Lagos',
        'Ogun' => 'Africa/Lagos',
        'Akwa Ibom' => 'Africa/Lagos',
        'Cross River' => 'Africa/Lagos',
        'Kaduna' => 'Africa/Lagos',
        'Katsina' => 'Africa/Lagos',
        'Anambra' => 'Africa/Lagos',
        'Benue' => 'Africa/Lagos',
        'Borno' => 'Africa/Lagos',
        'Imo' => 'Africa/Lagos',
        'Kano' => 'Africa/Lagos',
        'Kwara' => 'Africa/Lagos',
        'Niger' => 'Africa/Lagos',
        'Oyo' => 'Africa/Lagos',
        'Adamawa' => 'Africa/Lagos',
        'Delta' => 'Africa/Lagos',
        'Edo' => 'Africa/Lagos',
        'Jigawa' => 'Africa/Lagos',
        'Kebbi' => 'Africa/Lagos',
        'Kogi' => 'Africa/Lagos',
        'Osun' => 'Africa/Lagos',
        'Taraba' => 'Africa/Lagos',
        'Yobe' => 'Africa/Lagos',
        'Abia' => 'Africa/Lagos',
        'Bauchi' => 'Africa/Lagos',
        'Enugu' => 'Africa/Lagos',
        'Ondo' => 'Africa/Lagos',
        'Plateau' => 'Africa/Lagos',
        'Rivers' => 'Africa/Lagos',
        'Sokoto' => 'Africa/Lagos',
        'Bayelsa' => 'Africa/Lagos',
        'Ebonyi' => 'Africa/Lagos',
        'Ekiti' => 'Africa/Lagos',
        'Gombe' => 'Africa/Lagos',
        'Nassarawa' => 'Africa/Lagos',
        'Zamfara' => 'Africa/Lagos',
      ],
      'NI' => [
        'Boaco' => 'America/Managua',
        'Carazo' => 'America/Managua',
        'Chinandega' => 'America/Managua',
        'Chontales' => 'America/Managua',
        'Esteli' => 'America/Managua',
        'Granada' => 'America/Managua',
        'Jinotega' => 'America/Managua',
        'Leon' => 'America/Managua',
        'Madriz' => 'America/Managua',
        'Managua' => 'America/Managua',
        'Masaya' => 'America/Managua',
        'Matagalpa' => 'America/Managua',
        'Nueva Segovia' => 'America/Managua',
        'Rio San Juan' => 'America/Managua',
        'Rivas' => 'America/Managua',
        'Zelaya' => 'America/Managua',
        'Autonoma Atlantico Norte' => 'America/Managua',
        'Region Autonoma Atlantico Sur' => 'America/Managua',
      ],
      'NL' => [
        'Drenthe' => 'Europe/Amsterdam',
        'Friesland' => 'Europe/Amsterdam',
        'Gelderland' => 'Europe/Amsterdam',
        'Groningen' => 'Europe/Amsterdam',
        'Limburg' => 'Europe/Amsterdam',
        'Noord-Brabant' => 'Europe/Amsterdam',
        'Noord-Holland' => 'Europe/Amsterdam',
        'Utrecht' => 'Europe/Amsterdam',
        'Zeeland' => 'Europe/Amsterdam',
        'Zuid-Holland' => 'Europe/Amsterdam',
        'Overijssel' => 'Europe/Amsterdam',
        'Flevoland' => 'Europe/Amsterdam',
      ],
      'NO' => [
        'Akershus' => 'Europe/Oslo',
        'Aust-Agder' => 'Europe/Oslo',
        'Buskerud' => 'Europe/Oslo',
        'Finnmark' => 'Europe/Oslo',
        'Hedmark' => 'Europe/Oslo',
        'Hordaland' => 'Europe/Oslo',
        'More og Romsdal' => 'Europe/Oslo',
        'Nordland' => 'Europe/Oslo',
        'Nord-Trondelag' => 'Europe/Oslo',
        'Oppland' => 'Europe/Oslo',
        'Oslo' => 'Europe/Oslo',
        'Ostfold' => 'Europe/Oslo',
        'Rogaland' => 'Europe/Oslo',
        'Sogn og Fjordane' => 'Europe/Oslo',
        'Sor-Trondelag' => 'Europe/Oslo',
        'Telemark' => 'Europe/Oslo',
        'Troms' => 'Europe/Oslo',
        'Vest-Agder' => 'Europe/Oslo',
        'Vestfold' => 'Europe/Oslo',
      ],
      'NP' => [
        'Bagmati' => 'Asia/Kathmandu',
        'Bheri' => 'Asia/Kathmandu',
        'Dhawalagiri' => 'Asia/Kathmandu',
        'Gandaki' => 'Asia/Kathmandu',
        'Janakpur' => 'Asia/Kathmandu',
        'Karnali' => 'Asia/Kathmandu',
        'Kosi' => 'Asia/Kathmandu',
        'Lumbini' => 'Asia/Kathmandu',
        'Mahakali' => 'Asia/Kathmandu',
        'Mechi' => 'Asia/Kathmandu',
        'Narayani' => 'Asia/Kathmandu',
        'Rapti' => 'Asia/Kathmandu',
        'Sagarmatha' => 'Asia/Kathmandu',
        'Seti' => 'Asia/Kathmandu',
      ],
      'NR' => [
        'Aiwo' => 'Pacific/Nauru',
        'Anabar' => 'Pacific/Nauru',
        'Anetan' => 'Pacific/Nauru',
        'Anibare' => 'Pacific/Nauru',
        'Baiti' => 'Pacific/Nauru',
        'Boe' => 'Pacific/Nauru',
        'Buada' => 'Pacific/Nauru',
        'Denigomodu' => 'Pacific/Nauru',
        'Ewa' => 'Pacific/Nauru',
        'Ijuw' => 'Pacific/Nauru',
        'Meneng' => 'Pacific/Nauru',
        'Nibok' => 'Pacific/Nauru',
        'Uaboe' => 'Pacific/Nauru',
        'Yaren' => 'Pacific/Nauru',
      ],
      'NZ' => [
        'Chatham Islands' => 'Pacific/Chatham',
        'Auckland' => 'Pacific/Auckland',
        'Bay of Plenty' => 'Pacific/Auckland',
        'Canterbury' => 'Pacific/Auckland',
        'Gisborne' => 'Pacific/Auckland',
        "Hawke's Bay" => 'Pacific/Auckland',
        'Manawatu-Wanganui' => 'Pacific/Auckland',
        'Marlborough' => 'Pacific/Auckland',
        'Nelson' => 'Pacific/Auckland',
        'Northland' => 'Pacific/Auckland',
        'Otago' => 'Pacific/Chatham',
        'Southland' => 'Pacific/Auckland',
        'Taranaki' => 'Pacific/Auckland',
        'Waikato' => 'Pacific/Auckland',
        'Wellington' => 'Pacific/Auckland',
        'West Coast' => 'Pacific/Auckland',
      ],
      'OM' => [
        'Ad Dakhiliyah' => 'Asia/Muscat',
        'Al Batinah' => 'Asia/Muscat',
        'Al Wusta' => 'Asia/Muscat',
        'Ash Sharqiyah' => 'Asia/Muscat',
        'Az Zahirah' => 'Asia/Muscat',
        'Masqat' => 'Asia/Muscat',
        'Musandam' => 'Asia/Muscat',
        'Zufar' => 'Asia/Muscat',
      ],
      'PA' => [
        'Bocas del Toro' => 'America/Panama',
        'Chiriqui' => 'America/Panama',
        'Cocle' => 'America/Panama',
        'Colon' => 'America/Panama',
        'Darien' => 'America/Panama',
        'Herrera' => 'America/Panama',
        'Los Santos' => 'America/Panama',
        'Panama' => 'America/Panama',
        'San Blas' => 'America/Panama',
        'Veraguas' => 'America/Panama',
      ],
      'PE' => [
        'Amazonas' => 'America/Lima',
        'Ancash' => 'America/Lima',
        'Apurimac' => 'America/Lima',
        'Arequipa' => 'America/Lima',
        'Ayacucho' => 'America/Lima',
        'Cajamarca' => 'America/Lima',
        'Callao' => 'America/Lima',
        'Cusco' => 'America/Lima',
        'Huancavelica' => 'America/Lima',
        'Huanuco' => 'America/Lima',
        'Ica' => 'America/Lima',
        'Junin' => 'America/Lima',
        'La Libertad' => 'America/Lima',
        'Lambayeque' => 'America/Lima',
        'Lima' => 'America/Lima',
        'Loreto' => 'America/Lima',
        'Madre de Dios' => 'America/Lima',
        'Moquegua' => 'America/Lima',
        'Pasco' => 'America/Lima',
        'Piura' => 'America/Lima',
        'Puno' => 'America/Lima',
        'San Martin' => 'America/Lima',
        'Tacna' => 'America/Lima',
        'Tumbes' => 'America/Lima',
        'Ucayali' => 'America/Lima',
      ],
      'PG' => [
        'Central' => 'Pacific/Port_Moresby',
        'Gulf' => 'Pacific/Port_Moresby',
        'Milne Bay' => 'Pacific/Port_Moresby',
        'Northern' => 'Pacific/Port_Moresby',
        'Southern Highlands' => 'Pacific/Port_Moresby',
        'Western' => 'Pacific/Port_Moresby',
        'North Solomons' => 'Pacific/Port_Moresby',
        'Chimbu' => 'Pacific/Port_Moresby',
        'Eastern Highlands' => 'Pacific/Port_Moresby',
        'East New Britain' => 'Pacific/Port_Moresby',
        'East Sepik' => 'Pacific/Port_Moresby',
        'Madang' => 'Pacific/Port_Moresby',
        'Manus' => 'Pacific/Port_Moresby',
        'Morobe' => 'Pacific/Port_Moresby',
        'New Ireland' => 'Pacific/Port_Moresby',
        'Western Highlands' => 'Pacific/Port_Moresby',
        'West New Britain' => 'Pacific/Port_Moresby',
        'Sandaun' => 'Pacific/Port_Moresby',
        'Enga' => 'Pacific/Port_Moresby',
        'National Capital' => 'Pacific/Port_Moresby',
      ],
      'PH' => [
        'Abra' => 'Asia/Manila',
        'Agusan del Norte' => 'Asia/Manila',
        'Agusan del Sur' => 'Asia/Manila',
        'Aklan' => 'Asia/Manila',
        'Albay' => 'Asia/Manila',
        'Antique' => 'Asia/Manila',
        'Bataan' => 'Asia/Manila',
        'Batanes' => 'Asia/Manila',
        'Batangas' => 'Asia/Manila',
        'Benguet' => 'Asia/Manila',
        'Bohol' => 'Asia/Manila',
        'Bukidnon' => 'Asia/Manila',
        'Bulacan' => 'Asia/Manila',
        'Cagayan' => 'Asia/Manila',
        'Camarines Norte' => 'Asia/Manila',
        'Camarines Sur' => 'Asia/Manila',
        'Camiguin' => 'Asia/Manila',
        'Capiz' => 'Asia/Manila',
        'Catanduanes' => 'Asia/Manila',
        'Cavite' => 'Asia/Manila',
        'Cebu' => 'Asia/Manila',
        'Basilan' => 'Asia/Manila',
        'Eastern Samar' => 'Asia/Manila',
        'Davao' => 'Asia/Manila',
        'Davao del Sur' => 'Asia/Manila',
        'Davao Oriental' => 'Asia/Manila',
        'Ifugao' => 'Asia/Manila',
        'Ilocos Norte' => 'Asia/Manila',
        'Ilocos Sur' => 'Asia/Manila',
        'Iloilo' => 'Asia/Manila',
        'Isabela' => 'Asia/Manila',
        'Kalinga-Apayao' => 'Asia/Manila',
        'Laguna' => 'Asia/Manila',
        'Lanao del Norte' => 'Asia/Manila',
        'Lanao del Sur' => 'Asia/Manila',
        'La Union' => 'Asia/Manila',
        'Leyte' => 'Asia/Manila',
        'Marinduque' => 'Asia/Manila',
        'Masbate' => 'Asia/Manila',
        'Mindoro Occidental' => 'Asia/Manila',
        'Mindoro Oriental' => 'Asia/Manila',
        'Misamis Occidental' => 'Asia/Manila',
        'Misamis Oriental' => 'Asia/Manila',
        'Mountain' => 'Asia/Manila',
        'Negros Occidental' => 'Asia/Manila',
        'Negros Oriental' => 'Asia/Manila',
        'Nueva Ecija' => 'Asia/Manila',
        'Nueva Vizcaya' => 'Asia/Manila',
        'Palawan' => 'Asia/Manila',
        'Pampanga' => 'Asia/Manila',
        'Pangasinan' => 'Asia/Manila',
        'Rizal' => 'Asia/Manila',
        'Romblon' => 'Asia/Manila',
        'Samar' => 'Asia/Manila',
        'Maguindanao' => 'Asia/Manila',
        'North Cotabato' => 'Asia/Manila',
        'Sorsogon' => 'Asia/Manila',
        'Southern Leyte' => 'Asia/Manila',
        'Sulu' => 'Asia/Manila',
        'Surigao del Norte' => 'Asia/Manila',
        'Surigao del Sur' => 'Asia/Manila',
        'Tarlac' => 'Asia/Manila',
        'Zamboanga del Norte' => 'Asia/Manila',
        'Zamboanga del Sur' => 'Asia/Manila',
        'Northern Samar' => 'Asia/Manila',
        'Quirino' => 'Asia/Manila',
        'Siquijor' => 'Asia/Manila',
        'South Cotabato' => 'Asia/Manila',
        'Sultan Kudarat' => 'Asia/Manila',
        'Tawitawi' => 'Asia/Manila',
        'Angeles' => 'Asia/Manila',
        'Bacolod' => 'Asia/Manila',
        'Bago' => 'Asia/Manila',
        'Baguio' => 'Asia/Manila',
        'Bais' => 'Asia/Manila',
        'Basilan City' => 'Asia/Manila',
        'Batangas City' => 'Asia/Manila',
        'Butuan' => 'Asia/Manila',
        'Cabanatuan' => 'Asia/Manila',
        'Cadiz' => 'Asia/Manila',
        'Cagayan de Oro' => 'Asia/Manila',
        'Calbayog' => 'Asia/Manila',
        'Caloocan' => 'Asia/Manila',
        'Canlaon' => 'Asia/Manila',
        'Cavite City' => 'Asia/Manila',
        'Cebu City' => 'Asia/Manila',
        'Cotabato' => 'Asia/Manila',
        'Dagupan' => 'Asia/Manila',
        'Danao' => 'Asia/Manila',
        'Dapitan' => 'Asia/Manila',
        'Davao City' => 'Asia/Manila',
        'Dipolog' => 'Asia/Manila',
        'Dumaguete' => 'Asia/Manila',
        'General Santos' => 'Asia/Manila',
        'Gingoog' => 'Asia/Manila',
        'Iligan' => 'Asia/Manila',
        'Iloilo City' => 'Asia/Manila',
        'Iriga' => 'Asia/Manila',
        'La Carlota' => 'Asia/Manila',
        'Laoag' => 'Asia/Manila',
        'Lapu-Lapu' => 'Asia/Manila',
        'Legaspi' => 'Asia/Manila',
        'Lipa' => 'Asia/Manila',
        'Lucena' => 'Asia/Manila',
        'Mandaue' => 'Asia/Manila',
        'Manila' => 'Asia/Manila',
        'Marawi' => 'Asia/Manila',
        'Naga' => 'Asia/Manila',
        'Olongapo' => 'Asia/Manila',
        'Ormoc' => 'Asia/Manila',
        'Oroquieta' => 'Asia/Manila',
        'Ozamis' => 'Asia/Manila',
        'Pagadian' => 'Asia/Manila',
        'Palayan' => 'Asia/Manila',
        'Pasay' => 'Asia/Manila',
        'Puerto Princesa' => 'Asia/Manila',
        'Quezon City' => 'Asia/Manila',
        'Roxas' => 'Asia/Manila',
        'San Carlos' => 'Asia/Manila',
        'San Jose' => 'Asia/Manila',
        'San Pablo' => 'Asia/Manila',
        'Silay' => 'Asia/Manila',
        'Surigao' => 'Asia/Manila',
        'Tacloban' => 'Asia/Manila',
        'Tagaytay' => 'Asia/Manila',
        'Tagbilaran' => 'Asia/Manila',
        'Tangub' => 'Asia/Manila',
        'Toledo' => 'Asia/Manila',
        'Trece Martires' => 'Asia/Manila',
        'Aurora' => 'Asia/Manila',
        'Quezon' => 'Asia/Manila',
        'Biliran' => 'Asia/Manila',
        'Compostela Valley' => 'Asia/Manila',
        'Davao del Norte' => 'Asia/Manila',
        'Guimaras' => 'Asia/Manila',
        'Himamaylan' => 'Asia/Manila',
        'Kalinga' => 'Asia/Manila',
        'Las Pinas' => 'Asia/Manila',
        'Malabon' => 'Asia/Manila',
        'Malaybalay' => 'Asia/Manila',
        'Muntinlupa' => 'Asia/Manila',
        'Navotas' => 'Asia/Manila',
        'Paranaque' => 'Asia/Manila',
        'Passi' => 'Asia/Manila',
        'Zambales' => 'Asia/Manila',
        'San Jose del Monte' => 'Asia/Manila',
        'San Juan' => 'Asia/Manila',
        'Santiago' => 'Asia/Manila',
        'Sarangani' => 'Asia/Manila',
        'Sipalay' => 'Asia/Manila',
        'Zamboanga' => 'Asia/Manila',
      ],
      'PK' => [
        'Federally Administered Tribal Areas' => 'Asia/Karachi',
        'Balochistan' => 'Asia/Karachi',
        'North-West Frontier' => 'Asia/Karachi',
        'Punjab' => 'Asia/Karachi',
        'Sindh' => 'Asia/Karachi',
        'Azad Kashmir' => 'Asia/Karachi',
        'Northern Areas' => 'Asia/Karachi',
        'Islamabad' => 'Asia/Karachi',
      ],
      'PL' => [
        'Dolnoslaskie' => 'Europe/Warsaw',
        'Kujawsko-Pomorskie' => 'Europe/Warsaw',
        'Lodzkie' => 'Europe/Warsaw',
        'Lubelskie' => 'Europe/Warsaw',
        'Lubuskie' => 'Europe/Warsaw',
        'Malopolskie' => 'Europe/Warsaw',
        'Mazowieckie' => 'Europe/Warsaw',
        'Opolskie' => 'Europe/Warsaw',
        'Podkarpackie' => 'Europe/Warsaw',
        'Podlaskie' => 'Europe/Warsaw',
        'Pomorskie' => 'Europe/Warsaw',
        'Slaskie' => 'Europe/Warsaw',
        'Swietokrzyskie' => 'Europe/Warsaw',
        'Warminsko-Mazurskie' => 'Europe/Warsaw',
        'Wielkopolskie' => 'Europe/Warsaw',
        'Zachodniopomorskie' => 'Europe/Warsaw',
      ],
      'PS' => [
        'Gaza' => 'Asia/Gaza',
        'West Bank' => 'Asia/Gaza',
      ],
      'PT' => [
        'Aveiro' => 'Europe/Lisbon',
        'Beja' => 'Europe/Lisbon',
        'Braga' => 'Europe/Lisbon',
        'Braganca' => 'Europe/Lisbon',
        'Castelo Branco' => 'Europe/Lisbon',
        'Coimbra' => 'Europe/Lisbon',
        'Evora' => 'Europe/Lisbon',
        'Faro' => 'Europe/Lisbon',
        'Madeira' => 'Atlantic/Madeira',
        'Guarda' => 'Europe/Lisbon',
        'Leiria' => 'Europe/Lisbon',
        'Lisboa' => 'Europe/Lisbon',
        'Portalegre' => 'Europe/Lisbon',
        'Porto' => 'Europe/Lisbon',
        'Santarem' => 'Europe/Lisbon',
        'Setubal' => 'Europe/Lisbon',
        'Viana do Castelo' => 'Europe/Lisbon',
        'Vila Real' => 'Europe/Lisbon',
        'Viseu' => 'Europe/Lisbon',
        'Azores' => 'Atlantic/Azores',
      ],
      'PY' => [
        'Alto Parana' => 'America/Asuncion',
        'Amambay' => 'America/Asuncion',
        'Caaguazu' => 'America/Asuncion',
        'Caazapa' => 'America/Asuncion',
        'Central' => 'America/Asuncion',
        'Concepcion' => 'America/Asuncion',
        'Cordillera' => 'America/Asuncion',
        'Guaira' => 'America/Asuncion',
        'Itapua' => 'America/Asuncion',
        'Misiones' => 'America/Asuncion',
        'Neembucu' => 'America/Asuncion',
        'Paraguari' => 'America/Asuncion',
        'Presidente Hayes' => 'America/Asuncion',
        'San Pedro' => 'America/Asuncion',
        'Canindeyu' => 'America/Asuncion',
        'Asuncion' => 'America/Asuncion',
        'Alto Paraguay' => 'America/Asuncion',
        'Boqueron' => 'America/Asuncion',
      ],
      'QA' => [
        'Ad Dawhah' => 'Asia/Qatar',
        'Al Ghuwariyah' => 'Asia/Qatar',
        'Al Jumaliyah' => 'Asia/Qatar',
        'Al Khawr' => 'Asia/Qatar',
        'Al Wakrah Municipality' => 'Asia/Qatar',
        'Ar Rayyan' => 'Asia/Qatar',
        'Madinat ach Shamal' => 'Asia/Qatar',
        'Umm Salal' => 'Asia/Qatar',
        'Al Wakrah' => 'Asia/Qatar',
        'Jariyan al Batnah' => 'Asia/Qatar',
        "'Umm Sa'id" => 'Asia/Qatar',
      ],
      'RO' => [
        'Alba' => 'Europe/Bucharest',
        'Arad' => 'Europe/Bucharest',
        'Arges' => 'Europe/Bucharest',
        'Bacau' => 'Europe/Bucharest',
        'Bihor' => 'Europe/Bucharest',
        'Bistrita-Nasaud' => 'Europe/Bucharest',
        'Botosani' => 'Europe/Bucharest',
        'Braila' => 'Europe/Bucharest',
        'Brasov' => 'Europe/Bucharest',
        'Bucuresti' => 'Europe/Bucharest',
        'Buzau' => 'Europe/Bucharest',
        'Caras-Severin' => 'Europe/Bucharest',
        'Cluj' => 'Europe/Bucharest',
        'Constanta' => 'Europe/Bucharest',
        'Covasna' => 'Europe/Bucharest',
        'Dambovita' => 'Europe/Bucharest',
        'Dolj' => 'Europe/Bucharest',
        'Galati' => 'Europe/Bucharest',
        'Gorj' => 'Europe/Bucharest',
        'Harghita' => 'Europe/Bucharest',
        'Hunedoara' => 'Europe/Bucharest',
        'Ialomita' => 'Europe/Bucharest',
        'Iasi' => 'Europe/Bucharest',
        'Maramures' => 'Europe/Bucharest',
        'Mehedinti' => 'Europe/Bucharest',
        'Mures' => 'Europe/Bucharest',
        'Neamt' => 'Europe/Bucharest',
        'Olt' => 'Europe/Bucharest',
        'Prahova' => 'Europe/Bucharest',
        'Salaj' => 'Europe/Bucharest',
        'Satu Mare' => 'Europe/Bucharest',
        'Sibiu' => 'Europe/Bucharest',
        'Suceava' => 'Europe/Bucharest',
        'Teleorman' => 'Europe/Bucharest',
        'Timis' => 'Europe/Bucharest',
        'Tulcea' => 'Europe/Bucharest',
        'Vaslui' => 'Europe/Bucharest',
        'Valcea' => 'Europe/Bucharest',
        'Vrancea' => 'Europe/Bucharest',
        'Calarasi' => 'Europe/Bucharest',
        'Giurgiu' => 'Europe/Bucharest',
        'Ilfov' => 'Europe/Bucharest',
      ],
      'RS' => [
        'Kosovo' => 'Europe/Belgrade',
        'Vojvodina' => 'Europe/Belgrade',
      ],
      'RU' => [
        'Adygeya, Republic of' => 'Europe/Volgograd',
        'Aginsky Buryatsky AO' => 'Asia/Irkutsk',
        'Gorno-Altay' => 'Asia/Novokuznetsk',
        'Altaisky krai' => 'Asia/Novosibirsk',
        'Amur' => 'Asia/Vladivostok',
        "Arkhangel'sk" => 'Europe/Moscow',
        "Astrakhan'" => 'Europe/Volgograd',
        'Bashkortostan' => 'Europe/Samara',
        'Belgorod' => 'Europe/Moscow',
        'Bryansk' => 'Europe/Moscow',
        'Buryat' => 'Asia/Irkutsk',
        'Chechnya' => 'Europe/Volgograd',
        'Chelyabinsk' => 'Asia/Yekaterinburg',
        'Chita' => 'Asia/Irkutsk',
        'Chukot' => 'Asia/Anadyr',
        'Chuvashia' => 'Europe/Samara',
        'Dagestan' => 'Europe/Volgograd',
        'Evenk' => 'Asia/Krasnoyarsk',
        'Ingush' => 'Europe/Moscow',
        'Irkutsk' => 'Asia/Irkutsk',
        'Ivanovo' => 'Europe/Moscow',
        'Kabardin-Balkar' => 'Europe/Volgograd',
        'Kaliningrad' => 'Europe/Kaliningrad',
        'Kalmyk' => 'Europe/Volgograd',
        'Kaluga' => 'Europe/Moscow',
        'Kamchatka' => 'Asia/Kamchatka',
        'Karachay-Cherkess' => 'Europe/Volgograd',
        'Karelia' => 'Europe/Moscow',
        'Kemerovo' => 'Asia/Novokuznetsk',
        'Khabarovsk' => 'Asia/Vladivostok',
        'Khakass' => 'Asia/Krasnoyarsk',
        'Khanty-Mansiy' => 'Asia/Omsk',
        'Kirov' => 'Asia/Yekaterinburg',
        'Komi' => 'Asia/Yekaterinburg',
        'Koryak' => 'Asia/Anadyr',
        'Kostroma' => 'Europe/Moscow',
        'Krasnodar' => 'Europe/Volgograd',
        'Krasnoyarsk' => 'Asia/Krasnoyarsk',
        'Kurgan' => 'Asia/Yekaterinburg',
        'Kursk' => 'Europe/Moscow',
        'Leningrad' => 'Europe/Moscow',
        'Lipetsk' => 'Europe/Moscow',
        'Magadan' => 'Asia/Magadan',
        'Mariy-El' => 'Europe/Samara',
        'Mordovia' => 'Europe/Samara',
        'Moskva' => 'Europe/Moscow',
        'Moscow City' => 'Europe/Moscow',
        'Murmansk' => 'Europe/Moscow',
        'Nenets' => 'Asia/Yekaterinburg',
        'Nizhegorod' => 'Europe/Moscow',
        'Novgorod' => 'Europe/Moscow',
        'Novosibirsk' => 'Asia/Novosibirsk',
        'Omsk' => 'Asia/Omsk',
        'Orenburg' => 'Europe/Samara',
        'Orel' => 'Europe/Moscow',
        'Penza' => 'Europe/Samara',
        "Perm'" => 'Asia/Yekaterinburg',
        "Primor'ye" => 'Asia/Vladivostok',
        'Pskov' => 'Europe/Kaliningrad',
        'Rostov' => 'Europe/Volgograd',
        "Ryazan'" => 'Europe/Moscow',
        'Sakha' => 'Asia/Yakutsk',
        'Sakhalin' => 'Asia/Sakhalin',
        'Samara' => 'Europe/Samara',
        'Saint Petersburg City' => 'Europe/Moscow',
        'Saratov' => 'Europe/Samara',
        'North Ossetia' => 'Europe/Volgograd',
        'Smolensk' => 'Europe/Moscow',
        "Stavropol'" => 'Europe/Volgograd',
        'Sverdlovsk' => 'Asia/Yekaterinburg',
        'Tambovskaya oblast' => 'Europe/Moscow',
        'Tatarstan' => 'Europe/Samara',
        'Taymyr' => 'Asia/Krasnoyarsk',
        'Tomsk' => 'Asia/Novosibirsk',
        'Tula' => 'Europe/Moscow',
        "Tver'" => 'Europe/Moscow',
        "Tyumen'" => 'Asia/Yekaterinburg',
        'Tuva' => 'Asia/Irkutsk',
        'Udmurt' => 'Asia/Yekaterinburg',
        "Ul'yanovsk" => 'Europe/Samara',
        'Vladimir' => 'Europe/Moscow',
        'Volgograd' => 'Europe/Volgograd',
        'Vologda' => 'Europe/Moscow',
        'Voronezh' => 'Europe/Moscow',
        'Yamal-Nenets' => 'Asia/Novosibirsk',
        "Yaroslavl'" => 'Europe/Moscow',
        'Yevrey' => 'Asia/Vladivostok',
        'Permskiy Kray' => 'Asia/Yekaterinburg',
        'Krasnoyarskiy Kray' => 'Asia/Krasnoyarsk',
        'Kamchatskiy Kray' => 'Asia/Anadyr',
        "Zabaykal'skiy Kray" => 'Asia/Irkutsk',
      ],
      'RW' => [
        'Butare' => 'Africa/Kigali',
        'Gitarama' => 'Africa/Kigali',
        'Kibungo' => 'Africa/Kigali',
        'Kigali' => 'Africa/Kigali',
        'Est' => 'Africa/Kigali',
        'Nord' => 'Africa/Kigali',
        'Ouest' => 'Africa/Kigali',
        'Sud' => 'Africa/Kigali',
      ],
      'SA' => [
        'Al Bahah' => 'Asia/Riyadh',
        'Al Madinah' => 'Asia/Riyadh',
        'Ash Sharqiyah' => 'Asia/Riyadh',
        'Al Qasim' => 'Asia/Riyadh',
        'Ar Riyad' => 'Asia/Riyadh',
        'Asir Province' => 'Asia/Riyadh',
        "Ha'il" => 'Asia/Riyadh',
        'Makkah' => 'Asia/Riyadh',
        'Al Hudud ash Shamaliyah' => 'Asia/Riyadh',
        'Najran' => 'Asia/Riyadh',
        'Jizan' => 'Asia/Riyadh',
        'Tabuk' => 'Asia/Riyadh',
        'Al Jawf' => 'Asia/Riyadh',
      ],
      'SB' => [
        'Malaita' => 'Pacific/Guadalcanal',
        'Guadalcanal' => 'Pacific/Guadalcanal',
        'Isabel' => 'Pacific/Guadalcanal',
        'Makira' => 'Pacific/Guadalcanal',
        'Temotu' => 'Pacific/Guadalcanal',
        'Central' => 'Pacific/Guadalcanal',
        'Western' => 'Pacific/Guadalcanal',
        'Choiseul' => 'Pacific/Guadalcanal',
        'Rennell and Bellona' => 'Pacific/Guadalcanal',
      ],
      'SC' => [
        'Anse aux Pins' => 'Indian/Mahe',
        'Anse Boileau' => 'Indian/Mahe',
        'Anse Etoile' => 'Indian/Mahe',
        'Anse Louis' => 'Indian/Mahe',
        'Anse Royale' => 'Indian/Mahe',
        'Baie Lazare' => 'Indian/Mahe',
        'Baie Sainte Anne' => 'Indian/Mahe',
        'Beau Vallon' => 'Indian/Mahe',
        'Bel Air' => 'Indian/Mahe',
        'Bel Ombre' => 'Indian/Mahe',
        'Cascade' => 'Indian/Mahe',
        'Glacis' => 'Indian/Mahe',
        "Grand' Anse" => 'Indian/Mahe',
        'La Digue' => 'Indian/Mahe',
        'La Riviere Anglaise' => 'Indian/Mahe',
        'Mont Buxton' => 'Indian/Mahe',
        'Mont Fleuri' => 'Indian/Mahe',
        'Plaisance' => 'Indian/Mahe',
        'Pointe La Rue' => 'Indian/Mahe',
        'Port Glaud' => 'Indian/Mahe',
        'Saint Louis' => 'Indian/Mahe',
        'Takamaka' => 'Indian/Mahe',
      ],
      'SD' => [
        'Al Wusta' => 'Africa/Khartoum',
        "Al Istiwa'iyah" => 'Africa/Khartoum',
        'Al Khartum' => 'Africa/Khartoum',
        'Ash Shamaliyah' => 'Africa/Khartoum',
        'Ash Sharqiyah' => 'Africa/Khartoum',
        'Bahr al Ghazal' => 'Africa/Khartoum',
        'Darfur' => 'Africa/Khartoum',
        'Kurdufan' => 'Africa/Khartoum',
        'Upper Nile' => 'Africa/Khartoum',
        'Al Wahadah State' => 'Africa/Khartoum',
        'Central Equatoria State' => 'Africa/Khartoum',
        'Southern Darfur' => 'Africa/Khartoum',
        'Southern Kordofan' => 'Africa/Khartoum',
        'Kassala' => 'Africa/Khartoum',
        'River Nile' => 'Africa/Khartoum',
        'Northern Darfur' => 'Africa/Khartoum',
      ],
      'SE' => [
        'Blekinge Lan' => 'Europe/Stockholm',
        'Gavleborgs Lan' => 'Europe/Stockholm',
        'Gotlands Lan' => 'Europe/Stockholm',
        'Hallands Lan' => 'Europe/Stockholm',
        'Jamtlands Lan' => 'Europe/Stockholm',
        'Jonkopings Lan' => 'Europe/Stockholm',
        'Kalmar Lan' => 'Europe/Stockholm',
        'Dalarnas Lan' => 'Europe/Stockholm',
        'Kronobergs Lan' => 'Europe/Stockholm',
        'Norrbottens Lan' => 'Europe/Stockholm',
        'Orebro Lan' => 'Europe/Stockholm',
        'Ostergotlands Lan' => 'Europe/Stockholm',
        'Sodermanlands Lan' => 'Europe/Stockholm',
        'Uppsala Lan' => 'Europe/Stockholm',
        'Varmlands Lan' => 'Europe/Stockholm',
        'Vasterbottens Lan' => 'Europe/Stockholm',
        'Vasternorrlands Lan' => 'Europe/Stockholm',
        'Vastmanlands Lan' => 'Europe/Stockholm',
        'Stockholms Lan' => 'Europe/Stockholm',
        'Skane Lan' => 'Europe/Stockholm',
        'Vastra Gotaland' => 'Europe/Stockholm',
      ],
      'SH' => [
        'Ascension' => 'Atlantic/St_Helena',
        'Saint Helena' => 'Atlantic/St_Helena',
        'Tristan da Cunha' => 'Atlantic/St_Helena',
      ],
      'SI' => [
        'Ajdovscina Commune' => 'Europe/Ljubljana',
        'Beltinci Commune' => 'Europe/Ljubljana',
        'Bled Commune' => 'Europe/Ljubljana',
        'Bohinj Commune' => 'Europe/Ljubljana',
        'Borovnica Commune' => 'Europe/Ljubljana',
        'Bovec Commune' => 'Europe/Ljubljana',
        'Brda Commune' => 'Europe/Ljubljana',
        'Brezice Commune' => 'Europe/Ljubljana',
        'Brezovica Commune' => 'Europe/Ljubljana',
        'Celje Commune' => 'Europe/Ljubljana',
        'Cerklje na Gorenjskem Commune' => 'Europe/Ljubljana',
        'Cerknica Commune' => 'Europe/Ljubljana',
        'Cerkno Commune' => 'Europe/Ljubljana',
        'Crensovci Commune' => 'Europe/Ljubljana',
        'Crna na Koroskem Commune' => 'Europe/Ljubljana',
        'Crnomelj Commune' => 'Europe/Ljubljana',
        'Divaca Commune' => 'Europe/Ljubljana',
        'Dobrepolje Commune' => 'Europe/Ljubljana',
        'Dol pri Ljubljani Commune' => 'Europe/Ljubljana',
        'Dornava Commune' => 'Europe/Ljubljana',
        'Dravograd Commune' => 'Europe/Ljubljana',
        'Duplek Commune' => 'Europe/Ljubljana',
        'Gorenja vas-Poljane Commune' => 'Europe/Ljubljana',
        'Gorisnica Commune' => 'Europe/Ljubljana',
        'Gornja Radgona Commune' => 'Europe/Ljubljana',
        'Gornji Grad Commune' => 'Europe/Ljubljana',
        'Gornji Petrovci Commune' => 'Europe/Ljubljana',
        'Grosuplje Commune' => 'Europe/Ljubljana',
        'Hrastnik Commune' => 'Europe/Ljubljana',
        'Hrpelje-Kozina Commune' => 'Europe/Ljubljana',
        'Idrija Commune' => 'Europe/Ljubljana',
        'Ig Commune' => 'Europe/Ljubljana',
        'Ilirska Bistrica Commune' => 'Europe/Ljubljana',
        'Ivancna Gorica Commune' => 'Europe/Ljubljana',
        'Izola-Isola Commune' => 'Europe/Ljubljana',
        'Jursinci Commune' => 'Europe/Ljubljana',
        'Kanal Commune' => 'Europe/Ljubljana',
        'Kidricevo Commune' => 'Europe/Ljubljana',
        'Kobarid Commune' => 'Europe/Ljubljana',
        'Kobilje Commune' => 'Europe/Ljubljana',
        'Komen Commune' => 'Europe/Ljubljana',
        'Koper-Capodistria Urban Commune' => 'Europe/Ljubljana',
        'Kozje Commune' => 'Europe/Ljubljana',
        'Kranj Commune' => 'Europe/Ljubljana',
        'Kranjska Gora Commune' => 'Europe/Ljubljana',
        'Krsko Commune' => 'Europe/Ljubljana',
        'Kungota Commune' => 'Europe/Ljubljana',
        'Lasko Commune' => 'Europe/Ljubljana',
        'Ljubljana Urban Commune' => 'Europe/Ljubljana',
        'Ljubno Commune' => 'Europe/Ljubljana',
        'Logatec Commune' => 'Europe/Ljubljana',
        'Loski Potok Commune' => 'Europe/Ljubljana',
        'Lukovica Commune' => 'Europe/Ljubljana',
        'Medvode Commune' => 'Europe/Ljubljana',
        'Menges Commune' => 'Europe/Ljubljana',
        'Metlika Commune' => 'Europe/Ljubljana',
        'Mezica Commune' => 'Europe/Ljubljana',
        'Mislinja Commune' => 'Europe/Ljubljana',
        'Moravce Commune' => 'Europe/Ljubljana',
        'Moravske Toplice Commune' => 'Europe/Ljubljana',
        'Mozirje Commune' => 'Europe/Ljubljana',
        'Murska Sobota Urban Commune' => 'Europe/Ljubljana',
        'Muta Commune' => 'Europe/Ljubljana',
        'Naklo Commune' => 'Europe/Ljubljana',
        'Nazarje Commune' => 'Europe/Ljubljana',
        'Nova Gorica Urban Commune' => 'Europe/Ljubljana',
        'Odranci Commune' => 'Europe/Ljubljana',
        'Ormoz Commune' => 'Europe/Ljubljana',
        'Osilnica Commune' => 'Europe/Ljubljana',
        'Pesnica Commune' => 'Europe/Ljubljana',
        'Pivka Commune' => 'Europe/Ljubljana',
        'Podcetrtek Commune' => 'Europe/Ljubljana',
        'Postojna Commune' => 'Europe/Ljubljana',
        'Puconci Commune' => 'Europe/Ljubljana',
        'Race-Fram Commune' => 'Europe/Ljubljana',
        'Radece Commune' => 'Europe/Ljubljana',
        'Radenci Commune' => 'Europe/Ljubljana',
        'Radlje ob Dravi Commune' => 'Europe/Ljubljana',
        'Radovljica Commune' => 'Europe/Ljubljana',
        'Rogasovci Commune' => 'Europe/Ljubljana',
        'Rogaska Slatina Commune' => 'Europe/Ljubljana',
        'Rogatec Commune' => 'Europe/Ljubljana',
        'Semic Commune' => 'Europe/Ljubljana',
        'Sencur Commune' => 'Europe/Ljubljana',
        'Sentilj Commune' => 'Europe/Ljubljana',
        'Sentjernej Commune' => 'Europe/Ljubljana',
        'Sevnica Commune' => 'Europe/Ljubljana',
        'Sezana Commune' => 'Europe/Ljubljana',
        'Skocjan Commune' => 'Europe/Ljubljana',
        'Skofja Loka Commune' => 'Europe/Ljubljana',
        'Skofljica Commune' => 'Europe/Ljubljana',
        'Slovenj Gradec Urban Commune' => 'Europe/Ljubljana',
        'Slovenske Konjice Commune' => 'Europe/Ljubljana',
        'Smarje pri Jelsah Commune' => 'Europe/Ljubljana',
        'Smartno ob Paki Commune' => 'Europe/Ljubljana',
        'Sostanj Commune' => 'Europe/Ljubljana',
        'Starse Commune' => 'Europe/Ljubljana',
        'Store Commune' => 'Europe/Ljubljana',
        'Sveti Jurij Commune' => 'Europe/Ljubljana',
        'Tolmin Commune' => 'Europe/Ljubljana',
        'Trbovlje Commune' => 'Europe/Ljubljana',
        'Trebnje Commune' => 'Europe/Ljubljana',
        'Trzic Commune' => 'Europe/Ljubljana',
        'Turnisce Commune' => 'Europe/Ljubljana',
        'Velenje Urban Commune' => 'Europe/Ljubljana',
        'Velike Lasce Commune' => 'Europe/Ljubljana',
        'Vipava Commune' => 'Europe/Ljubljana',
        'Vitanje Commune' => 'Europe/Ljubljana',
        'Vodice Commune' => 'Europe/Ljubljana',
        'Vrhnika Commune' => 'Europe/Ljubljana',
        'Vuzenica Commune' => 'Europe/Ljubljana',
        'Zagorje ob Savi Commune' => 'Europe/Ljubljana',
        'Zavrc Commune' => 'Europe/Ljubljana',
        'Zelezniki Commune' => 'Europe/Ljubljana',
        'Ziri Commune' => 'Europe/Ljubljana',
        'Zrece Commune' => 'Europe/Ljubljana',
        'Benedikt Commune' => 'Europe/Ljubljana',
        'Bistrica ob Sotli Commune' => 'Europe/Ljubljana',
        'Bloke Commune' => 'Europe/Ljubljana',
        'Braslovce Commune' => 'Europe/Ljubljana',
        'Cankova Commune' => 'Europe/Ljubljana',
        'Cerkvenjak Commune' => 'Europe/Ljubljana',
        'Destrnik Commune' => 'Europe/Ljubljana',
        'Dobje Commune' => 'Europe/Ljubljana',
        'Dobrna Commune' => 'Europe/Ljubljana',
        'Dobrova-Horjul-Polhov Gradec Commune' => 'Europe/Ljubljana',
        'Dobrovnik-Dobronak Commune' => 'Europe/Ljubljana',
        'Dolenjske Toplice Commune' => 'Europe/Ljubljana',
        'Domzale Commune' => 'Europe/Ljubljana',
        'Grad Commune' => 'Europe/Ljubljana',
        'Hajdina Commune' => 'Europe/Ljubljana',
        'Hoce-Slivnica Commune' => 'Europe/Ljubljana',
        'Hodos-Hodos Commune' => 'Europe/Ljubljana',
        'Horjul Commune' => 'Europe/Ljubljana',
        'Jesenice Commune' => 'Europe/Ljubljana',
        'Jezersko Commune' => 'Europe/Ljubljana',
        'Kamnik Commune' => 'Europe/Ljubljana',
        'Kocevje Commune' => 'Europe/Ljubljana',
        'Komenda Commune' => 'Europe/Ljubljana',
        'Kostel Commune' => 'Europe/Ljubljana',
        'Krizevci Commune' => 'Europe/Ljubljana',
        'Kuzma Commune' => 'Europe/Ljubljana',
        'Lenart Commune' => 'Europe/Ljubljana',
        'Lendava-Lendva Commune' => 'Europe/Ljubljana',
        'Litija Commune' => 'Europe/Ljubljana',
        'Ljutomer Commune' => 'Europe/Ljubljana',
        'Loska Dolina Commune' => 'Europe/Ljubljana',
        'Lovrenc na Pohorju Commune' => 'Europe/Ljubljana',
        'Luce Commune' => 'Europe/Ljubljana',
        'Majsperk Commune' => 'Europe/Ljubljana',
        'Maribor Commune' => 'Europe/Ljubljana',
        'Markovci Commune' => 'Europe/Ljubljana',
        'Miklavz na Dravskem polju Commune' => 'Europe/Ljubljana',
        'Miren-Kostanjevica Commune' => 'Europe/Ljubljana',
        'Mirna Pec Commune' => 'Europe/Ljubljana',
        'Novo mesto Urban Commune' => 'Europe/Ljubljana',
        'Oplotnica Commune' => 'Europe/Ljubljana',
        'Piran-Pirano Commune' => 'Europe/Ljubljana',
        'Podlehnik Commune' => 'Europe/Ljubljana',
        'Podvelka Commune' => 'Europe/Ljubljana',
        'Polzela Commune' => 'Europe/Ljubljana',
        'Prebold Commune' => 'Europe/Ljubljana',
        'Preddvor Commune' => 'Europe/Ljubljana',
        'Prevalje Commune' => 'Europe/Ljubljana',
        'Ptuj Urban Commune' => 'Europe/Ljubljana',
        'Ravne na Koroskem Commune' => 'Europe/Ljubljana',
        'Razkrizje Commune' => 'Europe/Ljubljana',
        'Ribnica Commune' => 'Europe/Ljubljana',
        'Ribnica na Pohorju Commune' => 'Europe/Ljubljana',
        'Ruse Commune' => 'Europe/Ljubljana',
        'Salovci Commune' => 'Europe/Ljubljana',
        'Selnica ob Dravi Commune' => 'Europe/Ljubljana',
        'Sempeter-Vrtojba Commune' => 'Europe/Ljubljana',
        'Sentjur pri Celju Commune' => 'Europe/Ljubljana',
        'Slovenska Bistrica Commune' => 'Europe/Ljubljana',
        'Smartno pri Litiji Commune' => 'Europe/Ljubljana',
        'Sodrazica Commune' => 'Europe/Ljubljana',
        'Solcava Commune' => 'Europe/Ljubljana',
        'Sveta Ana Commune' => 'Europe/Ljubljana',
        'Sveti Andraz v Slovenskih goricah Commune' => 'Europe/Ljubljana',
        'Tabor Commune' => 'Europe/Ljubljana',
        'Tisina Commune' => 'Europe/Ljubljana',
        'Trnovska vas Commune' => 'Europe/Ljubljana',
        'Trzin Commune' => 'Europe/Ljubljana',
        'Velika Polana Commune' => 'Europe/Ljubljana',
        'Verzej Commune' => 'Europe/Ljubljana',
        'Videm Commune' => 'Europe/Ljubljana',
        'Vojnik Commune' => 'Europe/Ljubljana',
        'Vransko Commune' => 'Europe/Ljubljana',
        'Zalec Commune' => 'Europe/Ljubljana',
        'Zetale Commune' => 'Europe/Ljubljana',
        'Zirovnica Commune' => 'Europe/Ljubljana',
        'Zuzemberk Commune' => 'Europe/Ljubljana',
        'Apace Commune' => 'Europe/Ljubljana',
        'Cirkulane Commune' => 'Europe/Ljubljana',
        'Gorje' => 'Europe/Ljubljana',
        'Kostanjevica na Krki' => 'Europe/Ljubljana',
        'Log-Dragomer' => 'Europe/Ljubljana',
        'Makole' => 'Europe/Ljubljana',
        'Mirna' => 'Europe/Ljubljana',
        'Mokronog-Trebelno' => 'Europe/Ljubljana',
        'Poljcane' => 'Europe/Ljubljana',
        'Recica ob Savinji' => 'Europe/Ljubljana',
        'Rence-Vogrsko' => 'Europe/Ljubljana',
        'Sentrupert' => 'Europe/Ljubljana',
        'Smarjesk Toplice' => 'Europe/Ljubljana',
        'Sredisce ob Dravi' => 'Europe/Ljubljana',
        'Straza' => 'Europe/Ljubljana',
        'Sveti Jurij v Slovenskih Goricah' => 'Europe/Ljubljana',
      ],
      'SK' => [
        'Banska Bystrica' => 'Europe/Bratislava',
        'Bratislava' => 'Europe/Bratislava',
        'Kosice' => 'Europe/Bratislava',
        'Nitra' => 'Europe/Bratislava',
        'Presov' => 'Europe/Bratislava',
        'Trencin' => 'Europe/Bratislava',
        'Trnava' => 'Europe/Bratislava',
        'Zilina' => 'Europe/Bratislava',
      ],
      'SL' => [
        'Eastern' => 'Africa/Freetown',
        'Northern' => 'Africa/Freetown',
        'Southern' => 'Africa/Freetown',
        'Western Area' => 'Africa/Freetown',
      ],
      'SM' => [
        'Acquaviva' => 'Europe/San_Marino',
        'Chiesanuova' => 'Europe/San_Marino',
        'Domagnano' => 'Europe/San_Marino',
        'Faetano' => 'Europe/San_Marino',
        'Fiorentino' => 'Europe/San_Marino',
        'Borgo Maggiore' => 'Europe/San_Marino',
        'San Marino' => 'Europe/San_Marino',
        'Monte Giardino' => 'Europe/San_Marino',
        'Serravalle' => 'Europe/San_Marino',
      ],
      'SN' => [
        'Dakar' => 'Africa/Dakar',
        'Diourbel' => 'Africa/Dakar',
        'Tambacounda' => 'Africa/Dakar',
        'Thies' => 'Africa/Dakar',
        'Fatick' => 'Africa/Dakar',
        'Kaolack' => 'Africa/Dakar',
        'Kolda' => 'Africa/Dakar',
        'Ziguinchor' => 'Africa/Dakar',
        'Louga' => 'Africa/Dakar',
        'Saint-Louis' => 'Africa/Dakar',
        'Matam' => 'Africa/Dakar',
      ],
      'SO' => [
        'Bakool' => 'Africa/Mogadishu',
        'Banaadir' => 'Africa/Mogadishu',
        'Bari' => 'Africa/Mogadishu',
        'Bay' => 'Africa/Mogadishu',
        'Galguduud' => 'Africa/Mogadishu',
        'Gedo' => 'Africa/Mogadishu',
        'Hiiraan' => 'Africa/Mogadishu',
        'Jubbada Dhexe' => 'Africa/Mogadishu',
        'Jubbada Hoose' => 'Africa/Mogadishu',
        'Mudug' => 'Africa/Mogadishu',
        'Nugaal' => 'Africa/Mogadishu',
        'Sanaag' => 'Africa/Mogadishu',
        'Shabeellaha Dhexe' => 'Africa/Mogadishu',
        'Shabeellaha Hoose' => 'Africa/Mogadishu',
        'Woqooyi Galbeed' => 'Africa/Mogadishu',
        'Togdheer' => 'Africa/Mogadishu',
        'Awdal' => 'Africa/Mogadishu',
        'Sool' => 'Africa/Mogadishu',
      ],
      'SR' => [
        'Brokopondo' => 'America/Paramaribo',
        'Commewijne' => 'America/Paramaribo',
        'Coronie' => 'America/Paramaribo',
        'Marowijne' => 'America/Paramaribo',
        'Nickerie' => 'America/Paramaribo',
        'Para' => 'America/Paramaribo',
        'Paramaribo' => 'America/Paramaribo',
        'Saramacca' => 'America/Paramaribo',
        'Sipaliwini' => 'America/Paramaribo',
        'Wanica' => 'America/Paramaribo',
      ],
      'SS' => [
        'Central Equatoria' => 'Africa/Juba',
        'Eastern Equatoria' => 'Africa/Juba',
        'Jonglei' => 'Africa/Juba',
        'Lakes' => 'Africa/Juba',
        'Northern Bahr el Ghazal' => 'Africa/Juba',
        'Unity' => 'Africa/Juba',
        'Upper Nile' => 'Africa/Juba',
        'Warrap' => 'Africa/Juba',
        'Western Bahr el Ghazal' => 'Africa/Juba',
        'Western Equatoria' => 'Africa/Juba',
      ],
      'ST' => [
        'Principe' => 'Africa/Sao_Tome',
        'Sao Tome' => 'Africa/Sao_Tome',
      ],
      'SV' => [
        'Ahuachapan' => 'America/El_Salvador',
        'Cabanas' => 'America/El_Salvador',
        'Chalatenango' => 'America/El_Salvador',
        'Cuscatlan' => 'America/El_Salvador',
        'La Libertad' => 'America/El_Salvador',
        'La Paz' => 'America/El_Salvador',
        'La Union' => 'America/El_Salvador',
        'Morazan' => 'America/El_Salvador',
        'San Miguel' => 'America/El_Salvador',
        'San Salvador' => 'America/El_Salvador',
        'Santa Ana' => 'America/El_Salvador',
        'San Vicente' => 'America/El_Salvador',
        'Sonsonate' => 'America/El_Salvador',
        'Usulutan' => 'America/El_Salvador',
      ],
      'SY' => [
        'Al Hasakah' => 'Asia/Damascus',
        'Al Ladhiqiyah' => 'Asia/Damascus',
        'Al Qunaytirah' => 'Asia/Damascus',
        'Ar Raqqah' => 'Asia/Damascus',
        "As Suwayda'" => 'Asia/Damascus',
        'Dar' => 'Asia/Damascus',
        'Dayr az Zawr' => 'Asia/Damascus',
        'Rif Dimashq' => 'Asia/Damascus',
        'Halab' => 'Asia/Damascus',
        'Hamah' => 'Asia/Damascus',
        'Hims' => 'Asia/Damascus',
        'Idlib' => 'Asia/Damascus',
        'Dimashq' => 'Asia/Damascus',
        'Tartus' => 'Asia/Damascus',
      ],
      'SZ' => [
        'Hhohho' => 'Africa/Mbabane',
        'Lubombo' => 'Africa/Mbabane',
        'Manzini' => 'Africa/Mbabane',
        'Shiselweni' => 'Africa/Mbabane',
        'Praslin' => 'Africa/Mbabane',
      ],
      'TD' => [
        'Batha' => 'Africa/Ndjamena',
        'Biltine' => 'Africa/Ndjamena',
        'Borkou-Ennedi-Tibesti' => 'Africa/Ndjamena',
        'Chari-Baguirmi' => 'Africa/Ndjamena',
        'Guera' => 'Africa/Ndjamena',
        'Kanem' => 'Africa/Ndjamena',
        'Lac' => 'Africa/Ndjamena',
        'Logone Occidental' => 'Africa/Ndjamena',
        'Logone Oriental' => 'Africa/Ndjamena',
        'Mayo-Kebbi' => 'Africa/Ndjamena',
        'Moyen-Chari' => 'Africa/Ndjamena',
        'Ouaddai' => 'Africa/Ndjamena',
        'Salamat' => 'Africa/Ndjamena',
        'Tandjile' => 'Africa/Ndjamena',
      ],
      'TG' => [
        'Centrale' => 'Africa/Lome',
        'Kara' => 'Africa/Lome',
        'Maritime' => 'Africa/Lome',
        'Plateaux' => 'Africa/Lome',
        'Savanes' => 'Africa/Lome',
      ],
      'TH' => [
        'Mae Hong Son' => 'Asia/Bangkok',
        'Chiang Mai' => 'Asia/Bangkok',
        'Chiang Rai' => 'Asia/Bangkok',
        'Nan' => 'Asia/Bangkok',
        'Lamphun' => 'Asia/Bangkok',
        'Lampang' => 'Asia/Bangkok',
        'Phrae' => 'Asia/Bangkok',
        'Tak' => 'Asia/Bangkok',
        'Sukhothai' => 'Asia/Bangkok',
        'Uttaradit' => 'Asia/Bangkok',
        'Kamphaeng Phet' => 'Asia/Bangkok',
        'Phitsanulok' => 'Asia/Bangkok',
        'Phichit' => 'Asia/Bangkok',
        'Phetchabun' => 'Asia/Bangkok',
        'Uthai Thani' => 'Asia/Bangkok',
        'Nakhon Sawan' => 'Asia/Bangkok',
        'Nong Khai' => 'Asia/Bangkok',
        'Loei' => 'Asia/Bangkok',
        'Sakon Nakhon' => 'Asia/Bangkok',
        'Nakhon Phanom' => 'Asia/Bangkok',
        'Khon Kaen' => 'Asia/Bangkok',
        'Kalasin' => 'Asia/Bangkok',
        'Maha Sarakham' => 'Asia/Bangkok',
        'Roi Et' => 'Asia/Bangkok',
        'Chaiyaphum' => 'Asia/Bangkok',
        'Nakhon Ratchasima' => 'Asia/Bangkok',
        'Buriram' => 'Asia/Bangkok',
        'Surin' => 'Asia/Bangkok',
        'Sisaket' => 'Asia/Bangkok',
        'Narathiwat' => 'Asia/Bangkok',
        'Chai Nat' => 'Asia/Bangkok',
        'Sing Buri' => 'Asia/Bangkok',
        'Lop Buri' => 'Asia/Bangkok',
        'Ang Thong' => 'Asia/Bangkok',
        'Phra Nakhon Si Ayutthaya' => 'Asia/Bangkok',
        'Saraburi' => 'Asia/Bangkok',
        'Nonthaburi' => 'Asia/Bangkok',
        'Pathum Thani' => 'Asia/Bangkok',
        'Krung Thep' => 'Asia/Bangkok',
        'Phayao' => 'Asia/Bangkok',
        'Samut Prakan' => 'Asia/Bangkok',
        'Nakhon Nayok' => 'Asia/Bangkok',
        'Chachoengsao' => 'Asia/Bangkok',
        'Prachin Buri' => 'Asia/Bangkok',
        'Chon Buri' => 'Asia/Bangkok',
        'Rayong' => 'Asia/Bangkok',
        'Chanthaburi' => 'Asia/Bangkok',
        'Trat' => 'Asia/Bangkok',
        'Kanchanaburi' => 'Asia/Bangkok',
        'Suphan Buri' => 'Asia/Bangkok',
        'Ratchaburi' => 'Asia/Bangkok',
        'Nakhon Pathom' => 'Asia/Bangkok',
        'Samut Songkhram' => 'Asia/Bangkok',
        'Samut Sakhon' => 'Asia/Bangkok',
        'Phetchaburi' => 'Asia/Bangkok',
        'Prachuap Khiri Khan' => 'Asia/Bangkok',
        'Chumphon' => 'Asia/Bangkok',
        'Ranong' => 'Asia/Bangkok',
        'Surat Thani' => 'Asia/Bangkok',
        'Phangnga' => 'Asia/Bangkok',
        'Phuket' => 'Asia/Bangkok',
        'Krabi' => 'Asia/Bangkok',
        'Nakhon Si Thammarat' => 'Asia/Bangkok',
        'Trang' => 'Asia/Bangkok',
        'Phatthalung' => 'Asia/Bangkok',
        'Satun' => 'Asia/Bangkok',
        'Songkhla' => 'Asia/Bangkok',
        'Pattani' => 'Asia/Bangkok',
        'Yala' => 'Asia/Bangkok',
        'Ubon Ratchathani' => 'Asia/Bangkok',
        'Yasothon' => 'Asia/Bangkok',
        'Udon Thani' => 'Asia/Bangkok',
        'Amnat Charoen' => 'Asia/Bangkok',
        'Mukdahan' => 'Asia/Bangkok',
        'Nong Bua Lamphu' => 'Asia/Bangkok',
        'Sa Kaeo' => 'Asia/Bangkok',
        'Bueng Kan' => 'Asia/Bangkok',
      ],
      'TJ' => [
        'Kuhistoni Badakhshon' => 'Asia/Dushanbe',
        'Khatlon' => 'Asia/Dushanbe',
        'Sughd' => 'Asia/Dushanbe',
        'Dushanbe' => 'Asia/Dushanbe',
        'Nohiyahoi Tobei Jumhuri' => 'Asia/Dushanbe',
      ],
      'TL' => [
        'Dili' => 'Asia/Dili',
      ],
      'TM' => [
        'Ahal' => 'Asia/Ashgabat',
        'Balkan' => 'Asia/Ashgabat',
        'Dashoguz' => 'Asia/Ashgabat',
        'Lebap' => 'Asia/Ashgabat',
        'Mary' => 'Asia/Ashgabat',
      ],
      'TN' => [
        'Kasserine' => 'Africa/Tunis',
        'Kairouan' => 'Africa/Tunis',
        'Jendouba' => 'Africa/Tunis',
        'Qafsah' => 'Africa/Tunis',
        'El Kef' => 'Africa/Tunis',
        'Al Mahdia' => 'Africa/Tunis',
        'Al Munastir' => 'Africa/Tunis',
        'Bajah' => 'Africa/Tunis',
        'Bizerte' => 'Africa/Tunis',
        'Nabeul' => 'Africa/Tunis',
        'Siliana' => 'Africa/Tunis',
        'Sousse' => 'Africa/Tunis',
        'Ben Arous' => 'Africa/Tunis',
        'Madanin' => 'Africa/Tunis',
        'Gabes' => 'Africa/Tunis',
        'Kebili' => 'Africa/Tunis',
        'Sfax' => 'Africa/Tunis',
        'Sidi Bou Zid' => 'Africa/Tunis',
        'Tataouine' => 'Africa/Tunis',
        'Tozeur' => 'Africa/Tunis',
        'Tunis' => 'Africa/Tunis',
        'Zaghouan' => 'Africa/Tunis',
        'Aiana' => 'Africa/Tunis',
        'Manouba' => 'Africa/Tunis',
      ],
      'TO' => [
        'Ha' => 'Pacific/Tongatapu',
        'Tongatapu' => 'Pacific/Tongatapu',
        'Vava' => 'Pacific/Tongatapu',
      ],
      'TR' => [
        'Adiyaman' => 'Asia/Istanbul',
        'Afyonkarahisar' => 'Asia/Istanbul',
        'Agri' => 'Asia/Istanbul',
        'Amasya' => 'Asia/Istanbul',
        'Antalya' => 'Asia/Istanbul',
        'Artvin' => 'Asia/Istanbul',
        'Aydin' => 'Asia/Istanbul',
        'Balikesir' => 'Asia/Istanbul',
        'Bilecik' => 'Asia/Istanbul',
        'Bingol' => 'Asia/Istanbul',
        'Bitlis' => 'Asia/Istanbul',
        'Bolu' => 'Asia/Istanbul',
        'Burdur' => 'Asia/Istanbul',
        'Bursa' => 'Asia/Istanbul',
        'Canakkale' => 'Asia/Istanbul',
        'Corum' => 'Asia/Istanbul',
        'Denizli' => 'Asia/Istanbul',
        'Diyarbakir' => 'Asia/Istanbul',
        'Edirne' => 'Asia/Istanbul',
        'Elazig' => 'Asia/Istanbul',
        'Erzincan' => 'Asia/Istanbul',
        'Erzurum' => 'Asia/Istanbul',
        'Eskisehir' => 'Asia/Istanbul',
        'Giresun' => 'Asia/Istanbul',
        'Hatay' => 'Asia/Istanbul',
        'Mersin' => 'Asia/Istanbul',
        'Isparta' => 'Asia/Istanbul',
        'Istanbul' => 'Asia/Istanbul',
        'Izmir' => 'Asia/Istanbul',
        'Kastamonu' => 'Asia/Istanbul',
        'Kayseri' => 'Asia/Istanbul',
        'Kirklareli' => 'Asia/Istanbul',
        'Kirsehir' => 'Asia/Istanbul',
        'Kocaeli' => 'Asia/Istanbul',
        'Kutahya' => 'Asia/Istanbul',
        'Malatya' => 'Asia/Istanbul',
        'Manisa' => 'Asia/Istanbul',
        'Kahramanmaras' => 'Asia/Istanbul',
        'Mugla' => 'Asia/Istanbul',
        'Mus' => 'Asia/Istanbul',
        'Nevsehir' => 'Asia/Istanbul',
        'Ordu' => 'Asia/Istanbul',
        'Rize' => 'Asia/Istanbul',
        'Sakarya' => 'Asia/Istanbul',
        'Samsun' => 'Asia/Istanbul',
        'Sinop' => 'Asia/Istanbul',
        'Sivas' => 'Asia/Istanbul',
        'Tekirdag' => 'Asia/Istanbul',
        'Tokat' => 'Asia/Istanbul',
        'Trabzon' => 'Asia/Istanbul',
        'Tunceli' => 'Asia/Istanbul',
        'Sanliurfa' => 'Asia/Istanbul',
        'Usak' => 'Asia/Istanbul',
        'Van' => 'Asia/Istanbul',
        'Yozgat' => 'Asia/Istanbul',
        'Ankara' => 'Asia/Istanbul',
        'Gumushane' => 'Asia/Istanbul',
        'Hakkari' => 'Asia/Istanbul',
        'Konya' => 'Asia/Istanbul',
        'Mardin' => 'Asia/Istanbul',
        'Nigde' => 'Asia/Istanbul',
        'Siirt' => 'Asia/Istanbul',
        'Aksaray' => 'Asia/Istanbul',
        'Batman' => 'Asia/Istanbul',
        'Bayburt' => 'Asia/Istanbul',
        'Karaman' => 'Asia/Istanbul',
        'Kirikkale' => 'Asia/Istanbul',
        'Sirnak' => 'Asia/Istanbul',
        'Adana' => 'Asia/Istanbul',
        'Cankiri' => 'Asia/Istanbul',
        'Gaziantep' => 'Asia/Istanbul',
        'Kars' => 'Asia/Istanbul',
        'Zonguldak' => 'Asia/Istanbul',
        'Ardahan' => 'Asia/Istanbul',
        'Bartin' => 'Asia/Istanbul',
        'Igdir' => 'Asia/Istanbul',
        'Karabuk' => 'Asia/Istanbul',
        'Kilis' => 'Asia/Istanbul',
        'Osmaniye' => 'Asia/Istanbul',
        'Yalova' => 'Asia/Istanbul',
        'Duzce' => 'Asia/Istanbul',
      ],
      'TT' => [
        'Arima' => 'America/Port_of_Spain',
        'Caroni' => 'America/Port_of_Spain',
        'Mayaro' => 'America/Port_of_Spain',
        'Nariva' => 'America/Port_of_Spain',
        'Port-of-Spain' => 'America/Port_of_Spain',
        'Saint Andrew' => 'America/Port_of_Spain',
        'Saint David' => 'America/Port_of_Spain',
        'Saint George' => 'America/Port_of_Spain',
        'Saint Patrick' => 'America/Port_of_Spain',
        'San Fernando' => 'America/Port_of_Spain',
        'Tobago' => 'America/Port_of_Spain',
        'Victoria' => 'America/Port_of_Spain',
      ],
      'TW' => [
        'Fu-chien' => 'Asia/Taipei',
        'Kao-hsiung' => 'Asia/Taipei',
        "T'ai-pei" => 'Asia/Taipei',
        "T'ai-wan" => 'Asia/Taipei',
      ],
      'TZ' => [
        'Pwani' => 'Africa/Dar_es_Salaam',
        'Dodoma' => 'Africa/Dar_es_Salaam',
        'Iringa' => 'Africa/Dar_es_Salaam',
        'Kigoma' => 'Africa/Dar_es_Salaam',
        'Kilimanjaro' => 'Africa/Dar_es_Salaam',
        'Lindi' => 'Africa/Dar_es_Salaam',
        'Mara' => 'Africa/Dar_es_Salaam',
        'Mbeya' => 'Africa/Dar_es_Salaam',
        'Morogoro' => 'Africa/Dar_es_Salaam',
        'Mtwara' => 'Africa/Dar_es_Salaam',
        'Mwanza' => 'Africa/Dar_es_Salaam',
        'Pemba North' => 'Africa/Dar_es_Salaam',
        'Ruvuma' => 'Africa/Dar_es_Salaam',
        'Shinyanga' => 'Africa/Dar_es_Salaam',
        'Singida' => 'Africa/Dar_es_Salaam',
        'Tabora' => 'Africa/Dar_es_Salaam',
        'Tanga' => 'Africa/Dar_es_Salaam',
        'Kagera' => 'Africa/Dar_es_Salaam',
        'Pemba South' => 'Africa/Dar_es_Salaam',
        'Zanzibar Central' => 'Africa/Dar_es_Salaam',
        'Zanzibar North' => 'Africa/Dar_es_Salaam',
        'Dar es Salaam' => 'Africa/Dar_es_Salaam',
        'Rukwa' => 'Africa/Dar_es_Salaam',
        'Zanzibar Urban' => 'Africa/Dar_es_Salaam',
        'Arusha' => 'Africa/Dar_es_Salaam',
        'Manyara' => 'Africa/Dar_es_Salaam',
      ],
      'UA' => [
        "Cherkas'ka Oblast'" => 'Europe/Kiev',
        "Chernihivs'ka Oblast'" => 'Europe/Kiev',
        "Chernivets'ka Oblast'" => 'Europe/Uzhgorod',
        "Dnipropetrovs'ka Oblast'" => 'Europe/Zaporozhye',
        "Donets'ka Oblast'" => 'Europe/Zaporozhye',
        "Ivano-Frankivs'ka Oblast'" => 'Europe/Uzhgorod',
        "Kharkivs'ka Oblast'" => 'Europe/Zaporozhye',
        "Khersons'ka Oblast'" => 'Europe/Simferopol',
        "Khmel'nyts'ka Oblast'" => 'Europe/Kiev',
        "Kirovohrads'ka Oblast'" => 'Europe/Zaporozhye',
        'Krym' => 'Europe/Simferopol',
        'Kyyiv' => 'Europe/Kiev',
        "Kyyivs'ka Oblast'" => 'Europe/Kiev',
        "Luhans'ka Oblast'" => 'Europe/Zaporozhye',
        "L'vivs'ka Oblast'" => 'Europe/Uzhgorod',
        "Mykolayivs'ka Oblast'" => 'Europe/Zaporozhye',
        "Odes'ka Oblast'" => 'Europe/Simferopol',
        "Poltavs'ka Oblast'" => 'Europe/Zaporozhye',
        "Rivnens'ka Oblast'" => 'Europe/Kiev',
        "Sevastopol'" => 'Europe/Simferopol',
        "Sums'ka Oblast" => 'Europe/Kiev',
        "Ternopil's'ka Oblast'" => 'Europe/Uzhgorod',
        "Vinnyts'ka Oblast'" => 'Europe/Kiev',
        "Volyns'ka Oblast'" => 'Europe/Uzhgorod',
        "Zakarpats'ka Oblast'" => 'Europe/Uzhgorod',
        "Zaporiz'ka Oblast'" => 'Europe/Zaporozhye',
        "Zhytomyrs'ka Oblast'" => 'Europe/Kiev',
      ],
      'UG' => [
        'Apac' => 'Africa/Kampala',
        'Bundibugyo' => 'Africa/Kampala',
        'Bushenyi' => 'Africa/Kampala',
        'Gulu' => 'Africa/Kampala',
        'Hoima' => 'Africa/Kampala',
        'Jinja' => 'Africa/Kampala',
        'Kalangala' => 'Africa/Kampala',
        'Kampala' => 'Africa/Kampala',
        'Kamuli' => 'Africa/Kampala',
        'Kapchorwa' => 'Africa/Kampala',
        'Kasese' => 'Africa/Kampala',
        'Kibale' => 'Africa/Kampala',
        'Kiboga' => 'Africa/Kampala',
        'Kisoro' => 'Africa/Kampala',
        'Kotido' => 'Africa/Kampala',
        'Kumi' => 'Africa/Kampala',
        'Lira' => 'Africa/Kampala',
        'Masindi' => 'Africa/Kampala',
        'Mbarara' => 'Africa/Kampala',
        'Mubende' => 'Africa/Kampala',
        'Nebbi' => 'Africa/Kampala',
        'Ntungamo' => 'Africa/Kampala',
        'Pallisa' => 'Africa/Kampala',
        'Rakai' => 'Africa/Kampala',
        'Adjumani' => 'Africa/Kampala',
        'Bugiri' => 'Africa/Kampala',
        'Busia' => 'Africa/Kampala',
        'Katakwi' => 'Africa/Kampala',
        'Luwero' => 'Africa/Kampala',
        'Masaka' => 'Africa/Kampala',
        'Moyo' => 'Africa/Kampala',
        'Nakasongola' => 'Africa/Kampala',
        'Sembabule' => 'Africa/Kampala',
        'Tororo' => 'Africa/Kampala',
        'Arua' => 'Africa/Kampala',
        'Iganga' => 'Africa/Kampala',
        'Kabarole' => 'Africa/Kampala',
        'Kaberamaido' => 'Africa/Kampala',
        'Kamwenge' => 'Africa/Kampala',
        'Kanungu' => 'Africa/Kampala',
        'Kayunga' => 'Africa/Kampala',
        'Kitgum' => 'Africa/Kampala',
        'Kyenjojo' => 'Africa/Kampala',
        'Mayuge' => 'Africa/Kampala',
        'Mbale' => 'Africa/Kampala',
        'Moroto' => 'Africa/Kampala',
        'Mpigi' => 'Africa/Kampala',
        'Mukono' => 'Africa/Kampala',
        'Nakapiripirit' => 'Africa/Kampala',
        'Pader' => 'Africa/Kampala',
        'Rukungiri' => 'Africa/Kampala',
        'Sironko' => 'Africa/Kampala',
        'Soroti' => 'Africa/Kampala',
        'Wakiso' => 'Africa/Kampala',
        'Yumbe' => 'Africa/Kampala',
      ],
      'US' => [
        'Armed Forces Americas' => '',
        'Armed Forces Europe, Middle East, & Canada' => '',
        'Armed Forces Europe, Middle East, and Canada' => '',
        'Alaska' => 'America/Anchorage',
        'Alabama' => 'America/Chicago',
        'Armed Forces Pacific' => '',
        'Arkansas' => 'America/Chicago',
        'American Samoa' => 'Pacific/Pago_Pago',
        'Arizona' => 'America/Phoenix',
        'California' => 'America/Los_Angeles',
        'Colorado' => 'America/Denver',
        'Connecticut' => 'America/New_York',
        'District of Columbia' => 'America/New_York',
        'Delaware' => 'America/New_York',
        'Florida' => 'America/New_York',
        'Federated States of Micronesia' => 'Pacific/Pohnpei',
        'Georgia' => 'America/New_York',
        'Guam' => 'Pacific/Guam',
        'Hawaii' => 'Pacific/Honolulu',
        'Iowa' => 'America/Chicago',
        'Idaho' => 'America/Denver',
        'Illinois' => 'America/Chicago',
        'Indiana' => 'America/Indiana/Indianapolis',
        'Kansas' => 'America/Chicago',
        'Kentucky' => 'America/New_York',
        'Louisiana' => 'America/Chicago',
        'Massachusetts' => 'America/New_York',
        'Maryland' => 'America/New_York',
        'Maine' => 'America/New_York',
        'Marshall Islands' => 'Pacific/Kwajalei',
        'Michigan' => 'America/New_York',
        'Minnesota' => 'America/Chicago',
        'Missouri' => 'America/Chicago',
        'Northern Mariana Islands' => 'Pacific/Saipan',
        'Mississippi' => 'America/Chicago',
        'Montana' => 'America/Denver',
        'North Carolina' => 'America/New_York',
        'North Dakota' => 'America/Chicago',
        'Nebraska' => 'America/Chicago',
        'New Hampshire' => 'America/New_York',
        'New Jersey' => 'America/New_York',
        'New Mexico' => 'America/Denver',
        'Nevada' => 'America/Los_Angeles',
        'New York' => 'America/New_York',
        'Ohio' => 'America/New_York',
        'Oklahoma' => 'America/Chicago',
        'Oregon' => 'America/Los_Angeles',
        'Pennsylvania' => 'America/New_York',
        'Palau' => 'Pacific/Palau',
        'Rhode Island' => 'America/New_York',
        'South Carolina' => 'America/New_York',
        'South Dakota' => 'America/Chicago',
        'Tennessee' => 'America/Chicago',
        'Texas' => 'America/Chicago',
        'Utah' => 'America/Denver',
        'Virginia' => 'America/New_York',
        'Virgin Islands' => 'America/St_Thomas',
        'Vermont' => 'America/New_York',
        'Washington' => 'America/Los_Angeles',
        'Wisconsin' => 'America/Chicago',
        'West Virginia' => 'America/New_York',
        'Wyoming' => 'America/Denver',
      ],
      'UY' => [
        'Artigas' => 'America/Montevideo',
        'Canelones' => 'America/Montevideo',
        'Cerro Largo' => 'America/Montevideo',
        'Colonia' => 'America/Montevideo',
        'Durazno' => 'America/Montevideo',
        'Flores' => 'America/Montevideo',
        'Florida' => 'America/Montevideo',
        'Lavalleja' => 'America/Montevideo',
        'Maldonado' => 'America/Montevideo',
        'Montevideo' => 'America/Montevideo',
        'Paysandu' => 'America/Montevideo',
        'Rio Negro' => 'America/Montevideo',
        'Rivera' => 'America/Montevideo',
        'Rocha' => 'America/Montevideo',
        'Salto' => 'America/Montevideo',
        'San Jose' => 'America/Montevideo',
        'Soriano' => 'America/Montevideo',
        'Tacuarembo' => 'America/Montevideo',
        'Treinta y Tres' => 'America/Montevideo',
      ],
      'UZ' => [
        'Andijon' => 'Asia/Tashkent',
        'Bukhoro' => 'Asia/Samarkand',
        'Farghona' => 'Asia/Tashkent',
        'Jizzakh' => 'Asia/Samarkand',
        'Khorazm' => 'Asia/Samarkand',
        'Namangan' => 'Asia/Tashkent',
        'Nawoiy' => 'Asia/Samarkand',
        'Qashqadaryo' => 'Asia/Samarkand',
        'Qoraqalpoghiston' => 'Asia/Samarkand',
        'Samarqand' => 'Asia/Samarkand',
        'Sirdaryo' => 'Asia/Tashkent',
        'Surkhondaryo' => 'Asia/Samarkand',
        'Toshkent' => 'Asia/Tashkent',
        'Jizzax' => 'Asia/Samarkand',
      ],
      'VC' => [
        'Charlotte' => 'America/St_Vincent',
        'Saint Andrew' => 'America/St_Vincent',
        'Saint David' => 'America/St_Vincent',
        'Saint George' => 'America/St_Vincent',
        'Saint Patrick' => 'America/St_Vincent',
        'Grenadines' => 'America/St_Vincent',
      ],
      'VE' => [
        'Amazonas' => 'America/Caracas',
        'Anzoategui' => 'America/Caracas',
        'Apure' => 'America/Caracas',
        'Aragua' => 'America/Caracas',
        'Barinas' => 'America/Caracas',
        'Bolivar' => 'America/Caracas',
        'Carabobo' => 'America/Caracas',
        'Cojedes' => 'America/Caracas',
        'Delta Amacuro' => 'America/Caracas',
        'Falcon' => 'America/Caracas',
        'Guarico' => 'America/Caracas',
        'Lara' => 'America/Caracas',
        'Merida' => 'America/Caracas',
        'Miranda' => 'America/Caracas',
        'Monagas' => 'America/Caracas',
        'Nueva Esparta' => 'America/Caracas',
        'Portuguesa' => 'America/Caracas',
        'Sucre' => 'America/Caracas',
        'Tachira' => 'America/Caracas',
        'Trujillo' => 'America/Caracas',
        'Yaracuy' => 'America/Caracas',
        'Zulia' => 'America/Caracas',
        'Dependencias Federales' => 'America/Caracas',
        'Distrito Federal' => 'America/Caracas',
        'Vargas' => 'America/Caracas',
      ],
      'VN' => [
        'An Giang' => 'Asia/Phnom_Penh',
        'Ben Tre' => 'Asia/Phnom_Penh',
        'Cao Bang' => 'Asia/Phnom_Penh',
        'Dong Thap' => 'Asia/Phnom_Penh',
        'Hai Phong' => 'Asia/Phnom_Penh',
        'Ho Chi Minh' => 'Asia/Phnom_Penh',
        'Kien Giang' => 'Asia/Phnom_Penh',
        'Lam Dong' => 'Asia/Phnom_Penh',
        'Long An' => 'Asia/Phnom_Penh',
        'Quang Ninh' => 'Asia/Phnom_Penh',
        'Son La' => 'Asia/Phnom_Penh',
        'Tay Ninh' => 'Asia/Phnom_Penh',
        'Thanh Hoa' => 'Asia/Phnom_Penh',
        'Thai Binh' => 'Asia/Phnom_Penh',
        'Tien Giang' => 'Asia/Phnom_Penh',
        'Lang Son' => 'Asia/Phnom_Penh',
        'Dong Nai' => 'Asia/Phnom_Penh',
        'Ha Noi' => 'Asia/Phnom_Penh',
        'Ba Ria-Vung Tau' => 'Asia/Phnom_Penh',
        'Binh Dinh' => 'Asia/Phnom_Penh',
        'Binh Thuan' => 'Asia/Phnom_Penh',
        'Gia Lai' => 'Asia/Phnom_Penh',
        'Ha Giang' => 'Asia/Phnom_Penh',
        'Ha Tinh' => 'Asia/Phnom_Penh',
        'Hoa Binh' => 'Asia/Phnom_Penh',
        'Khanh Hoa' => 'Asia/Phnom_Penh',
        'Kon Tum' => 'Asia/Phnom_Penh',
        'Nghe An' => 'Asia/Phnom_Penh',
        'Ninh Binh' => 'Asia/Phnom_Penh',
        'Ninh Thuan' => 'Asia/Phnom_Penh',
        'Phu Yen' => 'Asia/Phnom_Penh',
        'Quang Binh' => 'Asia/Phnom_Penh',
        'Quang Ngai' => 'Asia/Phnom_Penh',
        'Quang Tri' => 'Asia/Phnom_Penh',
        'Soc Trang' => 'Asia/Phnom_Penh',
        'Thua Thien-Hue' => 'Asia/Phnom_Penh',
        'Tra Vinh' => 'Asia/Phnom_Penh',
        'Tuyen Quang' => 'Asia/Phnom_Penh',
        'Vinh Long' => 'Asia/Phnom_Penh',
        'Yen Bai' => 'Asia/Phnom_Penh',
        'Bac Giang' => 'Asia/Phnom_Penh',
        'Bac Kan' => 'Asia/Phnom_Penh',
        'Bac Lieu' => 'Asia/Phnom_Penh',
        'Bac Ninh' => 'Asia/Phnom_Penh',
        'Binh Duong' => 'Asia/Phnom_Penh',
        'Binh Phuoc' => 'Asia/Phnom_Penh',
        'Ca Mau' => 'Asia/Phnom_Penh',
        'Da Nang' => 'Asia/Phnom_Penh',
        'Hai Duong' => 'Asia/Phnom_Penh',
        'Ha Nam' => 'Asia/Phnom_Penh',
        'Hung Yen' => 'Asia/Phnom_Penh',
        'Nam Dinh' => 'Asia/Phnom_Penh',
        'Phu Tho' => 'Asia/Phnom_Penh',
        'Quang Nam' => 'Asia/Phnom_Penh',
        'Thai Nguyen' => 'Asia/Phnom_Penh',
        'Vinh Phuc' => 'Asia/Phnom_Penh',
        'Can Tho' => 'Asia/Phnom_Penh',
        'Dac Lak' => 'Asia/Phnom_Penh',
        'Lai Chau' => 'Asia/Phnom_Penh',
        'Lao Cai' => 'Asia/Phnom_Penh',
        'Dak Nong' => 'Asia/Phnom_Penh',
        'Dien Bien' => 'Asia/Phnom_Penh',
        'Hau Giang' => 'Asia/Phnom_Penh',
      ],
      'VU' => [
        'Ambrym' => 'Pacific/Efate',
        'Aoba' => 'Pacific/Efate',
        'Torba' => 'Pacific/Efate',
        'Efate' => 'Pacific/Efate',
        'Epi' => 'Pacific/Efate',
        'Malakula' => 'Pacific/Efate',
        'Paama' => 'Pacific/Efate',
        'Pentecote' => 'Pacific/Efate',
        'Sanma' => 'Pacific/Efate',
        'Shepherd' => 'Pacific/Efate',
        'Tafea' => 'Pacific/Efate',
        'Malampa' => 'Pacific/Efate',
        'Penama' => 'Pacific/Efate',
        'Shefa' => 'Pacific/Efate',
      ],
      'WS' => [
        'Aiga-i-le-Tai' => 'Pacific/Pago_Pago',
        'Atua' => 'Pacific/Pago_Pago',
        'Fa' => 'Pacific/Pago_Pago',
        'Gaga' => 'Pacific/Pago_Pago',
        'Va' => 'Pacific/Pago_Pago',
        'Gagaifomauga' => 'Pacific/Pago_Pago',
        'Palauli' => 'Pacific/Pago_Pago',
        'Satupa' => 'Pacific/Pago_Pago',
        'Tuamasaga' => 'Pacific/Pago_Pago',
        'Vaisigano' => 'Pacific/Pago_Pago',
      ],
      'YE' => [
        'Abyan' => 'Asia/Aden',
        'Adan' => 'Asia/Aden',
        'Al Mahrah' => 'Asia/Aden',
        'Hadramawt' => 'Asia/Aden',
        'Shabwah' => 'Asia/Aden',
        'Lahij' => 'Asia/Aden',
        "Al Bayda'" => 'Asia/Aden',
        'Al Hudaydah' => 'Asia/Aden',
        'Al Jawf' => 'Asia/Aden',
        'Al Mahwit' => 'Asia/Aden',
        'Dhamar' => 'Asia/Aden',
        'Hajjah' => 'Asia/Aden',
        'Ibb' => 'Asia/Aden',
        "Ma'rib" => 'Asia/Aden',
        "Sa'dah" => 'Asia/Aden',
        "San'a'" => 'Asia/Aden',
        'Taizz' => 'Asia/Aden',
        'Ad Dali' => 'Asia/Aden',
        'Amran' => 'Asia/Aden',
      ],
      'ZA' => [
        'North-Western Province' => 'Africa/Johannesburg',
        'KwaZulu-Natal' => 'Africa/Johannesburg',
        'Free State' => 'Africa/Johannesburg',
        'Eastern Cape' => 'Africa/Johannesburg',
        'Gauteng' => 'Africa/Johannesburg',
        'Mpumalanga' => 'Africa/Johannesburg',
        'Northern Cape' => 'Africa/Johannesburg',
        'Limpopo' => 'Africa/Johannesburg',
        'North-West' => 'Africa/Johannesburg',
        'Western Cape' => 'Africa/Johannesburg',
      ],
      'ZM' => [
        'Western' => 'Africa/Lusaka',
        'Central' => 'Africa/Lusaka',
        'Eastern' => 'Africa/Lusaka',
        'Luapula' => 'Africa/Lusaka',
        'Northern' => 'Africa/Lusaka',
        'North-Western' => 'Africa/Lusaka',
        'Southern' => 'Africa/Lusaka',
        'Copperbelt' => 'Africa/Lusaka',
        'Lusaka' => 'Africa/Lusaka',
      ],
      'ZW' => [
        'Manicaland' => 'Africa/Harare',
        'Midlands' => 'Africa/Harare',
        'Mashonaland Central' => 'Africa/Harare',
        'Mashonaland East' => 'Africa/Harare',
        'Mashonaland West' => 'Africa/Harare',
        'Matabeleland North' => 'Africa/Harare',
        'Matabeleland South' => 'Africa/Harare',
        'Masvingo' => 'Africa/Harare',
        'Bulawayo' => 'Africa/Harare',
        'Harare' => 'Africa/Harare',
      ],
    ];
  }

  /**
   * Loads the list of time zone based on region code.
   *
   * @return array
   *   List of time zone based on region code.
   */
  private function loadRegionCodeList() {
    return [
      'AD' => [
        '02' => 'Europe/Andorra',
        '03' => 'Europe/Andorra',
        '04' => 'Europe/Andorra',
        '05' => 'Europe/Andorra',
        '06' => 'Europe/Andorra',
        '07' => 'Europe/Andorra',
        '08' => 'Europe/Andorra',
      ],
      'AE' => [
        '01' => 'Asia/Dubai',
        '02' => 'Asia/Dubai',
        '03' => 'Asia/Dubai',
        '04' => 'Asia/Dubai',
        '05' => 'Asia/Dubai',
        '06' => 'Asia/Dubai',
        '07' => 'Asia/Dubai',
      ],
      'AF' => [
        '01' => 'Asia/Kabul',
        '02' => 'Asia/Kabul',
        '03' => 'Asia/Kabul',
        '05' => 'Asia/Kabul',
        '06' => 'Asia/Kabul',
        '07' => 'Asia/Kabul',
        '08' => 'Asia/Kabul',
        '09' => 'Asia/Kabul',
        '10' => 'Asia/Kabul',
        '11' => 'Asia/Kabul',
        '13' => 'Asia/Kabul',
        '14' => 'Asia/Kabul',
        '17' => 'Asia/Kabul',
        '18' => 'Asia/Kabul',
        '19' => 'Asia/Kabul',
        '23' => 'Asia/Kabul',
        '24' => 'Asia/Kabul',
        '26' => 'Asia/Kabul',
        '27' => 'Asia/Kabul',
        '28' => 'Asia/Kabul',
        '29' => 'Asia/Kabul',
        '30' => 'Asia/Kabul',
        '31' => 'Asia/Kabul',
        '32' => 'Asia/Kabul',
        '33' => 'Asia/Kabul',
        '34' => 'Asia/Kabul',
        '35' => 'Asia/Kabul',
        '36' => 'Asia/Kabul',
        '37' => 'Asia/Kabul',
        '38' => 'Asia/Kabul',
        '39' => 'Asia/Kabul',
        '40' => 'Asia/Kabul',
        '41' => 'Asia/Kabul',
        '42' => 'Asia/Kabul',
      ],
      'AG' => [
        '01' => 'America/Antigua',
        '03' => 'America/Antigua',
        '04' => 'America/Antigua',
        '05' => 'America/Antigua',
        '06' => 'America/Antigua',
        '07' => 'America/Antigua',
        '08' => 'America/Antigua',
        '09' => 'America/Antigua',
      ],
      'AL' => [
        '40' => 'Europe/Tirane',
        '41' => 'Europe/Tirane',
        '42' => 'Europe/Tirane',
        '43' => 'Europe/Tirane',
        '44' => 'Europe/Tirane',
        '45' => 'Europe/Tirane',
        '46' => 'Europe/Tirane',
        '47' => 'Europe/Tirane',
        '48' => 'Europe/Tirane',
        '49' => 'Europe/Tirane',
        '50' => 'Europe/Tirane',
        '51' => 'Europe/Tirane',
      ],
      'AM' => [
        '01' => 'Asia/Yerevan',
        '02' => 'Asia/Yerevan',
        '03' => 'Asia/Yerevan',
        '04' => 'Asia/Yerevan',
        '05' => 'Asia/Yerevan',
        '06' => 'Asia/Yerevan',
        '07' => 'Asia/Yerevan',
        '08' => 'Asia/Yerevan',
        '09' => 'Asia/Yerevan',
        '10' => 'Asia/Yerevan',
        '11' => 'Asia/Yerevan',
      ],
      'AO' => [
        '01' => 'Africa/Luanda',
        '02' => 'Africa/Luanda',
        '03' => 'Africa/Luanda',
        '04' => 'Africa/Luanda',
        '05' => 'Africa/Luanda',
        '06' => 'Africa/Luanda',
        '07' => 'Africa/Luanda',
        '08' => 'Africa/Luanda',
        '09' => 'Africa/Luanda',
        '12' => 'Africa/Luanda',
        '13' => 'Africa/Luanda',
        '14' => 'Africa/Luanda',
        '15' => 'Africa/Luanda',
        '16' => 'Africa/Luanda',
        '17' => 'Africa/Luanda',
        '18' => 'Africa/Luanda',
        '19' => 'Africa/Luanda',
        '20' => 'Africa/Luanda',
      ],
      'AR' => [
        '01' => 'America/Argentina/Buenos_Aires',
        '02' => 'America/Argentina/Catamarca',
        '03' => 'America/Argentina/Tucuman',
        '04' => 'America/Argentina/Rio_Gallegos',
        '05' => 'America/Argentina/Cordoba',
        '06' => 'America/Argentina/Tucuman',
        '07' => 'America/Argentina/Buenos_Aires',
        '08' => 'America/Argentina/Buenos_Aires',
        '09' => 'America/Argentina/Tucuman',
        '10' => 'America/Argentina/Jujuy',
        '11' => 'America/Argentina/San_Luis',
        '12' => 'America/Argentina/La_Rioja',
        '13' => 'America/Argentina/Mendoza',
        '14' => 'America/Argentina/Buenos_Aires',
        '15' => 'America/Argentina/San_Luis',
        '16' => 'America/Argentina/Buenos_Aires',
        '17' => 'America/Argentina/Salta',
        '18' => 'America/Argentina/San_Juan',
        '19' => 'America/Argentina/San_Luis',
        '20' => 'America/Argentina/Rio_Gallegos',
        '21' => 'America/Argentina/Buenos_Aires',
        '22' => 'America/Argentina/Catamarca',
        '23' => 'America/Argentina/Ushuaia',
        '24' => 'America/Argentina/Tucuman',
      ],
      'AT' => [
        '01' => 'Europe/Vienna',
        '02' => 'Europe/Vienna',
        '03' => 'Europe/Vienna',
        '04' => 'Europe/Vienna',
        '05' => 'Europe/Vienna',
        '06' => 'Europe/Vienna',
        '07' => 'Europe/Vienna',
        '08' => 'Europe/Vienna',
        '09' => 'Europe/Vienna',
      ],
      'AU' => [
        '01' => 'Australia/Sydney',
        '02' => 'Australia/Sydney',
        '03' => 'Australia/Darwin',
        '04' => 'Australia/Brisbane',
        '05' => 'Australia/Adelaide',
        '06' => 'Australia/Hobart',
        '07' => 'Australia/Melbourne',
        '08' => 'Australia/Perth',
      ],
      'AZ' => [
        '01' => 'Asia/Baku',
        '02' => 'Asia/Baku',
        '03' => 'Asia/Baku',
        '04' => 'Asia/Baku',
        '05' => 'Asia/Baku',
        '06' => 'Asia/Baku',
        '07' => 'Asia/Baku',
        '08' => 'Asia/Baku',
        '09' => 'Asia/Baku',
        '10' => 'Asia/Baku',
        '11' => 'Asia/Baku',
        '12' => 'Asia/Baku',
        '13' => 'Asia/Baku',
        '14' => 'Asia/Baku',
        '15' => 'Asia/Baku',
        '16' => 'Asia/Baku',
        '17' => 'Asia/Baku',
        '18' => 'Asia/Baku',
        '19' => 'Asia/Baku',
        '20' => 'Asia/Baku',
        '21' => 'Asia/Baku',
        '22' => 'Asia/Baku',
        '23' => 'Asia/Baku',
        '24' => 'Asia/Baku',
        '25' => 'Asia/Baku',
        '26' => 'Asia/Baku',
        '27' => 'Asia/Baku',
        '28' => 'Asia/Baku',
        '29' => 'Asia/Baku',
        '30' => 'Asia/Baku',
        '31' => 'Asia/Baku',
        '32' => 'Asia/Baku',
        '33' => 'Asia/Baku',
        '34' => 'Asia/Baku',
        '35' => 'Asia/Baku',
        '36' => 'Asia/Baku',
        '37' => 'Asia/Baku',
        '38' => 'Asia/Baku',
        '39' => 'Asia/Baku',
        '40' => 'Asia/Baku',
        '41' => 'Asia/Baku',
        '42' => 'Asia/Baku',
        '43' => 'Asia/Baku',
        '44' => 'Asia/Baku',
        '45' => 'Asia/Baku',
        '46' => 'Asia/Baku',
        '47' => 'Asia/Baku',
        '48' => 'Asia/Baku',
        '49' => 'Asia/Baku',
        '50' => 'Asia/Baku',
        '51' => 'Asia/Baku',
        '52' => 'Asia/Baku',
        '53' => 'Asia/Baku',
        '54' => 'Asia/Baku',
        '55' => 'Asia/Baku',
        '56' => 'Asia/Baku',
        '57' => 'Asia/Baku',
        '58' => 'Asia/Baku',
        '59' => 'Asia/Baku',
        '60' => 'Asia/Baku',
        '61' => 'Asia/Baku',
        '62' => 'Asia/Baku',
        '63' => 'Asia/Baku',
        '64' => 'Asia/Baku',
        '65' => 'Asia/Baku',
        '66' => 'Asia/Baku',
        '67' => 'Asia/Baku',
        '68' => 'Asia/Baku',
        '69' => 'Asia/Baku',
        '70' => 'Asia/Baku',
        '71' => 'Asia/Baku',
      ],
      'BA' => [
        '01' => 'Europe/Sarajevo',
        '03' => 'Europe/Sarajevo',
        '02' => 'Europe/Sarajevo',
      ],
      'BB' => [
        '01' => 'America/Barbados',
        '02' => 'America/Barbados',
        '03' => 'America/Barbados',
        '04' => 'America/Barbados',
        '05' => 'America/Barbados',
        '06' => 'America/Barbados',
        '07' => 'America/Barbados',
        '08' => 'America/Barbados',
        '09' => 'America/Barbados',
        '10' => 'America/Barbados',
        '11' => 'America/Barbados',
      ],
      'BD' => [
        '81' => 'Asia/Dhaka',
        '82' => 'Asia/Dhaka',
        '83' => 'Asia/Dhaka',
        '84' => 'Asia/Dhaka',
        '85' => 'Asia/Dhaka',
        '86' => 'Asia/Dhaka',
        '87' => 'Asia/Dhaka',
      ],
      'BE' => [
        '01' => 'Europe/Brussels',
        '03' => 'Europe/Brussels',
        '04' => 'Europe/Brussels',
        '05' => 'Europe/Brussels',
        '06' => 'Europe/Brussels',
        '07' => 'Europe/Brussels',
        '08' => 'Europe/Brussels',
        '09' => 'Europe/Brussels',
        '10' => 'Europe/Brussels',
        '11' => 'Europe/Brussels',
        '12' => 'Europe/Brussels',
        '13' => 'Europe/Brussels',
        '14' => 'Europe/Brussels',
      ],
      'BF' => [
        '15' => 'Africa/Ouagadougou',
        '19' => 'Africa/Ouagadougou',
        '20' => 'Africa/Ouagadougou',
        '21' => 'Africa/Ouagadougou',
        '28' => 'Africa/Ouagadougou',
        '33' => 'Africa/Ouagadougou',
        '34' => 'Africa/Ouagadougou',
        '36' => 'Africa/Ouagadougou',
        '40' => 'Africa/Ouagadougou',
        '42' => 'Africa/Ouagadougou',
        '44' => 'Africa/Ouagadougou',
        '45' => 'Africa/Ouagadougou',
        '46' => 'Africa/Ouagadougou',
        '47' => 'Africa/Ouagadougou',
        '48' => 'Africa/Ouagadougou',
        '49' => 'Africa/Ouagadougou',
        '50' => 'Africa/Ouagadougou',
        '51' => 'Africa/Ouagadougou',
        '52' => 'Africa/Ouagadougou',
        '53' => 'Africa/Ouagadougou',
        '54' => 'Africa/Ouagadougou',
        '55' => 'Africa/Ouagadougou',
        '56' => 'Africa/Ouagadougou',
        '57' => 'Africa/Ouagadougou',
        '58' => 'Africa/Ouagadougou',
        '59' => 'Africa/Ouagadougou',
        '60' => 'Africa/Ouagadougou',
        '61' => 'Africa/Ouagadougou',
        '62' => 'Africa/Ouagadougou',
        '63' => 'Africa/Ouagadougou',
        '64' => 'Africa/Ouagadougou',
        '65' => 'Africa/Ouagadougou',
        '66' => 'Africa/Ouagadougou',
        '67' => 'Africa/Ouagadougou',
        '68' => 'Africa/Ouagadougou',
        '69' => 'Africa/Ouagadougou',
        '70' => 'Africa/Ouagadougou',
        '71' => 'Africa/Ouagadougou',
        '72' => 'Africa/Ouagadougou',
        '73' => 'Africa/Ouagadougou',
        '74' => 'Africa/Ouagadougou',
        '75' => 'Africa/Ouagadougou',
        '76' => 'Africa/Ouagadougou',
        '77' => 'Africa/Ouagadougou',
        '78' => 'Africa/Ouagadougou',
      ],
      'BG' => [
        '33' => 'Europe/Sofia',
        '38' => 'Europe/Sofia',
        '39' => 'Europe/Sofia',
        '40' => 'Europe/Sofia',
        '41' => 'Europe/Sofia',
        '42' => 'Europe/Sofia',
        '43' => 'Europe/Sofia',
        '44' => 'Europe/Sofia',
        '45' => 'Europe/Sofia',
        '46' => 'Europe/Sofia',
        '47' => 'Europe/Sofia',
        '48' => 'Europe/Sofia',
        '49' => 'Europe/Sofia',
        '50' => 'Europe/Sofia',
        '51' => 'Europe/Sofia',
        '52' => 'Europe/Sofia',
        '53' => 'Europe/Sofia',
        '54' => 'Europe/Sofia',
        '55' => 'Europe/Sofia',
        '56' => 'Europe/Sofia',
        '57' => 'Europe/Sofia',
        '58' => 'Europe/Sofia',
        '59' => 'Europe/Sofia',
        '60' => 'Europe/Sofia',
        '61' => 'Europe/Sofia',
        '62' => 'Europe/Sofia',
        '63' => 'Europe/Sofia',
        '64' => 'Europe/Sofia',
        '65' => 'Europe/Sofia',
      ],
      'BH' => [
        '01' => 'Asia/Bahrain',
        '02' => 'Asia/Bahrain',
        '05' => 'Asia/Bahrain',
        '06' => 'Asia/Bahrain',
        '08' => 'Asia/Bahrain',
        '09' => 'Asia/Bahrain',
        '10' => 'Asia/Bahrain',
        '11' => 'Asia/Bahrain',
        '12' => 'Asia/Bahrain',
        '13' => 'Asia/Bahrain',
        '14' => 'Asia/Bahrain',
        '15' => 'Asia/Bahrain',
        '16' => 'Asia/Bahrain',
        '17' => 'Asia/Bahrain',
        '18' => 'Asia/Bahrain',
        '19' => 'Asia/Bahrain',
      ],
      'BI' => [
        '02' => 'Africa/Bujumbura',
        '09' => 'Africa/Bujumbura',
        '10' => 'Africa/Bujumbura',
        '11' => 'Africa/Bujumbura',
        '12' => 'Africa/Bujumbura',
        '13' => 'Africa/Bujumbura',
        '14' => 'Africa/Bujumbura',
        '15' => 'Africa/Bujumbura',
        '16' => 'Africa/Bujumbura',
        '17' => 'Africa/Bujumbura',
        '18' => 'Africa/Bujumbura',
        '19' => 'Africa/Bujumbura',
        '20' => 'Africa/Bujumbura',
        '21' => 'Africa/Bujumbura',
        '22' => 'Africa/Bujumbura',
        '23' => 'Africa/Bujumbura',
      ],
      'BJ' => [
        '07' => 'Africa/Porto-Novo',
        '08' => 'Africa/Porto-Novo',
        '09' => 'Africa/Porto-Novo',
        '10' => 'Africa/Porto-Novo',
        '11' => 'Africa/Porto-Novo',
        '12' => 'Africa/Porto-Novo',
        '13' => 'Africa/Porto-Novo',
        '14' => 'Africa/Porto-Novo',
        '15' => 'Africa/Porto-Novo',
        '16' => 'Africa/Porto-Novo',
        '17' => 'Africa/Porto-Novo',
        '18' => 'Africa/Porto-Novo',
      ],
      'BM' => [
        '01' => 'Atlantic/Bermuda',
        '02' => 'Atlantic/Bermuda',
        '03' => 'Atlantic/Bermuda',
        '04' => 'Atlantic/Bermuda',
        '05' => 'Atlantic/Bermuda',
        '06' => 'Atlantic/Bermuda',
        '07' => 'Atlantic/Bermuda',
        '08' => 'Atlantic/Bermuda',
        '09' => 'Atlantic/Bermuda',
        '10' => 'Atlantic/Bermuda',
        '11' => 'Atlantic/Bermuda',
      ],
      'BN' => [
        '07' => 'Asia/Brunei',
        '08' => 'Asia/Brunei',
        '09' => 'Asia/Brunei',
        '10' => 'Asia/Brunei',
        '11' => 'Asia/Brunei',
        '12' => 'Asia/Brunei',
        '13' => 'Asia/Brunei',
        '14' => 'Asia/Brunei',
        '15' => 'Asia/Brunei',
        '16' => 'Asia/Brunei',
        '17' => 'Asia/Brunei',
        '18' => 'Asia/Brunei',
      ],
      'BO' => [
        '01' => 'America/La_Paz',
        '02' => 'America/La_Paz',
        '03' => 'America/La_Paz',
        '04' => 'America/La_Paz',
        '05' => 'America/La_Paz',
        '06' => 'America/La_Paz',
        '07' => 'America/La_Paz',
        '08' => 'America/La_Paz',
        '09' => 'America/La_Paz',
      ],
      'BR' => [
        '01' => 'America/Rio_Branco',
        '02' => 'America/Maceio',
        '03' => 'America/Sao_Paulo',
        '04' => 'America/Manaus',
        '05' => 'America/Bahia',
        '06' => 'America/Fortaleza',
        '07' => 'America/Sao_Paulo',
        '08' => 'America/Sao_Paulo',
        '11' => 'America/Campo_Grande',
        '13' => 'America/Belem',
        '14' => 'America/Cuiaba',
        '15' => 'America/Sao_Paulo',
        '16' => 'America/Belem',
        '17' => 'America/Recife',
        '18' => 'America/Sao_Paulo',
        '20' => 'America/Fortaleza',
        '21' => 'America/Sao_Paulo',
        '22' => 'America/Recife',
        '23' => 'America/Sao_Paulo',
        '24' => 'America/Porto_Velho',
        '25' => 'America/Boa_Vista',
        '26' => 'America/Sao_Paulo',
        '27' => 'America/Sao_Paulo',
        '28' => 'America/Maceio',
        '29' => 'America/Sao_Paulo',
        '30' => 'America/Recife',
        '31' => 'America/Araguaina',
      ],
      'BS' => [
        '05' => 'America/Nassau',
        '06' => 'America/Nassau',
        '10' => 'America/Nassau',
        '13' => 'America/Nassau',
        '15' => 'America/Nassau',
        '16' => 'America/Nassau',
        '18' => 'America/Nassau',
        '22' => 'America/Nassau',
        '23' => 'America/Nassau',
        '24' => 'America/Nassau',
        '25' => 'America/Nassau',
        '26' => 'America/Nassau',
        '27' => 'America/Nassau',
        '28' => 'America/Nassau',
        '29' => 'America/Nassau',
        '30' => 'America/Nassau',
        '31' => 'America/Nassau',
        '32' => 'America/Nassau',
        '33' => 'America/Nassau',
        '34' => 'America/Nassau',
        '35' => 'America/Nassau',
      ],
      'BT' => [
        '05' => 'Asia/Thimphu',
        '06' => 'Asia/Thimphu',
        '07' => 'Asia/Thimphu',
        '08' => 'Asia/Thimphu',
        '09' => 'Asia/Thimphu',
        '10' => 'Asia/Thimphu',
        '11' => 'Asia/Thimphu',
        '12' => 'Asia/Thimphu',
        '13' => 'Asia/Thimphu',
        '14' => 'Asia/Thimphu',
        '15' => 'Asia/Thimphu',
        '16' => 'Asia/Thimphu',
        '17' => 'Asia/Thimphu',
        '18' => 'Asia/Thimphu',
        '19' => 'Asia/Thimphu',
        '20' => 'Asia/Thimphu',
        '21' => 'Asia/Thimphu',
        '22' => 'Asia/Thimphu',
      ],
      'BW' => [
        '01' => 'Africa/Gaborone',
        '03' => 'Africa/Gaborone',
        '04' => 'Africa/Gaborone',
        '05' => 'Africa/Gaborone',
        '06' => 'Africa/Gaborone',
        '08' => 'Africa/Gaborone',
        '09' => 'Africa/Gaborone',
        '10' => 'Africa/Gaborone',
        '11' => 'Africa/Gaborone',
      ],
      'BY' => [
        '01' => 'Europe/Minsk',
        '02' => 'Europe/Minsk',
        '03' => 'Europe/Minsk',
        '04' => 'Europe/Minsk',
        '05' => 'Europe/Minsk',
        '06' => 'Europe/Minsk',
        '07' => 'Europe/Minsk',
      ],
      'BZ' => [
        '01' => 'America/Belize',
        '02' => 'America/Belize',
        '03' => 'America/Belize',
        '04' => 'America/Belize',
        '05' => 'America/Belize',
        '06' => 'America/Belize',
      ],
      'CA' => [
        'AB' => 'America/Edmonton',
        'BC' => 'America/Vancouver',
        'MB' => 'America/Winnipeg',
        'NB' => 'America/Halifax',
        'NL' => 'America/St_Johns',
        'NS' => 'America/Halifax',
        'NT' => 'America/Yellowknife',
        'NU' => 'America/Rankin_Inlet',
        'ON' => 'America/Toronto',
        'PE' => 'America/Halifax',
        'QC' => 'America/Montreal',
        'SK' => 'America/Regina',
        'YT' => 'America/Whitehorse',
      ],
      'CD' => [
        '01' => 'Africa/Kinshasa',
        '02' => 'Africa/Kinshasa',
        '04' => 'Africa/Lubumbashi',
        '05' => 'Africa/Lubumbashi',
        '06' => 'Africa/Kinshasa',
        '08' => 'Africa/Kinshasa',
        '09' => 'Africa/Lubumbashi',
        '10' => 'Africa/Lubumbashi',
        '11' => 'Africa/Lubumbashi',
        '12' => 'Africa/Lubumbashi',
      ],
      'CF' => [
        '01' => 'Africa/Bangui',
        '02' => 'Africa/Bangui',
        '03' => 'Africa/Bangui',
        '04' => 'Africa/Bangui',
        '05' => 'Africa/Bangui',
        '06' => 'Africa/Bangui',
        '07' => 'Africa/Bangui',
        '08' => 'Africa/Bangui',
        '09' => 'Africa/Bangui',
        '11' => 'Africa/Bangui',
        '12' => 'Africa/Bangui',
        '13' => 'Africa/Bangui',
        '14' => 'Africa/Bangui',
        '15' => 'Africa/Bangui',
        '16' => 'Africa/Bangui',
        '17' => 'Africa/Bangui',
        '18' => 'Africa/Bangui',
      ],
      'CG' => [
        '01' => 'Africa/Brazzaville',
        '04' => 'Africa/Brazzaville',
        '05' => 'Africa/Brazzaville',
        '06' => 'Africa/Brazzaville',
        '07' => 'Africa/Brazzaville',
        '08' => 'Africa/Brazzaville',
        '10' => 'Africa/Brazzaville',
        '11' => 'Africa/Brazzaville',
        '12' => 'Africa/Brazzaville',
        '13' => 'Africa/Brazzaville',
        '14' => 'Africa/Brazzaville',
      ],
      'CH' => [
        '01' => 'Europe/Zurich',
        '02' => 'Europe/Zurich',
        '03' => 'Europe/Zurich',
        '04' => 'Europe/Zurich',
        '05' => 'Europe/Zurich',
        '06' => 'Europe/Zurich',
        '07' => 'Europe/Zurich',
        '08' => 'Europe/Zurich',
        '09' => 'Europe/Zurich',
        '10' => 'Europe/Zurich',
        '11' => 'Europe/Zurich',
        '12' => 'Europe/Zurich',
        '13' => 'Europe/Zurich',
        '14' => 'Europe/Zurich',
        '15' => 'Europe/Zurich',
        '16' => 'Europe/Zurich',
        '17' => 'Europe/Zurich',
        '18' => 'Europe/Zurich',
        '19' => 'Europe/Zurich',
        '20' => 'Europe/Zurich',
        '21' => 'Europe/Zurich',
        '22' => 'Europe/Zurich',
        '23' => 'Europe/Zurich',
        '24' => 'Europe/Zurich',
        '25' => 'Europe/Zurich',
        '26' => 'Europe/Zurich',
      ],
      'CI' => [
        '74' => 'Africa/Abidjan',
        '75' => 'Africa/Abidjan',
        '76' => 'Africa/Abidjan',
        '77' => 'Africa/Abidjan',
        '78' => 'Africa/Abidjan',
        '79' => 'Africa/Abidjan',
        '80' => 'Africa/Abidjan',
        '81' => 'Africa/Abidjan',
        '82' => 'Africa/Abidjan',
        '83' => 'Africa/Abidjan',
        '84' => 'Africa/Abidjan',
        '85' => 'Africa/Abidjan',
        '86' => 'Africa/Abidjan',
        '87' => 'Africa/Abidjan',
        '88' => 'Africa/Abidjan',
        '89' => 'Africa/Abidjan',
        '90' => 'Africa/Abidjan',
        '91' => 'Africa/Abidjan',
        '92' => 'Africa/Abidjan',
      ],
      'CL' => [
        '01' => 'America/Santiago',
        '02' => 'America/Santiago',
        '03' => 'America/Santiago',
        '04' => 'America/Santiago',
        '05' => 'America/Santiago',
        '06' => 'America/Santiago',
        '07' => 'America/Santiago',
        '08' => 'America/Santiago',
        '09' => 'America/Santiago',
        '10' => 'America/Santiago',
        '11' => 'America/Santiago',
        '12' => 'America/Santiago',
        '13' => 'America/Santiago',
        '14' => 'America/Santiago',
        '15' => 'America/Santiago',
        '16' => 'America/Santiago',
        '17' => 'America/Santiago',
      ],
      'CM' => [
        '04' => 'Africa/Lagos',
        '05' => 'Africa/Lagos',
        '07' => 'Africa/Lagos',
        '08' => 'Africa/Lagos',
        '09' => 'Africa/Lagos',
        '10' => 'Africa/Lagos',
        '11' => 'Africa/Lagos',
        '12' => 'Africa/Lagos',
        '13' => 'Africa/Lagos',
        '14' => 'Africa/Lagos',
      ],
      'CN' => [
        '01' => 'Asia/Shanghai',
        '02' => 'Asia/Shanghai',
        '03' => 'Asia/Shanghai',
        '04' => 'Asia/Shanghai',
        '05' => 'Asia/Harbin',
        '06' => 'Asia/Chongqing',
        '07' => 'Asia/Shanghai',
        '08' => 'Asia/Harbin',
        '09' => 'Asia/Shanghai',
        '10' => 'Asia/Shanghai',
        '11' => 'Asia/Chongqing',
        '12' => 'Asia/Shanghai',
        '13' => 'Asia/Urumqi',
        '14' => 'Asia/Chongqing',
        '15' => 'Asia/Chongqing',
        '16' => 'Asia/Chongqing',
        '18' => 'Asia/Chongqing',
        '19' => 'Asia/Harbin',
        '20' => 'Asia/Harbin',
        '21' => 'Asia/Chongqing',
        '22' => 'Asia/Harbin',
        '23' => 'Asia/Shanghai',
        '24' => 'Asia/Chongqing',
        '25' => 'Asia/Shanghai',
        '26' => 'Asia/Chongqing',
        '28' => 'Asia/Shanghai',
        '29' => 'Asia/Chongqing',
        '30' => 'Asia/Chongqing',
        '31' => 'Asia/Chongqing',
        '32' => 'Asia/Chongqing',
        '33' => 'Asia/Chongqing',
      ],
      'CO' => [
        '01' => 'America/Bogota',
        '02' => 'America/Bogota',
        '03' => 'America/Bogota',
        '04' => 'America/Bogota',
        '08' => 'America/Bogota',
        '09' => 'America/Bogota',
        '10' => 'America/Bogota',
        '11' => 'America/Bogota',
        '12' => 'America/Bogota',
        '14' => 'America/Bogota',
        '15' => 'America/Bogota',
        '16' => 'America/Bogota',
        '17' => 'America/Bogota',
        '19' => 'America/Bogota',
        '20' => 'America/Bogota',
        '21' => 'America/Bogota',
        '22' => 'America/Bogota',
        '23' => 'America/Bogota',
        '24' => 'America/Bogota',
        '25' => 'America/Bogota',
        '26' => 'America/Bogota',
        '27' => 'America/Bogota',
        '28' => 'America/Bogota',
        '29' => 'America/Bogota',
        '30' => 'America/Bogota',
        '31' => 'America/Bogota',
        '32' => 'America/Bogota',
        '33' => 'America/Bogota',
        '34' => 'America/Bogota',
        '35' => 'America/Bogota',
        '36' => 'America/Bogota',
        '37' => 'America/Bogota',
        '38' => 'America/Bogota',
      ],
      'CR' => [
        '01' => 'America/Costa_Rica',
        '02' => 'America/Costa_Rica',
        '03' => 'America/Costa_Rica',
        '04' => 'America/Costa_Rica',
        '06' => 'America/Costa_Rica',
        '07' => 'America/Costa_Rica',
        '08' => 'America/Costa_Rica',
      ],
      'CU' => [
        '01' => 'America/Havana',
        '02' => 'America/Havana',
        '03' => 'America/Havana',
        '04' => 'America/Havana',
        '05' => 'America/Havana',
        '07' => 'America/Havana',
        '08' => 'America/Havana',
        '09' => 'America/Havana',
        '10' => 'America/Havana',
        '11' => 'America/Havana',
        '12' => 'America/Havana',
        '13' => 'America/Havana',
        '14' => 'America/Havana',
        '15' => 'America/Havana',
        '16' => 'America/Havana',
      ],
      'CV' => [
        '01' => 'Atlantic/Cape_Verde',
        '02' => 'Atlantic/Cape_Verde',
        '04' => 'Atlantic/Cape_Verde',
        '05' => 'Atlantic/Cape_Verde',
        '07' => 'Atlantic/Cape_Verde',
        '08' => 'Atlantic/Cape_Verde',
        '10' => 'Atlantic/Cape_Verde',
        '11' => 'Atlantic/Cape_Verde',
        '13' => 'Atlantic/Cape_Verde',
        '14' => 'Atlantic/Cape_Verde',
        '15' => 'Atlantic/Cape_Verde',
        '16' => 'Atlantic/Cape_Verde',
        '17' => 'Atlantic/Cape_Verde',
        '18' => 'Atlantic/Cape_Verde',
        '19' => 'Atlantic/Cape_Verde',
        '20' => 'Atlantic/Cape_Verde',
      ],
      'CY' => [
        '01' => 'Asia/Nicosia',
        '02' => 'Asia/Nicosia',
        '03' => 'Asia/Nicosia',
        '04' => 'Asia/Nicosia',
        '05' => 'Asia/Nicosia',
        '06' => 'Asia/Nicosia',
      ],
      'CZ' => [
        '52' => 'Europe/Prague',
        '78' => 'Europe/Prague',
        '79' => 'Europe/Prague',
        '80' => 'Europe/Prague',
        '81' => 'Europe/Prague',
        '82' => 'Europe/Prague',
        '83' => 'Europe/Prague',
        '84' => 'Europe/Prague',
        '85' => 'Europe/Prague',
        '86' => 'Europe/Prague',
        '87' => 'Europe/Prague',
        '88' => 'Europe/Prague',
        '89' => 'Europe/Prague',
        '90' => 'Europe/Prague',
      ],
      'DE' => [
        '01' => 'Europe/Berlin',
        '02' => 'Europe/Berlin',
        '03' => 'Europe/Berlin',
        '04' => 'Europe/Berlin',
        '05' => 'Europe/Berlin',
        '06' => 'Europe/Berlin',
        '07' => 'Europe/Berlin',
        '08' => 'Europe/Berlin',
        '09' => 'Europe/Berlin',
        '10' => 'Europe/Berlin',
        '11' => 'Europe/Berlin',
        '12' => 'Europe/Berlin',
        '13' => 'Europe/Berlin',
        '14' => 'Europe/Berlin',
        '15' => 'Europe/Berlin',
        '16' => 'Europe/Berlin',
      ],
      'DJ' => [
        '01' => 'Africa/Djibouti',
        '04' => 'Africa/Djibouti',
        '05' => 'Africa/Djibouti',
        '06' => 'Africa/Djibouti',
        '07' => 'Africa/Djibouti',
        '08' => 'Africa/Djibouti',
      ],
      'DK' => [
        '17' => 'Europe/Copenhagen',
        '18' => 'Europe/Copenhagen',
        '19' => 'Europe/Copenhagen',
        '20' => 'Europe/Copenhagen',
        '21' => 'Europe/Copenhagen',
      ],
      'DM' => [
        '02' => 'America/Dominica',
        '03' => 'America/Dominica',
        '04' => 'America/Dominica',
        '05' => 'America/Dominica',
        '06' => 'America/Dominica',
        '07' => 'America/Dominica',
        '08' => 'America/Dominica',
        '09' => 'America/Dominica',
        '10' => 'America/Dominica',
        '11' => 'America/Dominica',
      ],
      'DO' => [
        '01' => 'America/Santo_Domingo',
        '02' => 'America/Santo_Domingo',
        '03' => 'America/Santo_Domingo',
        '04' => 'America/Santo_Domingo',
        '05' => 'America/Santo_Domingo',
        '06' => 'America/Santo_Domingo',
        '08' => 'America/Santo_Domingo',
        '09' => 'America/Santo_Domingo',
        '10' => 'America/Santo_Domingo',
        '11' => 'America/Santo_Domingo',
        '12' => 'America/Santo_Domingo',
        '14' => 'America/Santo_Domingo',
        '15' => 'America/Santo_Domingo',
        '16' => 'America/Santo_Domingo',
        '17' => 'America/Santo_Domingo',
        '18' => 'America/Santo_Domingo',
        '19' => 'America/Santo_Domingo',
        '20' => 'America/Santo_Domingo',
        '21' => 'America/Santo_Domingo',
        '23' => 'America/Santo_Domingo',
        '24' => 'America/Santo_Domingo',
        '25' => 'America/Santo_Domingo',
        '26' => 'America/Santo_Domingo',
        '27' => 'America/Santo_Domingo',
        '28' => 'America/Santo_Domingo',
        '29' => 'America/Santo_Domingo',
        '30' => 'America/Santo_Domingo',
        '31' => 'America/Santo_Domingo',
        '32' => 'America/Santo_Domingo',
        '33' => 'America/Santo_Domingo',
        '34' => 'America/Santo_Domingo',
        '35' => 'America/Santo_Domingo',
        '36' => 'America/Santo_Domingo',
        '37' => 'America/Santo_Domingo',
      ],
      'DZ' => [
        '01' => 'Africa/Algiers',
        '03' => 'Africa/Algiers',
        '04' => 'Africa/Algiers',
        '06' => 'Africa/Algiers',
        '07' => 'Africa/Algiers',
        '09' => 'Africa/Algiers',
        '10' => 'Africa/Algiers',
        '12' => 'Africa/Algiers',
        '13' => 'Africa/Algiers',
        '14' => 'Africa/Algiers',
        '15' => 'Africa/Algiers',
        '18' => 'Africa/Algiers',
        '19' => 'Africa/Algiers',
        '20' => 'Africa/Algiers',
        '21' => 'Africa/Algiers',
        '22' => 'Africa/Algiers',
        '23' => 'Africa/Algiers',
        '24' => 'Africa/Algiers',
        '25' => 'Africa/Algiers',
        '26' => 'Africa/Algiers',
        '27' => 'Africa/Algiers',
        '29' => 'Africa/Algiers',
        '30' => 'Africa/Algiers',
        '31' => 'Africa/Algiers',
        '33' => 'Africa/Algiers',
        '34' => 'Africa/Algiers',
        '35' => 'Africa/Algiers',
        '36' => 'Africa/Algiers',
        '37' => 'Africa/Algiers',
        '38' => 'Africa/Algiers',
        '39' => 'Africa/Algiers',
        '40' => 'Africa/Algiers',
        '41' => 'Africa/Algiers',
        '42' => 'Africa/Algiers',
        '43' => 'Africa/Algiers',
        '44' => 'Africa/Algiers',
        '45' => 'Africa/Algiers',
        '46' => 'Africa/Algiers',
        '47' => 'Africa/Algiers',
        '48' => 'Africa/Algiers',
        '49' => 'Africa/Algiers',
        '50' => 'Africa/Algiers',
        '51' => 'Africa/Algiers',
        '52' => 'Africa/Algiers',
        '53' => 'Africa/Algiers',
        '54' => 'Africa/Algiers',
        '55' => 'Africa/Algiers',
        '56' => 'Africa/Algiers',
      ],
      'EC' => [
        '01' => 'Pacific/Galapagos',
        '02' => 'America/Guayaquil',
        '03' => 'America/Guayaquil',
        '04' => 'America/Guayaquil',
        '05' => 'America/Guayaquil',
        '06' => 'America/Guayaquil',
        '07' => 'America/Guayaquil',
        '08' => 'America/Guayaquil',
        '09' => 'America/Guayaquil',
        '10' => 'America/Guayaquil',
        '11' => 'America/Guayaquil',
        '12' => 'America/Guayaquil',
        '13' => 'America/Guayaquil',
        '14' => 'America/Guayaquil',
        '15' => 'America/Guayaquil',
        '17' => 'America/Guayaquil',
        '18' => 'America/Guayaquil',
        '19' => 'America/Guayaquil',
        '20' => 'America/Guayaquil',
        '22' => 'America/Guayaquil',
        '23' => 'America/Guayaquil',
        '24' => 'America/Guayaquil',
      ],
      'EE' => [
        '01' => 'Europe/Tallinn',
        '02' => 'Europe/Tallinn',
        '03' => 'Europe/Tallinn',
        '04' => 'Europe/Tallinn',
        '05' => 'Europe/Tallinn',
        '06' => 'Europe/Tallinn',
        '07' => 'Europe/Tallinn',
        '08' => 'Europe/Tallinn',
        '09' => 'Europe/Tallinn',
        '10' => 'Europe/Tallinn',
        '11' => 'Europe/Tallinn',
        '12' => 'Europe/Tallinn',
        '13' => 'Europe/Tallinn',
        '14' => 'Europe/Tallinn',
        '15' => 'Europe/Tallinn',
        '16' => 'Europe/Tallinn',
        '17' => 'Europe/Tallinn',
        '18' => 'Europe/Tallinn',
        '19' => 'Europe/Tallinn',
        '20' => 'Europe/Tallinn',
        '21' => 'Europe/Tallinn',
      ],
      'EG' => [
        '01' => 'Africa/Cairo',
        '02' => 'Africa/Cairo',
        '03' => 'Africa/Cairo',
        '04' => 'Africa/Cairo',
        '05' => 'Africa/Cairo',
        '06' => 'Africa/Cairo',
        '07' => 'Africa/Cairo',
        '08' => 'Africa/Cairo',
        '09' => 'Africa/Cairo',
        '10' => 'Africa/Cairo',
        '11' => 'Africa/Cairo',
        '12' => 'Africa/Cairo',
        '13' => 'Africa/Cairo',
        '14' => 'Africa/Cairo',
        '15' => 'Africa/Cairo',
        '16' => 'Africa/Cairo',
        '17' => 'Africa/Cairo',
        '18' => 'Africa/Cairo',
        '19' => 'Africa/Cairo',
        '20' => 'Africa/Cairo',
        '21' => 'Africa/Cairo',
        '22' => 'Africa/Cairo',
        '23' => 'Africa/Cairo',
        '24' => 'Africa/Cairo',
        '26' => 'Africa/Cairo',
        '27' => 'Africa/Cairo',
        '28' => 'Africa/Cairo',
      ],
      'ER' => [
        '01' => 'Africa/Asmara',
        '02' => 'Africa/Asmara',
        '03' => 'Africa/Asmara',
        '04' => 'Africa/Asmara',
        '05' => 'Africa/Asmara',
        '06' => 'Africa/Asmara',
      ],
      'ES' => [
        '07' => 'Europe/Madrid',
        '27' => 'Europe/Madrid',
        '29' => 'Europe/Madrid',
        '31' => 'Europe/Madrid',
        '32' => 'Europe/Madrid',
        '34' => 'Europe/Madrid',
        '39' => 'Europe/Madrid',
        '51' => 'Africa/Ceuta',
        '52' => 'Europe/Madrid',
        '53' => 'Atlantic/Canary',
        '54' => 'Europe/Madrid',
        '55' => 'Europe/Madrid',
        '56' => 'Europe/Madrid',
        '57' => 'Europe/Madrid',
        '58' => 'Europe/Madrid',
        '59' => 'Europe/Madrid',
        '60' => 'Europe/Madrid',
      ],
      'ET' => [
        '44' => 'Africa/Addis_Ababa',
        '45' => 'Africa/Addis_Ababa',
        '46' => 'Africa/Addis_Ababa',
        '47' => 'Africa/Addis_Ababa',
        '48' => 'Africa/Addis_Ababa',
        '49' => 'Africa/Addis_Ababa',
        '50' => 'Africa/Addis_Ababa',
        '51' => 'Africa/Addis_Ababa',
        '52' => 'Africa/Addis_Ababa',
        '53' => 'Africa/Addis_Ababa',
        '54' => 'Africa/Addis_Ababa',
      ],
      'FI' => [
        '01' => 'Europe/Helsinki',
        '06' => 'Europe/Helsinki',
        '08' => 'Europe/Helsinki',
        '13' => 'Europe/Helsinki',
        '14' => 'Europe/Helsinki',
        '15' => 'Europe/Helsinki',
      ],
      'FJ' => [
        '01' => 'Pacific/Fiji',
        '02' => 'Pacific/Fiji',
        '03' => 'Pacific/Fiji',
        '04' => 'Pacific/Fiji',
        '05' => 'Pacific/Fiji',
      ],
      'FM' => [
        '01' => 'Pacific/Pohnpei',
        '02' => 'Pacific/Pohnpei',
        '03' => 'Pacific/Pohnpei',
        '04' => 'Pacific/Pohnpei',
      ],
      'FR' => [
        '97' => 'Europe/Paris',
        '98' => 'Europe/Paris',
        '99' => 'Europe/Paris',
        'A1' => 'Europe/Paris',
        'A2' => 'Europe/Paris',
        'A3' => 'Europe/Paris',
        'A4' => 'Europe/Paris',
        'A5' => 'Europe/Paris',
        'A6' => 'Europe/Paris',
        'A7' => 'Europe/Paris',
        'A8' => 'Europe/Paris',
        'A9' => 'Europe/Paris',
        'B1' => 'Europe/Paris',
        'B2' => 'Europe/Paris',
        'B3' => 'Europe/Paris',
        'B4' => 'Europe/Paris',
        'B5' => 'Europe/Paris',
        'B6' => 'Europe/Paris',
        'B7' => 'Europe/Paris',
        'B8' => 'Europe/Paris',
        'B9' => 'Europe/Paris',
        'C1' => 'Europe/Paris',
      ],
      'GA' => [
        '01' => 'Africa/Libreville',
        '02' => 'Africa/Libreville',
        '03' => 'Africa/Libreville',
        '04' => 'Africa/Libreville',
        '05' => 'Africa/Libreville',
        '06' => 'Africa/Libreville',
        '07' => 'Africa/Libreville',
        '08' => 'Africa/Libreville',
        '09' => 'Africa/Libreville',
      ],
      'GB' => [
        'A1' => 'Europe/London',
        'A2' => 'Europe/London',
        'A3' => 'Europe/London',
        'A4' => 'Europe/London',
        'A5' => 'Europe/London',
        'A6' => 'Europe/London',
        'A7' => 'Europe/London',
        'A8' => 'Europe/London',
        'A9' => 'Europe/London',
        'B1' => 'Europe/London',
        'B2' => 'Europe/London',
        'B3' => 'Europe/London',
        'B4' => 'Europe/London',
        'B5' => 'Europe/London',
        'B6' => 'Europe/London',
        'B7' => 'Europe/London',
        'B8' => 'Europe/London',
        'B9' => 'Europe/London',
        'C1' => 'Europe/London',
        'C2' => 'Europe/London',
        'C3' => 'Europe/London',
        'C4' => 'Europe/London',
        'C5' => 'Europe/London',
        'C6' => 'Europe/London',
        'C7' => 'Europe/London',
        'C8' => 'Europe/London',
        'C9' => 'Europe/London',
        'D1' => 'Europe/London',
        'D2' => 'Europe/London',
        'D3' => 'Europe/London',
        'D4' => 'Europe/London',
        'D5' => 'Europe/London',
        'D6' => 'Europe/London',
        'D7' => 'Europe/London',
        'D8' => 'Europe/London',
        'D9' => 'Europe/London',
        'E1' => 'Europe/London',
        'E2' => 'Europe/London',
        'E3' => 'Europe/London',
        'E4' => 'Europe/London',
        'E5' => 'Europe/London',
        'E6' => 'Europe/London',
        'E7' => 'Europe/London',
        'E8' => 'Europe/London',
        'E9' => 'Europe/London',
        'F1' => 'Europe/London',
        'F2' => 'Europe/London',
        'F3' => 'Europe/London',
        'F4' => 'Europe/London',
        'F5' => 'Europe/London',
        'F6' => 'Europe/London',
        'F7' => 'Europe/London',
        'F8' => 'Europe/London',
        'F9' => 'Europe/London',
        'G1' => 'Europe/London',
        'G2' => 'Europe/London',
        'G3' => 'Europe/London',
        'G4' => 'Europe/London',
        'G5' => 'Europe/London',
        'G6' => 'Europe/London',
        'G7' => 'Europe/London',
        'G8' => 'Europe/London',
        'G9' => 'Europe/London',
        'H1' => 'Europe/London',
        'H2' => 'Europe/London',
        'H3' => 'Europe/London',
        'H4' => 'Europe/London',
        'H5' => 'Europe/London',
        'H6' => 'Europe/London',
        'H7' => 'Europe/London',
        'H8' => 'Europe/London',
        'H9' => 'Europe/London',
        'I1' => 'Europe/London',
        'I2' => 'Europe/London',
        'I3' => 'Europe/London',
        'I4' => 'Europe/London',
        'I5' => 'Europe/London',
        'I6' => 'Europe/London',
        'I7' => 'Europe/London',
        'I8' => 'Europe/London',
        'I9' => 'Europe/London',
        'J1' => 'Europe/London',
        'J2' => 'Europe/London',
        'J3' => 'Europe/London',
        'J4' => 'Europe/London',
        'J5' => 'Europe/London',
        'J6' => 'Europe/London',
        'J7' => 'Europe/London',
        'J8' => 'Europe/London',
        'J9' => 'Europe/London',
        'K1' => 'Europe/London',
        'K2' => 'Europe/London',
        'K3' => 'Europe/London',
        'K4' => 'Europe/London',
        'K5' => 'Europe/London',
        'K6' => 'Europe/London',
        'K7' => 'Europe/London',
        'K8' => 'Europe/London',
        'K9' => 'Europe/London',
        'L1' => 'Europe/London',
        'L2' => 'Europe/London',
        'L3' => 'Europe/London',
        'L4' => 'Europe/London',
        'L5' => 'Europe/London',
        'L6' => 'Europe/London',
        'L7' => 'Europe/London',
        'L8' => 'Europe/London',
        'L9' => 'Europe/London',
        'M1' => 'Europe/London',
        'M2' => 'Europe/London',
        'M3' => 'Europe/London',
        'M4' => 'Europe/London',
        'M5' => 'Europe/London',
        'M6' => 'Europe/London',
        'M7' => 'Europe/London',
        'M8' => 'Europe/London',
        'M9' => 'Europe/London',
        'N1' => 'Europe/London',
        'N2' => 'Europe/London',
        'N3' => 'Europe/London',
        'N4' => 'Europe/London',
        'N5' => 'Europe/London',
        'N6' => 'Europe/London',
        'N7' => 'Europe/London',
        'N8' => 'Europe/London',
        'N9' => 'Europe/London',
        'O1' => 'Europe/London',
        'O2' => 'Europe/London',
        'O3' => 'Europe/London',
        'O4' => 'Europe/London',
        'O5' => 'Europe/London',
        'O6' => 'Europe/London',
        'O7' => 'Europe/London',
        'O8' => 'Europe/London',
        'O9' => 'Europe/London',
        'P1' => 'Europe/London',
        'P2' => 'Europe/London',
        'P3' => 'Europe/London',
        'P4' => 'Europe/London',
        'P5' => 'Europe/London',
        'P6' => 'Europe/London',
        'P7' => 'Europe/London',
        'P8' => 'Europe/London',
        'P9' => 'Europe/London',
        'Q1' => 'Europe/London',
        'Q2' => 'Europe/London',
        'Q3' => 'Europe/London',
        'Q4' => 'Europe/London',
        'Q5' => 'Europe/London',
        'Q6' => 'Europe/London',
        'Q7' => 'Europe/London',
        'Q8' => 'Europe/London',
        'Q9' => 'Europe/London',
        'R1' => 'Europe/London',
        'R2' => 'Europe/London',
        'R3' => 'Europe/London',
        'R4' => 'Europe/London',
        'R5' => 'Europe/London',
        'R6' => 'Europe/London',
        'R7' => 'Europe/London',
        'R8' => 'Europe/London',
        'R9' => 'Europe/London',
        'S1' => 'Europe/London',
        'S2' => 'Europe/London',
        'S3' => 'Europe/London',
        'S4' => 'Europe/London',
        'S5' => 'Europe/London',
        'S6' => 'Europe/London',
        'S7' => 'Europe/London',
        'S8' => 'Europe/London',
        'S9' => 'Europe/London',
        'T1' => 'Europe/London',
        'T2' => 'Europe/London',
        'T3' => 'Europe/London',
        'T4' => 'Europe/London',
        'T5' => 'Europe/London',
        'T6' => 'Europe/London',
        'T7' => 'Europe/London',
        'T8' => 'Europe/London',
        'T9' => 'Europe/London',
        'U1' => 'Europe/London',
        'U2' => 'Europe/London',
        'U3' => 'Europe/London',
        'U4' => 'Europe/London',
        'U5' => 'Europe/London',
        'U6' => 'Europe/London',
        'U7' => 'Europe/London',
        'U8' => 'Europe/London',
        'U9' => 'Europe/London',
        'V1' => 'Europe/London',
        'V2' => 'Europe/London',
        'V3' => 'Europe/London',
        'V4' => 'Europe/London',
        'V5' => 'Europe/London',
        'V6' => 'Europe/London',
        'V7' => 'Europe/London',
        'V8' => 'Europe/London',
        'V9' => 'Europe/London',
        'W1' => 'Europe/London',
        'W2' => 'Europe/London',
        'W3' => 'Europe/London',
        'W4' => 'Europe/London',
        'W5' => 'Europe/London',
        'W6' => 'Europe/London',
        'W7' => 'Europe/London',
        'W8' => 'Europe/London',
        'W9' => 'Europe/London',
        'X1' => 'Europe/London',
        'X2' => 'Europe/London',
        'X3' => 'Europe/London',
        'X4' => 'Europe/London',
        'X5' => 'Europe/London',
        'X6' => 'Europe/London',
        'X7' => 'Europe/London',
        'X8' => 'Europe/London',
        'X9' => 'Europe/London',
        'Y1' => 'Europe/London',
        'Y2' => 'Europe/London',
        'Y3' => 'Europe/London',
        'Y4' => 'Europe/London',
        'Y5' => 'Europe/London',
        'Y6' => 'Europe/London',
        'Y7' => 'Europe/London',
        'Y8' => 'Europe/London',
        'Y9' => 'Europe/London',
        'Z1' => 'Europe/London',
        'Z2' => 'Europe/London',
        'Z3' => 'Europe/London',
        'Z4' => 'Europe/London',
        'Z5' => 'Europe/London',
        'Z6' => 'Europe/London',
        'Z7' => 'Europe/London',
        'Z8' => 'Europe/London',
        'Z9' => 'Europe/London',
      ],
      'GD' => [
        '01' => 'America/Grenada',
        '02' => 'America/Grenada',
        '03' => 'America/Grenada',
        '04' => 'America/Grenada',
        '05' => 'America/Grenada',
        '06' => 'America/Grenada',
      ],
      'GE' => [
        '01' => 'Asia/Tbilisi',
        '02' => 'Asia/Tbilisi',
        '03' => 'Asia/Tbilisi',
        '04' => 'Asia/Tbilisi',
        '05' => 'Asia/Tbilisi',
        '06' => 'Asia/Tbilisi',
        '07' => 'Asia/Tbilisi',
        '08' => 'Asia/Tbilisi',
        '09' => 'Asia/Tbilisi',
        '10' => 'Asia/Tbilisi',
        '11' => 'Asia/Tbilisi',
        '12' => 'Asia/Tbilisi',
        '13' => 'Asia/Tbilisi',
        '14' => 'Asia/Tbilisi',
        '15' => 'Asia/Tbilisi',
        '16' => 'Asia/Tbilisi',
        '17' => 'Asia/Tbilisi',
        '18' => 'Asia/Tbilisi',
        '19' => 'Asia/Tbilisi',
        '20' => 'Asia/Tbilisi',
        '21' => 'Asia/Tbilisi',
        '22' => 'Asia/Tbilisi',
        '23' => 'Asia/Tbilisi',
        '24' => 'Asia/Tbilisi',
        '25' => 'Asia/Tbilisi',
        '26' => 'Asia/Tbilisi',
        '27' => 'Asia/Tbilisi',
        '28' => 'Asia/Tbilisi',
        '29' => 'Asia/Tbilisi',
        '30' => 'Asia/Tbilisi',
        '31' => 'Asia/Tbilisi',
        '32' => 'Asia/Tbilisi',
        '33' => 'Asia/Tbilisi',
        '34' => 'Asia/Tbilisi',
        '35' => 'Asia/Tbilisi',
        '36' => 'Asia/Tbilisi',
        '37' => 'Asia/Tbilisi',
        '38' => 'Asia/Tbilisi',
        '39' => 'Asia/Tbilisi',
        '40' => 'Asia/Tbilisi',
        '41' => 'Asia/Tbilisi',
        '42' => 'Asia/Tbilisi',
        '43' => 'Asia/Tbilisi',
        '44' => 'Asia/Tbilisi',
        '45' => 'Asia/Tbilisi',
        '46' => 'Asia/Tbilisi',
        '47' => 'Asia/Tbilisi',
        '48' => 'Asia/Tbilisi',
        '49' => 'Asia/Tbilisi',
        '50' => 'Asia/Tbilisi',
        '51' => 'Asia/Tbilisi',
        '52' => 'Asia/Tbilisi',
        '53' => 'Asia/Tbilisi',
        '54' => 'Asia/Tbilisi',
        '55' => 'Asia/Tbilisi',
        '56' => 'Asia/Tbilisi',
        '57' => 'Asia/Tbilisi',
        '58' => 'Asia/Tbilisi',
        '59' => 'Asia/Tbilisi',
        '60' => 'Asia/Tbilisi',
        '61' => 'Asia/Tbilisi',
        '62' => 'Asia/Tbilisi',
        '63' => 'Asia/Tbilisi',
        '64' => 'Asia/Tbilisi',
      ],
      'GH' => [
        '01' => 'Africa/Accra',
        '02' => 'Africa/Accra',
        '03' => 'Africa/Accra',
        '04' => 'Africa/Accra',
        '05' => 'Africa/Accra',
        '06' => 'Africa/Accra',
        '08' => 'Africa/Accra',
        '09' => 'Africa/Accra',
        '10' => 'Africa/Accra',
        '11' => 'Africa/Accra',
      ],
      'GL' => [
        '01' => 'America/Thule',
        '02' => 'America/Godthab',
        '03' => 'America/Godthab',
      ],
      'GM' => [
        '01' => 'Africa/Banjul',
        '02' => 'Africa/Banjul',
        '03' => 'Africa/Banjul',
        '04' => 'Africa/Banjul',
        '05' => 'Africa/Banjul',
        '07' => 'Africa/Banjul',
      ],
      'GN' => [
        '01' => 'Africa/Conakry',
        '02' => 'Africa/Conakry',
        '03' => 'Africa/Conakry',
        '04' => 'Africa/Conakry',
        '05' => 'Africa/Conakry',
        '06' => 'Africa/Conakry',
        '07' => 'Africa/Conakry',
        '09' => 'Africa/Conakry',
        '10' => 'Africa/Conakry',
        '11' => 'Africa/Conakry',
        '12' => 'Africa/Conakry',
        '13' => 'Africa/Conakry',
        '15' => 'Africa/Conakry',
        '16' => 'Africa/Conakry',
        '17' => 'Africa/Conakry',
        '18' => 'Africa/Conakry',
        '19' => 'Africa/Conakry',
        '21' => 'Africa/Conakry',
        '22' => 'Africa/Conakry',
        '23' => 'Africa/Conakry',
        '25' => 'Africa/Conakry',
        '27' => 'Africa/Conakry',
        '28' => 'Africa/Conakry',
        '29' => 'Africa/Conakry',
        '30' => 'Africa/Conakry',
        '31' => 'Africa/Conakry',
        '32' => 'Africa/Conakry',
        '33' => 'Africa/Conakry',
        '34' => 'Africa/Conakry',
        '35' => 'Africa/Conakry',
        '36' => 'Africa/Conakry',
        '37' => 'Africa/Conakry',
        '38' => 'Africa/Conakry',
        '39' => 'Africa/Conakry',
      ],
      'GQ' => [
        '03' => 'Africa/Malabo',
        '04' => 'Africa/Malabo',
        '05' => 'Africa/Malabo',
        '06' => 'Africa/Malabo',
        '07' => 'Africa/Malabo',
        '08' => 'Africa/Malabo',
        '09' => 'Africa/Malabo',
      ],
      'GR' => [
        '01' => 'Europe/Athens',
        '02' => 'Europe/Athens',
        '03' => 'Europe/Athens',
        '04' => 'Europe/Athens',
        '05' => 'Europe/Athens',
        '06' => 'Europe/Athens',
        '07' => 'Europe/Athens',
        '08' => 'Europe/Athens',
        '09' => 'Europe/Athens',
        '10' => 'Europe/Athens',
        '11' => 'Europe/Athens',
        '12' => 'Europe/Athens',
        '13' => 'Europe/Athens',
        '14' => 'Europe/Athens',
        '15' => 'Europe/Athens',
        '16' => 'Europe/Athens',
        '17' => 'Europe/Athens',
        '18' => 'Europe/Athens',
        '19' => 'Europe/Athens',
        '20' => 'Europe/Athens',
        '21' => 'Europe/Athens',
        '22' => 'Europe/Athens',
        '23' => 'Europe/Athens',
        '24' => 'Europe/Athens',
        '25' => 'Europe/Athens',
        '26' => 'Europe/Athens',
        '27' => 'Europe/Athens',
        '28' => 'Europe/Athens',
        '29' => 'Europe/Athens',
        '30' => 'Europe/Athens',
        '31' => 'Europe/Athens',
        '32' => 'Europe/Athens',
        '33' => 'Europe/Athens',
        '34' => 'Europe/Athens',
        '35' => 'Europe/Athens',
        '36' => 'Europe/Athens',
        '37' => 'Europe/Athens',
        '38' => 'Europe/Athens',
        '39' => 'Europe/Athens',
        '40' => 'Europe/Athens',
        '41' => 'Europe/Athens',
        '42' => 'Europe/Athens',
        '43' => 'Europe/Athens',
        '44' => 'Europe/Athens',
        '45' => 'Europe/Athens',
        '46' => 'Europe/Athens',
        '47' => 'Europe/Athens',
        '48' => 'Europe/Athens',
        '49' => 'Europe/Athens',
        '50' => 'Europe/Athens',
        '51' => 'Europe/Athens',
      ],
      'GT' => [
        '01' => 'America/Guatemala',
        '02' => 'America/Guatemala',
        '03' => 'America/Guatemala',
        '04' => 'America/Guatemala',
        '05' => 'America/Guatemala',
        '06' => 'America/Guatemala',
        '07' => 'America/Guatemala',
        '08' => 'America/Guatemala',
        '09' => 'America/Guatemala',
        '10' => 'America/Guatemala',
        '11' => 'America/Guatemala',
        '12' => 'America/Guatemala',
        '13' => 'America/Guatemala',
        '14' => 'America/Guatemala',
        '15' => 'America/Guatemala',
        '16' => 'America/Guatemala',
        '17' => 'America/Guatemala',
        '18' => 'America/Guatemala',
        '19' => 'America/Guatemala',
        '20' => 'America/Guatemala',
        '21' => 'America/Guatemala',
        '22' => 'America/Guatemala',
      ],
      'GW' => [
        '01' => 'Africa/Bissau',
        '02' => 'Africa/Bissau',
        '04' => 'Africa/Bissau',
        '05' => 'Africa/Bissau',
        '06' => 'Africa/Bissau',
        '07' => 'Africa/Bissau',
        '10' => 'Africa/Bissau',
        '11' => 'Africa/Bissau',
        '12' => 'Africa/Bissau',
      ],
      'GY' => [
        '10' => 'America/Guyana',
        '11' => 'America/Guyana',
        '12' => 'America/Guyana',
        '13' => 'America/Guyana',
        '14' => 'America/Guyana',
        '15' => 'America/Guyana',
        '16' => 'America/Guyana',
        '17' => 'America/Guyana',
        '18' => 'America/Guyana',
        '19' => 'America/Guyana',
      ],
      'HN' => [
        '01' => 'America/Tegucigalpa',
        '02' => 'America/Tegucigalpa',
        '03' => 'America/Tegucigalpa',
        '04' => 'America/Tegucigalpa',
        '05' => 'America/Tegucigalpa',
        '06' => 'America/Tegucigalpa',
        '07' => 'America/Tegucigalpa',
        '08' => 'America/Tegucigalpa',
        '09' => 'America/Tegucigalpa',
        '10' => 'America/Tegucigalpa',
        '11' => 'America/Tegucigalpa',
        '12' => 'America/Tegucigalpa',
        '13' => 'America/Tegucigalpa',
        '14' => 'America/Tegucigalpa',
        '15' => 'America/Tegucigalpa',
        '16' => 'America/Tegucigalpa',
        '17' => 'America/Tegucigalpa',
        '18' => 'America/Tegucigalpa',
      ],
      'HR' => [
        '01' => 'Europe/Zagreb',
        '02' => 'Europe/Zagreb',
        '03' => 'Europe/Zagreb',
        '04' => 'Europe/Zagreb',
        '05' => 'Europe/Zagreb',
        '06' => 'Europe/Zagreb',
        '07' => 'Europe/Zagreb',
        '08' => 'Europe/Zagreb',
        '09' => 'Europe/Zagreb',
        '10' => 'Europe/Zagreb',
        '11' => 'Europe/Zagreb',
        '12' => 'Europe/Zagreb',
        '13' => 'Europe/Zagreb',
        '14' => 'Europe/Zagreb',
        '15' => 'Europe/Zagreb',
        '16' => 'Europe/Zagreb',
        '17' => 'Europe/Zagreb',
        '18' => 'Europe/Zagreb',
        '19' => 'Europe/Zagreb',
        '20' => 'Europe/Zagreb',
        '21' => 'Europe/Zagreb',
      ],
      'HT' => [
        '03' => 'America/Port-au-Prince',
        '06' => 'America/Port-au-Prince',
        '07' => 'America/Port-au-Prince',
        '09' => 'America/Port-au-Prince',
        '10' => 'America/Port-au-Prince',
        '11' => 'America/Port-au-Prince',
        '12' => 'America/Port-au-Prince',
        '13' => 'America/Port-au-Prince',
        '14' => 'America/Port-au-Prince',
        '15' => 'America/Port-au-Prince',
      ],
      'HU' => [
        '01' => 'Europe/Budapest',
        '02' => 'Europe/Budapest',
        '03' => 'Europe/Budapest',
        '04' => 'Europe/Budapest',
        '05' => 'Europe/Budapest',
        '06' => 'Europe/Budapest',
        '07' => 'Europe/Budapest',
        '08' => 'Europe/Budapest',
        '09' => 'Europe/Budapest',
        '10' => 'Europe/Budapest',
        '11' => 'Europe/Budapest',
        '12' => 'Europe/Budapest',
        '13' => 'Europe/Budapest',
        '14' => 'Europe/Budapest',
        '15' => 'Europe/Budapest',
        '16' => 'Europe/Budapest',
        '17' => 'Europe/Budapest',
        '18' => 'Europe/Budapest',
        '19' => 'Europe/Budapest',
        '20' => 'Europe/Budapest',
        '21' => 'Europe/Budapest',
        '22' => 'Europe/Budapest',
        '23' => 'Europe/Budapest',
        '24' => 'Europe/Budapest',
        '25' => 'Europe/Budapest',
        '26' => 'Europe/Budapest',
        '27' => 'Europe/Budapest',
        '28' => 'Europe/Budapest',
        '29' => 'Europe/Budapest',
        '30' => 'Europe/Budapest',
        '31' => 'Europe/Budapest',
        '32' => 'Europe/Budapest',
        '33' => 'Europe/Budapest',
        '34' => 'Europe/Budapest',
        '35' => 'Europe/Budapest',
        '36' => 'Europe/Budapest',
        '37' => 'Europe/Budapest',
        '38' => 'Europe/Budapest',
        '39' => 'Europe/Budapest',
        '40' => 'Europe/Budapest',
        '41' => 'Europe/Budapest',
        '42' => 'Europe/Budapest',
        '43' => 'Europe/Budapest',
      ],
      'ID' => [
        '01' => 'Asia/Pontianak',
        '02' => 'Asia/Makassar',
        '03' => 'Asia/Jakarta',
        '04' => 'Asia/Jakarta',
        '05' => 'Asia/Jakarta',
        '07' => 'Asia/Jakarta',
        '08' => 'Asia/Jakarta',
        '10' => 'Asia/Jakarta',
        '11' => 'Asia/Pontianak',
        '12' => 'Asia/Makassar',
        '13' => 'Asia/Makassar',
        '14' => 'Asia/Makassar',
        '15' => 'Asia/Jakarta',
        '17' => 'Asia/Makassar',
        '18' => 'Asia/Makassar',
        '21' => 'Asia/Makassar',
        '22' => 'Asia/Makassar',
        '24' => 'Asia/Jakarta',
        '26' => 'Asia/Pontianak',
        '28' => 'Asia/Jayapura',
        '29' => 'Asia/Makassar',
        '30' => 'Asia/Jakarta',
        '31' => 'Asia/Makassar',
        '32' => 'Asia/Jakarta',
        '33' => 'Asia/Jakarta',
        '34' => 'Asia/Makassar',
        '35' => 'Asia/Pontianak',
        '36' => 'Asia/Jayapura',
        '37' => 'Asia/Pontianak',
        '38' => 'Asia/Makassar',
        '39' => 'Asia/Jayapura',
        '40' => 'Asia/Pontianak',
        '41' => 'Asia/Makassar',
      ],
      'IE' => [
        '01' => 'Europe/Dublin',
        '02' => 'Europe/Dublin',
        '03' => 'Europe/Dublin',
        '04' => 'Europe/Dublin',
        '06' => 'Europe/Dublin',
        '07' => 'Europe/Dublin',
        '10' => 'Europe/Dublin',
        '11' => 'Europe/Dublin',
        '12' => 'Europe/Dublin',
        '13' => 'Europe/Dublin',
        '14' => 'Europe/Dublin',
        '15' => 'Europe/Dublin',
        '16' => 'Europe/Dublin',
        '18' => 'Europe/Dublin',
        '19' => 'Europe/Dublin',
        '20' => 'Europe/Dublin',
        '21' => 'Europe/Dublin',
        '22' => 'Europe/Dublin',
        '23' => 'Europe/Dublin',
        '24' => 'Europe/Dublin',
        '25' => 'Europe/Dublin',
        '26' => 'Europe/Dublin',
        '27' => 'Europe/Dublin',
        '29' => 'Europe/Dublin',
        '30' => 'Europe/Dublin',
        '31' => 'Europe/Dublin',
      ],
      'IL' => [
        '01' => 'Asia/Jerusalem',
        '02' => 'Asia/Jerusalem',
        '03' => 'Asia/Jerusalem',
        '04' => 'Asia/Jerusalem',
        '05' => 'Asia/Jerusalem',
        '06' => 'Asia/Jerusalem',
      ],
      'IN' => [
        '01' => 'Asia/Kolkata',
        '02' => 'Asia/Kolkata',
        '03' => 'Asia/Kolkata',
        '05' => 'Asia/Kolkata',
        '06' => 'Asia/Kolkata',
        '07' => 'Asia/Kolkata',
        '09' => 'Asia/Kolkata',
        '10' => 'Asia/Kolkata',
        '11' => 'Asia/Kolkata',
        '12' => 'Asia/Kolkata',
        '13' => 'Asia/Kolkata',
        '14' => 'Asia/Kolkata',
        '16' => 'Asia/Kolkata',
        '17' => 'Asia/Kolkata',
        '18' => 'Asia/Kolkata',
        '19' => 'Asia/Kolkata',
        '20' => 'Asia/Kolkata',
        '21' => 'Asia/Kolkata',
        '22' => 'Asia/Kolkata',
        '23' => 'Asia/Kolkata',
        '24' => 'Asia/Kolkata',
        '25' => 'Asia/Kolkata',
        '26' => 'Asia/Kolkata',
        '28' => 'Asia/Kolkata',
        '29' => 'Asia/Kolkata',
        '30' => 'Asia/Kolkata',
        '31' => 'Asia/Kolkata',
        '32' => 'Asia/Kolkata',
        '33' => 'Asia/Kolkata',
        '34' => 'Asia/Kolkata',
        '35' => 'Asia/Kolkata',
        '36' => 'Asia/Kolkata',
        '37' => 'Asia/Kolkata',
        '38' => 'Asia/Kolkata',
        '39' => 'Asia/Kolkata',
      ],
      'IQ' => [
        '01' => 'Asia/Baghdad',
        '02' => 'Asia/Baghdad',
        '03' => 'Asia/Baghdad',
        '04' => 'Asia/Baghdad',
        '05' => 'Asia/Baghdad',
        '06' => 'Asia/Baghdad',
        '07' => 'Asia/Baghdad',
        '08' => 'Asia/Baghdad',
        '09' => 'Asia/Baghdad',
        '10' => 'Asia/Baghdad',
        '11' => 'Asia/Baghdad',
        '12' => 'Asia/Baghdad',
        '13' => 'Asia/Baghdad',
        '14' => 'Asia/Baghdad',
        '15' => 'Asia/Baghdad',
        '16' => 'Asia/Baghdad',
        '17' => 'Asia/Baghdad',
        '18' => 'Asia/Baghdad',
      ],
      'IR' => [
        '01' => 'Asia/Tehran',
        '03' => 'Asia/Tehran',
        '04' => 'Asia/Tehran',
        '05' => 'Asia/Tehran',
        '07' => 'Asia/Tehran',
        '08' => 'Asia/Tehran',
        '09' => 'Asia/Tehran',
        '10' => 'Asia/Tehran',
        '11' => 'Asia/Tehran',
        '12' => 'Asia/Tehran',
        '13' => 'Asia/Tehran',
        '15' => 'Asia/Tehran',
        '16' => 'Asia/Tehran',
        '17' => 'Asia/Tehran',
        '18' => 'Asia/Tehran',
        '19' => 'Asia/Tehran',
        '21' => 'Asia/Tehran',
        '22' => 'Asia/Tehran',
        '23' => 'Asia/Tehran',
        '24' => 'Asia/Tehran',
        '25' => 'Asia/Tehran',
        '26' => 'Asia/Tehran',
        '27' => 'Asia/Tehran',
        '28' => 'Asia/Tehran',
        '29' => 'Asia/Tehran',
        '30' => 'Asia/Tehran',
        '31' => 'Asia/Tehran',
        '32' => 'Asia/Tehran',
        '33' => 'Asia/Tehran',
        '34' => 'Asia/Tehran',
        '35' => 'Asia/Tehran',
        '36' => 'Asia/Tehran',
        '37' => 'Asia/Tehran',
        '38' => 'Asia/Tehran',
        '39' => 'Asia/Tehran',
        '40' => 'Asia/Tehran',
        '41' => 'Asia/Tehran',
        '42' => 'Asia/Tehran',
        '43' => 'Asia/Tehran',
        '44' => 'Asia/Tehran',
      ],
      'IS' => [
        '03' => 'Atlantic/Reykjavik',
        '05' => 'Atlantic/Reykjavik',
        '06' => 'Atlantic/Reykjavik',
        '07' => 'Atlantic/Reykjavik',
        '09' => 'Atlantic/Reykjavik',
        '10' => 'Atlantic/Reykjavik',
        '15' => 'Atlantic/Reykjavik',
        '17' => 'Atlantic/Reykjavik',
        '20' => 'Atlantic/Reykjavik',
        '21' => 'Atlantic/Reykjavik',
        '23' => 'Atlantic/Reykjavik',
        '28' => 'Atlantic/Reykjavik',
        '29' => 'Atlantic/Reykjavik',
        '30' => 'Atlantic/Reykjavik',
        '31' => 'Atlantic/Reykjavik',
        '32' => 'Atlantic/Reykjavik',
        '34' => 'Atlantic/Reykjavik',
        '35' => 'Atlantic/Reykjavik',
        '36' => 'Atlantic/Reykjavik',
        '37' => 'Atlantic/Reykjavik',
        '38' => 'Atlantic/Reykjavik',
        '39' => 'Atlantic/Reykjavik',
        '40' => 'Atlantic/Reykjavik',
        '41' => 'Atlantic/Reykjavik',
        '42' => 'Atlantic/Reykjavik',
        '43' => 'Atlantic/Reykjavik',
        '44' => 'Atlantic/Reykjavik',
        '45' => 'Atlantic/Reykjavik',
      ],
      'IT' => [
        '01' => 'Europe/Rome',
        '02' => 'Europe/Rome',
        '03' => 'Europe/Rome',
        '04' => 'Europe/Rome',
        '05' => 'Europe/Rome',
        '06' => 'Europe/Rome',
        '07' => 'Europe/Rome',
        '08' => 'Europe/Rome',
        '09' => 'Europe/Rome',
        '10' => 'Europe/Rome',
        '11' => 'Europe/Rome',
        '12' => 'Europe/Rome',
        '13' => 'Europe/Rome',
        '14' => 'Europe/Rome',
        '15' => 'Europe/Rome',
        '16' => 'Europe/Rome',
        '17' => 'Europe/Rome',
        '18' => 'Europe/Rome',
        '19' => 'Europe/Rome',
        '20' => 'Europe/Rome',
      ],
      'JM' => [
        '01' => 'America/Jamaica',
        '02' => 'America/Jamaica',
        '04' => 'America/Jamaica',
        '07' => 'America/Jamaica',
        '08' => 'America/Jamaica',
        '09' => 'America/Jamaica',
        '10' => 'America/Jamaica',
        '11' => 'America/Jamaica',
        '12' => 'America/Jamaica',
        '13' => 'America/Jamaica',
        '14' => 'America/Jamaica',
        '15' => 'America/Jamaica',
        '16' => 'America/Jamaica',
        '17' => 'America/Jamaica',
      ],
      'JO' => [
        '02' => 'Asia/Amman',
        '09' => 'Asia/Amman',
        '12' => 'Asia/Amman',
        '15' => 'Asia/Amman',
        '16' => 'Asia/Amman',
        '17' => 'Asia/Amman',
        '18' => 'Asia/Amman',
        '19' => 'Asia/Amman',
        '20' => 'Asia/Amman',
        '21' => 'Asia/Amman',
        '22' => 'Asia/Amman',
        '23' => 'Asia/Amman',
      ],
      'JP' => [
        '01' => 'Asia/Tokyo',
        '02' => 'Asia/Tokyo',
        '03' => 'Asia/Tokyo',
        '04' => 'Asia/Tokyo',
        '05' => 'Asia/Tokyo',
        '06' => 'Asia/Tokyo',
        '07' => 'Asia/Tokyo',
        '08' => 'Asia/Tokyo',
        '09' => 'Asia/Tokyo',
        '10' => 'Asia/Tokyo',
        '11' => 'Asia/Tokyo',
        '12' => 'Asia/Tokyo',
        '13' => 'Asia/Tokyo',
        '14' => 'Asia/Tokyo',
        '15' => 'Asia/Tokyo',
        '16' => 'Asia/Tokyo',
        '17' => 'Asia/Tokyo',
        '18' => 'Asia/Tokyo',
        '19' => 'Asia/Tokyo',
        '20' => 'Asia/Tokyo',
        '21' => 'Asia/Tokyo',
        '22' => 'Asia/Tokyo',
        '23' => 'Asia/Tokyo',
        '24' => 'Asia/Tokyo',
        '25' => 'Asia/Tokyo',
        '26' => 'Asia/Tokyo',
        '27' => 'Asia/Tokyo',
        '28' => 'Asia/Tokyo',
        '29' => 'Asia/Tokyo',
        '30' => 'Asia/Tokyo',
        '31' => 'Asia/Tokyo',
        '32' => 'Asia/Tokyo',
        '33' => 'Asia/Tokyo',
        '34' => 'Asia/Tokyo',
        '35' => 'Asia/Tokyo',
        '36' => 'Asia/Tokyo',
        '37' => 'Asia/Tokyo',
        '38' => 'Asia/Tokyo',
        '39' => 'Asia/Tokyo',
        '40' => 'Asia/Tokyo',
        '41' => 'Asia/Tokyo',
        '42' => 'Asia/Tokyo',
        '43' => 'Asia/Tokyo',
        '44' => 'Asia/Tokyo',
        '45' => 'Asia/Tokyo',
        '46' => 'Asia/Tokyo',
        '47' => 'Asia/Tokyo',
      ],
      'KE' => [
        '01' => 'Africa/Nairobi',
        '02' => 'Africa/Nairobi',
        '03' => 'Africa/Nairobi',
        '05' => 'Africa/Nairobi',
        '06' => 'Africa/Nairobi',
        '07' => 'Africa/Nairobi',
        '08' => 'Africa/Nairobi',
        '09' => 'Africa/Nairobi',
      ],
      'KG' => [
        '01' => 'Asia/Bishkek',
        '02' => 'Asia/Bishkek',
        '03' => 'Asia/Bishkek',
        '04' => 'Asia/Bishkek',
        '05' => 'Asia/Bishkek',
        '06' => 'Asia/Bishkek',
        '07' => 'Asia/Bishkek',
        '08' => 'Asia/Bishkek',
        '09' => 'Asia/Bishkek',
      ],
      'KH' => [
        '01' => 'Asia/Phnom_Penh',
        '02' => 'Asia/Phnom_Penh',
        '03' => 'Asia/Phnom_Penh',
        '04' => 'Asia/Phnom_Penh',
        '05' => 'Asia/Phnom_Penh',
        '06' => 'Asia/Phnom_Penh',
        '07' => 'Asia/Phnom_Penh',
        '08' => 'Asia/Phnom_Penh',
        '09' => 'Asia/Phnom_Penh',
        '10' => 'Asia/Phnom_Penh',
        '11' => 'Asia/Phnom_Penh',
        '12' => 'Asia/Phnom_Penh',
        '13' => 'Asia/Phnom_Penh',
        '14' => 'Asia/Phnom_Penh',
        '15' => 'Asia/Phnom_Penh',
        '16' => 'Asia/Phnom_Penh',
        '17' => 'Asia/Phnom_Penh',
        '18' => 'Asia/Phnom_Penh',
        '19' => 'Asia/Phnom_Penh',
        '22' => 'Asia/Phnom_Penh',
        '23' => 'Asia/Phnom_Penh',
        '25' => 'Asia/Phnom_Penh',
        '28' => 'Asia/Phnom_Penh',
        '29' => 'Asia/Phnom_Penh',
        '30' => 'Asia/Phnom_Penh',
      ],
      'KI' => [
        '01' => 'Pacific/Tarawa',
        '02' => 'Pacific/Tarawa',
        '03' => 'Pacific/Tarawa',
      ],
      'KM' => [
        '01' => 'Indian/Comoro',
        '02' => 'Indian/Comoro',
        '03' => 'Indian/Comoro',
      ],
      'KN' => [
        '01' => 'America/St_Kitts',
        '02' => 'America/St_Kitts',
        '03' => 'America/St_Kitts',
        '04' => 'America/St_Kitts',
        '05' => 'America/St_Kitts',
        '06' => 'America/St_Kitts',
        '07' => 'America/St_Kitts',
        '08' => 'America/St_Kitts',
        '09' => 'America/St_Kitts',
        '10' => 'America/St_Kitts',
        '11' => 'America/St_Kitts',
        '12' => 'America/St_Kitts',
        '13' => 'America/St_Kitts',
        '15' => 'America/St_Kitts',
      ],
      'KP' => [
        '01' => 'Asia/Pyongyang',
        '03' => 'Asia/Pyongyang',
        '06' => 'Asia/Pyongyang',
        '07' => 'Asia/Pyongyang',
        '08' => 'Asia/Pyongyang',
        '09' => 'Asia/Pyongyang',
        '11' => 'Asia/Pyongyang',
        '12' => 'Asia/Pyongyang',
        '13' => 'Asia/Pyongyang',
        '14' => 'Asia/Pyongyang',
        '15' => 'Asia/Pyongyang',
        '17' => 'Asia/Pyongyang',
        '18' => 'Asia/Pyongyang',
      ],
      'KR' => [
        '01' => 'Asia/Seoul',
        '03' => 'Asia/Seoul',
        '05' => 'Asia/Seoul',
        '06' => 'Asia/Seoul',
        '10' => 'Asia/Seoul',
        '11' => 'Asia/Seoul',
        '12' => 'Asia/Seoul',
        '13' => 'Asia/Seoul',
        '14' => 'Asia/Seoul',
        '15' => 'Asia/Seoul',
        '16' => 'Asia/Seoul',
        '17' => 'Asia/Seoul',
        '18' => 'Asia/Seoul',
        '19' => 'Asia/Seoul',
        '20' => 'Asia/Seoul',
        '21' => 'Asia/Seoul',
      ],
      'KW' => [
        '01' => 'Asia/Kuwait',
        '02' => 'Asia/Kuwait',
        '05' => 'Asia/Kuwait',
        '07' => 'Asia/Kuwait',
        '08' => 'Asia/Kuwait',
        '09' => 'Asia/Kuwait',
      ],
      'KY' => [
        '01' => 'America/Cayman',
        '02' => 'America/Cayman',
        '03' => 'America/Cayman',
        '04' => 'America/Cayman',
        '05' => 'America/Cayman',
        '06' => 'America/Cayman',
        '07' => 'America/Cayman',
        '08' => 'America/Cayman',
      ],
      'KZ' => [
        '01' => 'Asia/Almaty',
        '02' => 'Asia/Almaty',
        '03' => 'Asia/Qyzylorda',
        '04' => 'Asia/Aqtobe',
        '05' => 'Asia/Qyzylorda',
        '06' => 'Asia/Aqtau',
        '07' => 'Asia/Oral',
        '08' => 'Asia/Qyzylorda',
        '09' => 'Asia/Aqtau',
        '10' => 'Asia/Qyzylorda',
        '11' => 'Asia/Almaty',
        '12' => 'Asia/Qyzylorda',
        '13' => 'Asia/Aqtobe',
        '14' => 'Asia/Qyzylorda',
        '15' => 'Asia/Almaty',
        '16' => 'Asia/Aqtobe',
        '17' => 'Asia/Almaty',
      ],
      'LA' => [
        '01' => 'Asia/Vientiane',
        '02' => 'Asia/Vientiane',
        '03' => 'Asia/Vientiane',
        '04' => 'Asia/Vientiane',
        '05' => 'Asia/Vientiane',
        '07' => 'Asia/Vientiane',
        '08' => 'Asia/Vientiane',
        '09' => 'Asia/Vientiane',
        '10' => 'Asia/Vientiane',
        '11' => 'Asia/Vientiane',
        '13' => 'Asia/Vientiane',
        '14' => 'Asia/Vientiane',
        '17' => 'Asia/Vientiane',
      ],
      'LB' => [
        '01' => 'Asia/Beirut',
        '02' => 'Asia/Beirut',
        '03' => 'Asia/Beirut',
        '04' => 'Asia/Beirut',
        '05' => 'Asia/Beirut',
        '06' => 'Asia/Beirut',
        '07' => 'Asia/Beirut',
        '08' => 'Asia/Beirut',
        '09' => 'Asia/Beirut',
        '10' => 'Asia/Beirut',
        '11' => 'Asia/Beirut',
      ],
      'LC' => [
        '01' => 'America/St_Lucia',
        '02' => 'America/St_Lucia',
        '03' => 'America/St_Lucia',
        '04' => 'America/St_Lucia',
        '05' => 'America/St_Lucia',
        '06' => 'America/St_Lucia',
        '07' => 'America/St_Lucia',
        '08' => 'America/St_Lucia',
        '09' => 'America/St_Lucia',
        '10' => 'America/St_Lucia',
        '11' => 'America/St_Lucia',
      ],
      'LI' => [
        '01' => 'Europe/Vaduz',
        '02' => 'Europe/Vaduz',
        '03' => 'Europe/Vaduz',
        '04' => 'Europe/Vaduz',
        '05' => 'Europe/Vaduz',
        '06' => 'Europe/Vaduz',
        '07' => 'Europe/Vaduz',
        '08' => 'Europe/Vaduz',
        '09' => 'Europe/Vaduz',
        '10' => 'Europe/Vaduz',
        '11' => 'Europe/Vaduz',
        '21' => 'Europe/Vaduz',
        '22' => 'Europe/Vaduz',
      ],
      'LK' => [
        '29' => 'Asia/Colombo',
        '30' => 'Asia/Colombo',
        '32' => 'Asia/Colombo',
        '33' => 'Asia/Colombo',
        '34' => 'Asia/Colombo',
        '35' => 'Asia/Colombo',
        '36' => 'Asia/Colombo',
        '37' => 'Asia/Colombo',
        '38' => 'Asia/Colombo',
      ],
      'LR' => [
        '01' => 'Africa/Monrovia',
        '04' => 'Africa/Monrovia',
        '05' => 'Africa/Monrovia',
        '06' => 'Africa/Monrovia',
        '07' => 'Africa/Monrovia',
        '09' => 'Africa/Monrovia',
        '10' => 'Africa/Monrovia',
        '11' => 'Africa/Monrovia',
        '12' => 'Africa/Monrovia',
        '13' => 'Africa/Monrovia',
        '14' => 'Africa/Monrovia',
        '17' => 'Africa/Monrovia',
        '18' => 'Africa/Monrovia',
        '19' => 'Africa/Monrovia',
        '20' => 'Africa/Monrovia',
        '21' => 'Africa/Monrovia',
        '22' => 'Africa/Monrovia',
      ],
      'LS' => [
        '10' => 'Africa/Maseru',
        '11' => 'Africa/Maseru',
        '12' => 'Africa/Maseru',
        '13' => 'Africa/Maseru',
        '14' => 'Africa/Maseru',
        '15' => 'Africa/Maseru',
        '16' => 'Africa/Maseru',
        '17' => 'Africa/Maseru',
        '18' => 'Africa/Maseru',
        '19' => 'Africa/Maseru',
      ],
      'LT' => [
        '56' => 'Europe/Vilnius',
        '57' => 'Europe/Vilnius',
        '58' => 'Europe/Vilnius',
        '59' => 'Europe/Vilnius',
        '60' => 'Europe/Vilnius',
        '61' => 'Europe/Vilnius',
        '62' => 'Europe/Vilnius',
        '63' => 'Europe/Vilnius',
        '64' => 'Europe/Vilnius',
        '65' => 'Europe/Vilnius',
      ],
      'LU' => [
        '01' => 'Europe/Luxembourg',
        '02' => 'Europe/Luxembourg',
        '03' => 'Europe/Luxembourg',
      ],
      'LV' => [
        '01' => 'Europe/Riga',
        '02' => 'Europe/Riga',
        '03' => 'Europe/Riga',
        '04' => 'Europe/Riga',
        '05' => 'Europe/Riga',
        '06' => 'Europe/Riga',
        '07' => 'Europe/Riga',
        '08' => 'Europe/Riga',
        '09' => 'Europe/Riga',
        '10' => 'Europe/Riga',
        '11' => 'Europe/Riga',
        '12' => 'Europe/Riga',
        '13' => 'Europe/Riga',
        '14' => 'Europe/Riga',
        '15' => 'Europe/Riga',
        '16' => 'Europe/Riga',
        '17' => 'Europe/Riga',
        '18' => 'Europe/Riga',
        '19' => 'Europe/Riga',
        '20' => 'Europe/Riga',
        '21' => 'Europe/Riga',
        '22' => 'Europe/Riga',
        '23' => 'Europe/Riga',
        '24' => 'Europe/Riga',
        '25' => 'Europe/Riga',
        '26' => 'Europe/Riga',
        '27' => 'Europe/Riga',
        '28' => 'Europe/Riga',
        '29' => 'Europe/Riga',
        '30' => 'Europe/Riga',
        '31' => 'Europe/Riga',
        '32' => 'Europe/Riga',
        '33' => 'Europe/Riga',
      ],
      'LY' => [
        '03' => 'Africa/Tripoli',
        '05' => 'Africa/Tripoli',
        '08' => 'Africa/Tripoli',
        '13' => 'Africa/Tripoli',
        '30' => 'Africa/Tripoli',
        '34' => 'Africa/Tripoli',
        '41' => 'Africa/Tripoli',
        '42' => 'Africa/Tripoli',
        '45' => 'Africa/Tripoli',
        '47' => 'Africa/Tripoli',
        '48' => 'Africa/Tripoli',
        '49' => 'Africa/Tripoli',
        '50' => 'Africa/Tripoli',
        '51' => 'Africa/Tripoli',
        '52' => 'Africa/Tripoli',
        '53' => 'Africa/Tripoli',
        '54' => 'Africa/Tripoli',
        '55' => 'Africa/Tripoli',
        '56' => 'Africa/Tripoli',
        '57' => 'Africa/Tripoli',
        '58' => 'Africa/Tripoli',
        '59' => 'Africa/Tripoli',
        '60' => 'Africa/Tripoli',
        '61' => 'Africa/Tripoli',
        '62' => 'Africa/Tripoli',
      ],
      'MA' => [
        '45' => 'Africa/Casablanca',
        '46' => 'Africa/Casablanca',
        '47' => 'Africa/Casablanca',
        '48' => 'Africa/Casablanca',
        '49' => 'Africa/Casablanca',
        '50' => 'Africa/Casablanca',
        '51' => 'Africa/Casablanca',
        '52' => 'Africa/Casablanca',
        '53' => 'Africa/Casablanca',
        '54' => 'Africa/Casablanca',
        '55' => 'Africa/Casablanca',
        '56' => 'Africa/Casablanca',
        '57' => 'Africa/Casablanca',
        '58' => 'Africa/Casablanca',
        '59' => 'Africa/Casablanca',
      ],
      'MC' => [
        '01' => 'Europe/Monaco',
        '02' => 'Europe/Monaco',
        '03' => 'Europe/Monaco',
      ],
      'MD' => [
        '51' => 'Europe/Chisinau',
        '57' => 'Europe/Chisinau',
        '58' => 'Europe/Chisinau',
        '59' => 'Europe/Chisinau',
        '60' => 'Europe/Chisinau',
        '61' => 'Europe/Chisinau',
        '62' => 'Europe/Chisinau',
        '63' => 'Europe/Chisinau',
        '64' => 'Europe/Chisinau',
        '65' => 'Europe/Chisinau',
        '66' => 'Europe/Chisinau',
        '67' => 'Europe/Chisinau',
        '68' => 'Europe/Chisinau',
        '69' => 'Europe/Chisinau',
        '70' => 'Europe/Chisinau',
        '71' => 'Europe/Chisinau',
        '72' => 'Europe/Chisinau',
        '73' => 'Europe/Chisinau',
        '74' => 'Europe/Chisinau',
        '75' => 'Europe/Chisinau',
        '76' => 'Europe/Chisinau',
        '77' => 'Europe/Chisinau',
        '78' => 'Europe/Chisinau',
        '79' => 'Europe/Chisinau',
        '80' => 'Europe/Chisinau',
        '81' => 'Europe/Chisinau',
        '82' => 'Europe/Chisinau',
        '83' => 'Europe/Chisinau',
        '84' => 'Europe/Chisinau',
        '85' => 'Europe/Chisinau',
        '86' => 'Europe/Chisinau',
        '87' => 'Europe/Chisinau',
        '88' => 'Europe/Chisinau',
        '89' => 'Europe/Chisinau',
        '90' => 'Europe/Chisinau',
        '91' => 'Europe/Chisinau',
        '92' => 'Europe/Chisinau',
      ],
      'MG' => [
        '01' => 'Indian/Antananarivo',
        '02' => 'Indian/Antananarivo',
        '03' => 'Indian/Antananarivo',
        '04' => 'Indian/Antananarivo',
        '05' => 'Indian/Antananarivo',
        '06' => 'Indian/Antananarivo',
      ],
      'MK' => [
        '01' => 'Europe/Skopje',
        '02' => 'Europe/Skopje',
        '03' => 'Europe/Skopje',
        '04' => 'Europe/Skopje',
        '05' => 'Europe/Skopje',
        '06' => 'Europe/Skopje',
        '07' => 'Europe/Skopje',
        '08' => 'Europe/Skopje',
        '09' => 'Europe/Skopje',
        '10' => 'Europe/Skopje',
        '11' => 'Europe/Skopje',
        '12' => 'Europe/Skopje',
        '13' => 'Europe/Skopje',
        '14' => 'Europe/Skopje',
        '15' => 'Europe/Skopje',
        '16' => 'Europe/Skopje',
        '17' => 'Europe/Skopje',
        '18' => 'Europe/Skopje',
        '19' => 'Europe/Skopje',
        '20' => 'Europe/Skopje',
        '21' => 'Europe/Skopje',
        '22' => 'Europe/Skopje',
        '23' => 'Europe/Skopje',
        '24' => 'Europe/Skopje',
        '25' => 'Europe/Skopje',
        '26' => 'Europe/Skopje',
        '27' => 'Europe/Skopje',
        '28' => 'Europe/Skopje',
        '29' => 'Europe/Skopje',
        '30' => 'Europe/Skopje',
        '31' => 'Europe/Skopje',
        '32' => 'Europe/Skopje',
        '33' => 'Europe/Skopje',
        '34' => 'Europe/Skopje',
        '35' => 'Europe/Skopje',
        '36' => 'Europe/Skopje',
        '37' => 'Europe/Skopje',
        '38' => 'Europe/Skopje',
        '39' => 'Europe/Skopje',
        '40' => 'Europe/Skopje',
        '41' => 'Europe/Skopje',
        '42' => 'Europe/Skopje',
        '43' => 'Europe/Skopje',
        '44' => 'Europe/Skopje',
        '45' => 'Europe/Skopje',
        '46' => 'Europe/Skopje',
        '47' => 'Europe/Skopje',
        '48' => 'Europe/Skopje',
        '49' => 'Europe/Skopje',
        '50' => 'Europe/Skopje',
        '51' => 'Europe/Skopje',
        '52' => 'Europe/Skopje',
        '53' => 'Europe/Skopje',
        '54' => 'Europe/Skopje',
        '55' => 'Europe/Skopje',
        '56' => 'Europe/Skopje',
        '57' => 'Europe/Skopje',
        '58' => 'Europe/Skopje',
        '59' => 'Europe/Skopje',
        '60' => 'Europe/Skopje',
        '61' => 'Europe/Skopje',
        '62' => 'Europe/Skopje',
        '63' => 'Europe/Skopje',
        '64' => 'Europe/Skopje',
        '65' => 'Europe/Skopje',
        '66' => 'Europe/Skopje',
        '67' => 'Europe/Skopje',
        '68' => 'Europe/Skopje',
        '69' => 'Europe/Skopje',
        '70' => 'Europe/Skopje',
        '71' => 'Europe/Skopje',
        '72' => 'Europe/Skopje',
        '73' => 'Europe/Skopje',
        '74' => 'Europe/Skopje',
        '75' => 'Europe/Skopje',
        '76' => 'Europe/Skopje',
        '77' => 'Europe/Skopje',
        '78' => 'Europe/Skopje',
        '79' => 'Europe/Skopje',
        '80' => 'Europe/Skopje',
        '81' => 'Europe/Skopje',
        '82' => 'Europe/Skopje',
        '83' => 'Europe/Skopje',
        '84' => 'Europe/Skopje',
        '85' => 'Europe/Skopje',
        '86' => 'Europe/Skopje',
        '87' => 'Europe/Skopje',
        '88' => 'Europe/Skopje',
        '89' => 'Europe/Skopje',
        '90' => 'Europe/Skopje',
        '91' => 'Europe/Skopje',
        '92' => 'Europe/Skopje',
        '93' => 'Europe/Skopje',
        '94' => 'Europe/Skopje',
        '95' => 'Europe/Skopje',
        '96' => 'Europe/Skopje',
        '97' => 'Europe/Skopje',
        '98' => 'Europe/Skopje',
        '99' => 'Europe/Skopje',
        'A1' => 'Europe/Skopje',
        'A2' => 'Europe/Skopje',
        'A3' => 'Europe/Skopje',
        'A4' => 'Europe/Skopje',
        'A5' => 'Europe/Skopje',
        'A6' => 'Europe/Skopje',
        'A7' => 'Europe/Skopje',
        'A8' => 'Europe/Skopje',
        'A9' => 'Europe/Skopje',
        'B1' => 'Europe/Skopje',
        'B2' => 'Europe/Skopje',
        'B3' => 'Europe/Skopje',
        'B4' => 'Europe/Skopje',
        'B5' => 'Europe/Skopje',
        'B6' => 'Europe/Skopje',
        'B7' => 'Europe/Skopje',
        'B8' => 'Europe/Skopje',
        'B9' => 'Europe/Skopje',
        'C1' => 'Europe/Skopje',
        'C2' => 'Europe/Skopje',
        'C3' => 'Europe/Skopje',
        'C4' => 'Europe/Skopje',
        'C5' => 'Europe/Skopje',
        'C6' => 'Europe/Skopje',
        'C8' => 'Europe/Skopje',
        'C9' => 'Europe/Skopje',
        'D2' => 'Europe/Skopje',
        'D3' => 'Europe/Skopje',
        'D4' => 'Europe/Skopje',
        'D5' => 'Europe/Skopje',
        'D6' => 'Europe/Skopje',
        'D7' => 'Europe/Skopje',
        'D8' => 'Europe/Skopje',
        'E2' => 'Europe/Skopje',
        'E3' => 'Europe/Skopje',
        'E5' => 'Europe/Skopje',
        'E6' => 'Europe/Skopje',
        'E7' => 'Europe/Skopje',
        'E8' => 'Europe/Skopje',
        'E9' => 'Europe/Skopje',
        'F1' => 'Europe/Skopje',
        'F2' => 'Europe/Skopje',
      ],
      'ML' => [
        '01' => 'Africa/Bamako',
        '03' => 'Africa/Bamako',
        '04' => 'Africa/Bamako',
        '05' => 'Africa/Bamako',
        '06' => 'Africa/Bamako',
        '07' => 'Africa/Bamako',
        '08' => 'Africa/Bamako',
        '09' => 'Africa/Bamako',
        '10' => 'Africa/Bamako',
      ],
      'MM' => [
        '01' => 'Asia/Rangoon',
        '02' => 'Asia/Rangoon',
        '03' => 'Asia/Rangoon',
        '04' => 'Asia/Rangoon',
        '05' => 'Asia/Rangoon',
        '06' => 'Asia/Rangoon',
        '07' => 'Asia/Rangoon',
        '08' => 'Asia/Rangoon',
        '09' => 'Asia/Rangoon',
        '10' => 'Asia/Rangoon',
        '11' => 'Asia/Rangoon',
        '12' => 'Asia/Rangoon',
        '13' => 'Asia/Rangoon',
        '14' => 'Asia/Rangoon',
        '17' => 'Asia/Rangoon',
      ],
      'MN' => [
        '01' => 'Asia/Ulaanbaatar',
        '02' => 'Asia/Ulaanbaatar',
        '03' => 'Asia/Hovd',
        '05' => 'Asia/Ulaanbaatar',
        '06' => 'Asia/Choibalsan',
        '07' => 'Asia/Ulaanbaatar',
        '08' => 'Asia/Ulaanbaatar',
        '09' => 'Asia/Hovd',
        '10' => 'Asia/Hovd',
        '11' => 'Asia/Ulaanbaatar',
        '12' => 'Asia/Hovd',
        '13' => 'Asia/Ulaanbaatar',
        '14' => 'Asia/Ulaanbaatar',
        '15' => 'Asia/Ulaanbaatar',
        '16' => 'Asia/Ulaanbaatar',
        '17' => 'Asia/Choibalsan',
        '18' => 'Asia/Ulaanbaatar',
        '19' => 'Asia/Hovd',
        '20' => 'Asia/Ulaanbaatar',
        '21' => 'Asia/Ulaanbaatar',
        '22' => 'Asia/Ulaanbaatar',
        '23' => 'Asia/Ulaanbaatar',
        '24' => 'Asia/Ulaanbaatar',
        '25' => 'Asia/Ulaanbaatar',
      ],
      'MO' => [
        '01' => 'Asia/Macau',
        '02' => 'Asia/Macau',
      ],
      'MR' => [
        '01' => 'Africa/Nouakchott',
        '02' => 'Africa/Nouakchott',
        '03' => 'Africa/Nouakchott',
        '04' => 'Africa/Nouakchott',
        '05' => 'Africa/Nouakchott',
        '06' => 'Africa/Nouakchott',
        '07' => 'Africa/Nouakchott',
        '08' => 'Africa/Nouakchott',
        '09' => 'Africa/Nouakchott',
        '10' => 'Africa/Nouakchott',
        '11' => 'Africa/Nouakchott',
        '12' => 'Africa/Nouakchott',
      ],
      'MS' => [
        '01' => 'America/Montserrat',
        '02' => 'America/Montserrat',
        '03' => 'America/Montserrat',
      ],
      'MU' => [
        '12' => 'Indian/Mauritius',
        '13' => 'Indian/Mauritius',
        '14' => 'Indian/Mauritius',
        '15' => 'Indian/Mauritius',
        '16' => 'Indian/Mauritius',
        '17' => 'Indian/Mauritius',
        '18' => 'Indian/Mauritius',
        '19' => 'Indian/Mauritius',
        '20' => 'Indian/Mauritius',
        '21' => 'Indian/Mauritius',
        '22' => 'Indian/Mauritius',
        '23' => 'Indian/Mauritius',
      ],
      'MV' => [
        '01' => 'Indian/Maldives',
        '05' => 'Indian/Maldives',
        '30' => 'Indian/Maldives',
        '31' => 'Indian/Maldives',
        '32' => 'Indian/Maldives',
        '33' => 'Indian/Maldives',
        '34' => 'Indian/Maldives',
        '35' => 'Indian/Maldives',
        '36' => 'Indian/Maldives',
        '37' => 'Indian/Maldives',
        '38' => 'Indian/Maldives',
        '39' => 'Indian/Maldives',
        '40' => 'Indian/Maldives',
        '41' => 'Indian/Maldives',
        '42' => 'Indian/Maldives',
        '43' => 'Indian/Maldives',
        '44' => 'Indian/Maldives',
        '45' => 'Indian/Maldives',
        '46' => 'Indian/Maldives',
        '47' => 'Indian/Maldives',
      ],
      'MW' => [
        '02' => 'Africa/Blantyre',
        '03' => 'Africa/Blantyre',
        '04' => 'Africa/Blantyre',
        '05' => 'Africa/Blantyre',
        '06' => 'Africa/Blantyre',
        '07' => 'Africa/Blantyre',
        '08' => 'Africa/Blantyre',
        '09' => 'Africa/Blantyre',
        '11' => 'Africa/Blantyre',
        '12' => 'Africa/Blantyre',
        '13' => 'Africa/Blantyre',
        '15' => 'Africa/Blantyre',
        '16' => 'Africa/Blantyre',
        '17' => 'Africa/Blantyre',
        '18' => 'Africa/Blantyre',
        '19' => 'Africa/Blantyre',
        '20' => 'Africa/Blantyre',
        '21' => 'Africa/Blantyre',
        '22' => 'Africa/Blantyre',
        '23' => 'Africa/Blantyre',
        '24' => 'Africa/Blantyre',
        '25' => 'Africa/Blantyre',
        '26' => 'Africa/Blantyre',
        '27' => 'Africa/Blantyre',
        '28' => 'Africa/Blantyre',
        '29' => 'Africa/Blantyre',
        '30' => 'Africa/Blantyre',
      ],
      'MX' => [
        '01' => 'America/Mexico_City',
        '02' => 'America/Tijuana',
        '03' => 'America/Hermosillo',
        '04' => 'America/Merida',
        '05' => 'America/Mexico_City',
        '06' => 'America/Chihuahua',
        '07' => 'America/Monterrey',
        '08' => 'America/Mexico_City',
        '09' => 'America/Mexico_City',
        '10' => 'America/Mazatlan',
        '11' => 'America/Mexico_City',
        '12' => 'America/Mexico_City',
        '13' => 'America/Mexico_City',
        '14' => 'America/Mazatlan',
        '15' => 'America/Chihuahua',
        '16' => 'America/Mexico_City',
        '17' => 'America/Mexico_City',
        '18' => 'America/Mazatlan',
        '19' => 'America/Monterrey',
        '20' => 'America/Mexico_City',
        '21' => 'America/Mexico_City',
        '22' => 'America/Mexico_City',
        '23' => 'America/Cancun',
        '24' => 'America/Mexico_City',
        '25' => 'America/Mazatlan',
        '26' => 'America/Hermosillo',
        '27' => 'America/Merida',
        '28' => 'America/Monterrey',
        '29' => 'America/Mexico_City',
        '30' => 'America/Mexico_City',
        '31' => 'America/Merida',
        '32' => 'America/Monterrey',
      ],
      'MY' => [
        '01' => 'Asia/Kuala_Lumpur',
        '02' => 'Asia/Kuala_Lumpur',
        '03' => 'Asia/Kuala_Lumpur',
        '04' => 'Asia/Kuala_Lumpur',
        '05' => 'Asia/Kuala_Lumpur',
        '06' => 'Asia/Kuala_Lumpur',
        '07' => 'Asia/Kuala_Lumpur',
        '08' => 'Asia/Kuala_Lumpur',
        '09' => 'Asia/Kuala_Lumpur',
        '11' => 'Asia/Kuching',
        '12' => 'Asia/Kuala_Lumpur',
        '13' => 'Asia/Kuala_Lumpur',
        '14' => 'Asia/Kuala_Lumpur',
        '15' => 'Asia/Kuching',
        '16' => 'Asia/Kuching',
        '17' => 'Asia/Kuala_Lumpur',
      ],
      'MZ' => [
        '01' => 'Africa/Maputo',
        '02' => 'Africa/Maputo',
        '03' => 'Africa/Maputo',
        '04' => 'Africa/Maputo',
        '05' => 'Africa/Maputo',
        '06' => 'Africa/Maputo',
        '07' => 'Africa/Maputo',
        '08' => 'Africa/Maputo',
        '09' => 'Africa/Maputo',
        '10' => 'Africa/Maputo',
        '11' => 'Africa/Maputo',
      ],
      'NA' => [
        '01' => 'Africa/Windhoek',
        '02' => 'Africa/Windhoek',
        '03' => 'Africa/Windhoek',
        '04' => 'Africa/Windhoek',
        '05' => 'Africa/Windhoek',
        '06' => 'Africa/Windhoek',
        '07' => 'Africa/Windhoek',
        '08' => 'Africa/Windhoek',
        '09' => 'Africa/Windhoek',
        '10' => 'Africa/Windhoek',
        '11' => 'Africa/Windhoek',
        '12' => 'Africa/Windhoek',
        '13' => 'Africa/Windhoek',
        '14' => 'Africa/Windhoek',
        '15' => 'Africa/Windhoek',
        '16' => 'Africa/Windhoek',
        '17' => 'Africa/Windhoek',
        '18' => 'Africa/Windhoek',
        '20' => 'Africa/Windhoek',
        '21' => 'Africa/Windhoek',
        '22' => 'Africa/Windhoek',
        '23' => 'Africa/Windhoek',
        '24' => 'Africa/Windhoek',
        '25' => 'Africa/Windhoek',
        '26' => 'Africa/Windhoek',
        '27' => 'Africa/Windhoek',
        '28' => 'Africa/Windhoek',
        '29' => 'Africa/Windhoek',
        '30' => 'Africa/Windhoek',
        '31' => 'Africa/Windhoek',
        '32' => 'Africa/Windhoek',
        '33' => 'Africa/Windhoek',
        '34' => 'Africa/Windhoek',
        '35' => 'Africa/Windhoek',
        '36' => 'Africa/Windhoek',
        '37' => 'Africa/Windhoek',
        '38' => 'Africa/Windhoek',
        '39' => 'Africa/Windhoek',
      ],
      'NE' => [
        '01' => 'Africa/Niamey',
        '02' => 'Africa/Niamey',
        '03' => 'Africa/Niamey',
        '04' => 'Africa/Niamey',
        '05' => 'Africa/Niamey',
        '06' => 'Africa/Niamey',
        '07' => 'Africa/Niamey',
        '08' => 'Africa/Niamey',
      ],
      'NG' => [
        '05' => 'Africa/Lagos',
        '11' => 'Africa/Lagos',
        '16' => 'Africa/Lagos',
        '21' => 'Africa/Lagos',
        '22' => 'Africa/Lagos',
        '23' => 'Africa/Lagos',
        '24' => 'Africa/Lagos',
        '25' => 'Africa/Lagos',
        '26' => 'Africa/Lagos',
        '27' => 'Africa/Lagos',
        '28' => 'Africa/Lagos',
        '29' => 'Africa/Lagos',
        '30' => 'Africa/Lagos',
        '31' => 'Africa/Lagos',
        '32' => 'Africa/Lagos',
        '35' => 'Africa/Lagos',
        '36' => 'Africa/Lagos',
        '37' => 'Africa/Lagos',
        '39' => 'Africa/Lagos',
        '40' => 'Africa/Lagos',
        '41' => 'Africa/Lagos',
        '42' => 'Africa/Lagos',
        '43' => 'Africa/Lagos',
        '44' => 'Africa/Lagos',
        '45' => 'Africa/Lagos',
        '46' => 'Africa/Lagos',
        '47' => 'Africa/Lagos',
        '48' => 'Africa/Lagos',
        '49' => 'Africa/Lagos',
        '50' => 'Africa/Lagos',
        '51' => 'Africa/Lagos',
        '52' => 'Africa/Lagos',
        '53' => 'Africa/Lagos',
        '54' => 'Africa/Lagos',
        '55' => 'Africa/Lagos',
        '56' => 'Africa/Lagos',
        '57' => 'Africa/Lagos',
      ],
      'NI' => [
        '01' => 'America/Managua',
        '02' => 'America/Managua',
        '03' => 'America/Managua',
        '04' => 'America/Managua',
        '05' => 'America/Managua',
        '06' => 'America/Managua',
        '07' => 'America/Managua',
        '08' => 'America/Managua',
        '09' => 'America/Managua',
        '10' => 'America/Managua',
        '11' => 'America/Managua',
        '12' => 'America/Managua',
        '13' => 'America/Managua',
        '14' => 'America/Managua',
        '15' => 'America/Managua',
        '16' => 'America/Managua',
        '17' => 'America/Managua',
        '18' => 'America/Managua',
      ],
      'NL' => [
        '01' => 'Europe/Amsterdam',
        '02' => 'Europe/Amsterdam',
        '03' => 'Europe/Amsterdam',
        '04' => 'Europe/Amsterdam',
        '05' => 'Europe/Amsterdam',
        '06' => 'Europe/Amsterdam',
        '07' => 'Europe/Amsterdam',
        '09' => 'Europe/Amsterdam',
        '10' => 'Europe/Amsterdam',
        '11' => 'Europe/Amsterdam',
        '15' => 'Europe/Amsterdam',
        '16' => 'Europe/Amsterdam',
      ],
      'NO' => [
        '01' => 'Europe/Oslo',
        '02' => 'Europe/Oslo',
        '04' => 'Europe/Oslo',
        '05' => 'Europe/Oslo',
        '06' => 'Europe/Oslo',
        '07' => 'Europe/Oslo',
        '08' => 'Europe/Oslo',
        '09' => 'Europe/Oslo',
        '10' => 'Europe/Oslo',
        '11' => 'Europe/Oslo',
        '12' => 'Europe/Oslo',
        '13' => 'Europe/Oslo',
        '14' => 'Europe/Oslo',
        '15' => 'Europe/Oslo',
        '16' => 'Europe/Oslo',
        '17' => 'Europe/Oslo',
        '18' => 'Europe/Oslo',
        '19' => 'Europe/Oslo',
        '20' => 'Europe/Oslo',
      ],
      'NP' => [
        '01' => 'Asia/Kathmandu',
        '02' => 'Asia/Kathmandu',
        '03' => 'Asia/Kathmandu',
        '04' => 'Asia/Kathmandu',
        '05' => 'Asia/Kathmandu',
        '06' => 'Asia/Kathmandu',
        '07' => 'Asia/Kathmandu',
        '08' => 'Asia/Kathmandu',
        '09' => 'Asia/Kathmandu',
        '10' => 'Asia/Kathmandu',
        '11' => 'Asia/Kathmandu',
        '12' => 'Asia/Kathmandu',
        '13' => 'Asia/Kathmandu',
        '14' => 'Asia/Kathmandu',
      ],
      'NR' => [
        '01' => 'Pacific/Nauru',
        '02' => 'Pacific/Nauru',
        '03' => 'Pacific/Nauru',
        '04' => 'Pacific/Nauru',
        '05' => 'Pacific/Nauru',
        '06' => 'Pacific/Nauru',
        '07' => 'Pacific/Nauru',
        '08' => 'Pacific/Nauru',
        '09' => 'Pacific/Nauru',
        '10' => 'Pacific/Nauru',
        '11' => 'Pacific/Nauru',
        '12' => 'Pacific/Nauru',
        '13' => 'Pacific/Nauru',
        '14' => 'Pacific/Nauru',
      ],
      'NZ' => [
        '10' => 'Pacific/Chatham',
        'E7' => 'Pacific/Auckland',
        'E8' => 'Pacific/Auckland',
        'E9' => 'Pacific/Auckland',
        'F1' => 'Pacific/Auckland',
        'F2' => 'Pacific/Auckland',
        'F3' => 'Pacific/Auckland',
        'F4' => 'Pacific/Auckland',
        'F5' => 'Pacific/Auckland',
        'F6' => 'Pacific/Auckland',
        'F7' => 'Pacific/Chatham',
        'F8' => 'Pacific/Auckland',
        'F9' => 'Pacific/Auckland',
        'G1' => 'Pacific/Auckland',
        'G2' => 'Pacific/Auckland',
        'G3' => 'Pacific/Auckland',
      ],
      'OM' => [
        '01' => 'Asia/Muscat',
        '02' => 'Asia/Muscat',
        '03' => 'Asia/Muscat',
        '04' => 'Asia/Muscat',
        '05' => 'Asia/Muscat',
        '06' => 'Asia/Muscat',
        '07' => 'Asia/Muscat',
        '08' => 'Asia/Muscat',
      ],
      'PA' => [
        '01' => 'America/Panama',
        '02' => 'America/Panama',
        '03' => 'America/Panama',
        '04' => 'America/Panama',
        '05' => 'America/Panama',
        '06' => 'America/Panama',
        '07' => 'America/Panama',
        '08' => 'America/Panama',
        '09' => 'America/Panama',
        '10' => 'America/Panama',
      ],
      'PE' => [
        '01' => 'America/Lima',
        '02' => 'America/Lima',
        '03' => 'America/Lima',
        '04' => 'America/Lima',
        '05' => 'America/Lima',
        '06' => 'America/Lima',
        '07' => 'America/Lima',
        '08' => 'America/Lima',
        '09' => 'America/Lima',
        '10' => 'America/Lima',
        '11' => 'America/Lima',
        '12' => 'America/Lima',
        '13' => 'America/Lima',
        '14' => 'America/Lima',
        '15' => 'America/Lima',
        '16' => 'America/Lima',
        '17' => 'America/Lima',
        '18' => 'America/Lima',
        '19' => 'America/Lima',
        '20' => 'America/Lima',
        '21' => 'America/Lima',
        '22' => 'America/Lima',
        '23' => 'America/Lima',
        '24' => 'America/Lima',
        '25' => 'America/Lima',
      ],
      'PG' => [
        '01' => 'Pacific/Port_Moresby',
        '02' => 'Pacific/Port_Moresby',
        '03' => 'Pacific/Port_Moresby',
        '04' => 'Pacific/Port_Moresby',
        '05' => 'Pacific/Port_Moresby',
        '06' => 'Pacific/Port_Moresby',
        '07' => 'Pacific/Port_Moresby',
        '08' => 'Pacific/Port_Moresby',
        '09' => 'Pacific/Port_Moresby',
        '10' => 'Pacific/Port_Moresby',
        '11' => 'Pacific/Port_Moresby',
        '12' => 'Pacific/Port_Moresby',
        '13' => 'Pacific/Port_Moresby',
        '14' => 'Pacific/Port_Moresby',
        '15' => 'Pacific/Port_Moresby',
        '16' => 'Pacific/Port_Moresby',
        '17' => 'Pacific/Port_Moresby',
        '18' => 'Pacific/Port_Moresby',
        '19' => 'Pacific/Port_Moresby',
        '20' => 'Pacific/Port_Moresby',
      ],
      'PH' => [
        '01' => 'Asia/Manila',
        '02' => 'Asia/Manila',
        '03' => 'Asia/Manila',
        '04' => 'Asia/Manila',
        '05' => 'Asia/Manila',
        '06' => 'Asia/Manila',
        '07' => 'Asia/Manila',
        '08' => 'Asia/Manila',
        '09' => 'Asia/Manila',
        '10' => 'Asia/Manila',
        '11' => 'Asia/Manila',
        '12' => 'Asia/Manila',
        '13' => 'Asia/Manila',
        '14' => 'Asia/Manila',
        '15' => 'Asia/Manila',
        '16' => 'Asia/Manila',
        '17' => 'Asia/Manila',
        '18' => 'Asia/Manila',
        '19' => 'Asia/Manila',
        '20' => 'Asia/Manila',
        '21' => 'Asia/Manila',
        '22' => 'Asia/Manila',
        '23' => 'Asia/Manila',
        '24' => 'Asia/Manila',
        '25' => 'Asia/Manila',
        '26' => 'Asia/Manila',
        '27' => 'Asia/Manila',
        '28' => 'Asia/Manila',
        '29' => 'Asia/Manila',
        '30' => 'Asia/Manila',
        '31' => 'Asia/Manila',
        '32' => 'Asia/Manila',
        '33' => 'Asia/Manila',
        '34' => 'Asia/Manila',
        '35' => 'Asia/Manila',
        '36' => 'Asia/Manila',
        '37' => 'Asia/Manila',
        '38' => 'Asia/Manila',
        '39' => 'Asia/Manila',
        '40' => 'Asia/Manila',
        '41' => 'Asia/Manila',
        '42' => 'Asia/Manila',
        '43' => 'Asia/Manila',
        '44' => 'Asia/Manila',
        '45' => 'Asia/Manila',
        '46' => 'Asia/Manila',
        '47' => 'Asia/Manila',
        '48' => 'Asia/Manila',
        '49' => 'Asia/Manila',
        '50' => 'Asia/Manila',
        '51' => 'Asia/Manila',
        '53' => 'Asia/Manila',
        '54' => 'Asia/Manila',
        '55' => 'Asia/Manila',
        '56' => 'Asia/Manila',
        '57' => 'Asia/Manila',
        '58' => 'Asia/Manila',
        '59' => 'Asia/Manila',
        '60' => 'Asia/Manila',
        '61' => 'Asia/Manila',
        '62' => 'Asia/Manila',
        '63' => 'Asia/Manila',
        '64' => 'Asia/Manila',
        '65' => 'Asia/Manila',
        '66' => 'Asia/Manila',
        '67' => 'Asia/Manila',
        '68' => 'Asia/Manila',
        '69' => 'Asia/Manila',
        '70' => 'Asia/Manila',
        '71' => 'Asia/Manila',
        '72' => 'Asia/Manila',
        'A1' => 'Asia/Manila',
        'A2' => 'Asia/Manila',
        'A3' => 'Asia/Manila',
        'A4' => 'Asia/Manila',
        'A5' => 'Asia/Manila',
        'A6' => 'Asia/Manila',
        'A7' => 'Asia/Manila',
        'A8' => 'Asia/Manila',
        'A9' => 'Asia/Manila',
        'B1' => 'Asia/Manila',
        'B2' => 'Asia/Manila',
        'B3' => 'Asia/Manila',
        'B4' => 'Asia/Manila',
        'B5' => 'Asia/Manila',
        'B6' => 'Asia/Manila',
        'B7' => 'Asia/Manila',
        'B8' => 'Asia/Manila',
        'B9' => 'Asia/Manila',
        'C1' => 'Asia/Manila',
        'C2' => 'Asia/Manila',
        'C3' => 'Asia/Manila',
        'C4' => 'Asia/Manila',
        'C5' => 'Asia/Manila',
        'C6' => 'Asia/Manila',
        'C7' => 'Asia/Manila',
        'C8' => 'Asia/Manila',
        'C9' => 'Asia/Manila',
        'D1' => 'Asia/Manila',
        'D2' => 'Asia/Manila',
        'D3' => 'Asia/Manila',
        'D4' => 'Asia/Manila',
        'D5' => 'Asia/Manila',
        'D6' => 'Asia/Manila',
        'D7' => 'Asia/Manila',
        'D8' => 'Asia/Manila',
        'D9' => 'Asia/Manila',
        'E1' => 'Asia/Manila',
        'E2' => 'Asia/Manila',
        'E3' => 'Asia/Manila',
        'E4' => 'Asia/Manila',
        'E5' => 'Asia/Manila',
        'E6' => 'Asia/Manila',
        'E7' => 'Asia/Manila',
        'E8' => 'Asia/Manila',
        'E9' => 'Asia/Manila',
        'F1' => 'Asia/Manila',
        'F2' => 'Asia/Manila',
        'F3' => 'Asia/Manila',
        'F4' => 'Asia/Manila',
        'F5' => 'Asia/Manila',
        'F6' => 'Asia/Manila',
        'F7' => 'Asia/Manila',
        'F8' => 'Asia/Manila',
        'F9' => 'Asia/Manila',
        'G1' => 'Asia/Manila',
        'G2' => 'Asia/Manila',
        'G3' => 'Asia/Manila',
        'G4' => 'Asia/Manila',
        'G5' => 'Asia/Manila',
        'G6' => 'Asia/Manila',
        'G7' => 'Asia/Manila',
        'G8' => 'Asia/Manila',
        'H2' => 'Asia/Manila',
        'H3' => 'Asia/Manila',
        'H9' => 'Asia/Manila',
        'I6' => 'Asia/Manila',
        'I7' => 'Asia/Manila',
        'J3' => 'Asia/Manila',
        'J4' => 'Asia/Manila',
        'J7' => 'Asia/Manila',
        'K1' => 'Asia/Manila',
        'K5' => 'Asia/Manila',
        'K6' => 'Asia/Manila',
        'L4' => 'Asia/Manila',
        'L5' => 'Asia/Manila',
        'L7' => 'Asia/Manila',
        'L9' => 'Asia/Manila',
        'P1' => 'Asia/Manila',
        'M5' => 'Asia/Manila',
        'M6' => 'Asia/Manila',
        'M8' => 'Asia/Manila',
        'M9' => 'Asia/Manila',
        'N1' => 'Asia/Manila',
        'N3' => 'Asia/Manila',
        'P2' => 'Asia/Manila',
      ],
      'PK' => [
        '01' => 'Asia/Karachi',
        '02' => 'Asia/Karachi',
        '03' => 'Asia/Karachi',
        '04' => 'Asia/Karachi',
        '05' => 'Asia/Karachi',
        '06' => 'Asia/Karachi',
        '07' => 'Asia/Karachi',
        '08' => 'Asia/Karachi',
      ],
      'PL' => [
        '72' => 'Europe/Warsaw',
        '73' => 'Europe/Warsaw',
        '74' => 'Europe/Warsaw',
        '75' => 'Europe/Warsaw',
        '76' => 'Europe/Warsaw',
        '77' => 'Europe/Warsaw',
        '78' => 'Europe/Warsaw',
        '79' => 'Europe/Warsaw',
        '80' => 'Europe/Warsaw',
        '81' => 'Europe/Warsaw',
        '82' => 'Europe/Warsaw',
        '83' => 'Europe/Warsaw',
        '84' => 'Europe/Warsaw',
        '85' => 'Europe/Warsaw',
        '86' => 'Europe/Warsaw',
        '87' => 'Europe/Warsaw',
      ],
      'PS' => [
        'GZ' => 'Asia/Gaza',
        'WE' => 'Asia/Gaza',
      ],
      'PT' => [
        '02' => 'Europe/Lisbon',
        '03' => 'Europe/Lisbon',
        '04' => 'Europe/Lisbon',
        '05' => 'Europe/Lisbon',
        '06' => 'Europe/Lisbon',
        '07' => 'Europe/Lisbon',
        '08' => 'Europe/Lisbon',
        '09' => 'Europe/Lisbon',
        '10' => 'Atlantic/Madeira',
        '11' => 'Europe/Lisbon',
        '13' => 'Europe/Lisbon',
        '14' => 'Europe/Lisbon',
        '16' => 'Europe/Lisbon',
        '17' => 'Europe/Lisbon',
        '18' => 'Europe/Lisbon',
        '19' => 'Europe/Lisbon',
        '20' => 'Europe/Lisbon',
        '21' => 'Europe/Lisbon',
        '22' => 'Europe/Lisbon',
        '23' => 'Atlantic/Azores',
      ],
      'PY' => [
        '01' => 'America/Asuncion',
        '02' => 'America/Asuncion',
        '04' => 'America/Asuncion',
        '05' => 'America/Asuncion',
        '06' => 'America/Asuncion',
        '07' => 'America/Asuncion',
        '08' => 'America/Asuncion',
        '10' => 'America/Asuncion',
        '11' => 'America/Asuncion',
        '12' => 'America/Asuncion',
        '13' => 'America/Asuncion',
        '15' => 'America/Asuncion',
        '16' => 'America/Asuncion',
        '17' => 'America/Asuncion',
        '19' => 'America/Asuncion',
        '22' => 'America/Asuncion',
        '23' => 'America/Asuncion',
        '24' => 'America/Asuncion',
      ],
      'QA' => [
        '01' => 'Asia/Qatar',
        '02' => 'Asia/Qatar',
        '03' => 'Asia/Qatar',
        '04' => 'Asia/Qatar',
        '05' => 'Asia/Qatar',
        '06' => 'Asia/Qatar',
        '08' => 'Asia/Qatar',
        '09' => 'Asia/Qatar',
        '10' => 'Asia/Qatar',
        '11' => 'Asia/Qatar',
        '12' => 'Asia/Qatar',
      ],
      'RO' => [
        '01' => 'Europe/Bucharest',
        '02' => 'Europe/Bucharest',
        '03' => 'Europe/Bucharest',
        '04' => 'Europe/Bucharest',
        '05' => 'Europe/Bucharest',
        '06' => 'Europe/Bucharest',
        '07' => 'Europe/Bucharest',
        '08' => 'Europe/Bucharest',
        '09' => 'Europe/Bucharest',
        '10' => 'Europe/Bucharest',
        '11' => 'Europe/Bucharest',
        '12' => 'Europe/Bucharest',
        '13' => 'Europe/Bucharest',
        '14' => 'Europe/Bucharest',
        '15' => 'Europe/Bucharest',
        '16' => 'Europe/Bucharest',
        '17' => 'Europe/Bucharest',
        '18' => 'Europe/Bucharest',
        '19' => 'Europe/Bucharest',
        '20' => 'Europe/Bucharest',
        '21' => 'Europe/Bucharest',
        '22' => 'Europe/Bucharest',
        '23' => 'Europe/Bucharest',
        '25' => 'Europe/Bucharest',
        '26' => 'Europe/Bucharest',
        '27' => 'Europe/Bucharest',
        '28' => 'Europe/Bucharest',
        '29' => 'Europe/Bucharest',
        '30' => 'Europe/Bucharest',
        '31' => 'Europe/Bucharest',
        '32' => 'Europe/Bucharest',
        '33' => 'Europe/Bucharest',
        '34' => 'Europe/Bucharest',
        '35' => 'Europe/Bucharest',
        '36' => 'Europe/Bucharest',
        '37' => 'Europe/Bucharest',
        '38' => 'Europe/Bucharest',
        '39' => 'Europe/Bucharest',
        '40' => 'Europe/Bucharest',
        '41' => 'Europe/Bucharest',
        '42' => 'Europe/Bucharest',
        '43' => 'Europe/Bucharest',
      ],
      'RS' => [
        '01' => 'Europe/Belgrade',
        '02' => 'Europe/Belgrade',
      ],
      'RU' => [
        '01' => 'Europe/Volgograd',
        '02' => 'Asia/Irkutsk',
        '03' => 'Asia/Novokuznetsk',
        '04' => 'Asia/Novosibirsk',
        '05' => 'Asia/Vladivostok',
        '06' => 'Europe/Moscow',
        '07' => 'Europe/Volgograd',
        '08' => 'Europe/Samara',
        '09' => 'Europe/Moscow',
        '10' => 'Europe/Moscow',
        '11' => 'Asia/Irkutsk',
        '12' => 'Europe/Volgograd',
        '13' => 'Asia/Yekaterinburg',
        '14' => 'Asia/Irkutsk',
        '15' => 'Asia/Anadyr',
        '16' => 'Europe/Samara',
        '17' => 'Europe/Volgograd',
        '18' => 'Asia/Krasnoyarsk',
        '19' => 'Europe/Moscow',
        '20' => 'Asia/Irkutsk',
        '21' => 'Europe/Moscow',
        '22' => 'Europe/Volgograd',
        '23' => 'Europe/Kaliningrad',
        '24' => 'Europe/Volgograd',
        '25' => 'Europe/Moscow',
        '26' => 'Asia/Kamchatka',
        '27' => 'Europe/Volgograd',
        '28' => 'Europe/Moscow',
        '29' => 'Asia/Novokuznetsk',
        '30' => 'Asia/Vladivostok',
        '31' => 'Asia/Krasnoyarsk',
        '32' => 'Asia/Omsk',
        '33' => 'Asia/Yekaterinburg',
        '34' => 'Asia/Yekaterinburg',
        '36' => 'Asia/Anadyr',
        '37' => 'Europe/Moscow',
        '38' => 'Europe/Volgograd',
        '39' => 'Asia/Krasnoyarsk',
        '40' => 'Asia/Yekaterinburg',
        '41' => 'Europe/Moscow',
        '42' => 'Europe/Moscow',
        '43' => 'Europe/Moscow',
        '44' => 'Asia/Magadan',
        '45' => 'Europe/Samara',
        '46' => 'Europe/Samara',
        '47' => 'Europe/Moscow',
        '48' => 'Europe/Moscow',
        '49' => 'Europe/Moscow',
        '50' => 'Asia/Yekaterinburg',
        '51' => 'Europe/Moscow',
        '52' => 'Europe/Moscow',
        '53' => 'Asia/Novosibirsk',
        '54' => 'Asia/Omsk',
        '55' => 'Europe/Samara',
        '56' => 'Europe/Moscow',
        '57' => 'Europe/Samara',
        '58' => 'Asia/Yekaterinburg',
        '59' => 'Asia/Vladivostok',
        '60' => 'Europe/Kaliningrad',
        '61' => 'Europe/Volgograd',
        '62' => 'Europe/Moscow',
        '63' => 'Asia/Yakutsk',
        '64' => 'Asia/Sakhalin',
        '65' => 'Europe/Samara',
        '66' => 'Europe/Moscow',
        '67' => 'Europe/Samara',
        '68' => 'Europe/Volgograd',
        '69' => 'Europe/Moscow',
        '70' => 'Europe/Volgograd',
        '71' => 'Asia/Yekaterinburg',
        '72' => 'Europe/Moscow',
        '73' => 'Europe/Samara',
        '74' => 'Asia/Krasnoyarsk',
        '75' => 'Asia/Novosibirsk',
        '76' => 'Europe/Moscow',
        '77' => 'Europe/Moscow',
        '78' => 'Asia/Yekaterinburg',
        '79' => 'Asia/Irkutsk',
        '80' => 'Asia/Yekaterinburg',
        '81' => 'Europe/Samara',
        '83' => 'Europe/Moscow',
        '84' => 'Europe/Volgograd',
        '85' => 'Europe/Moscow',
        '86' => 'Europe/Moscow',
        '87' => 'Asia/Novosibirsk',
        '88' => 'Europe/Moscow',
        '89' => 'Asia/Vladivostok',
        '90' => 'Asia/Yekaterinburg',
        '91' => 'Asia/Krasnoyarsk',
        '92' => 'Asia/Anadyr',
        '93' => 'Asia/Irkutsk',
      ],
      'RW' => [
        '01' => 'Africa/Kigali',
        '06' => 'Africa/Kigali',
        '07' => 'Africa/Kigali',
        '09' => 'Africa/Kigali',
        '11' => 'Africa/Kigali',
        '12' => 'Africa/Kigali',
        '13' => 'Africa/Kigali',
        '14' => 'Africa/Kigali',
        '15' => 'Africa/Kigali',
      ],
      'SA' => [
        '02' => 'Asia/Riyadh',
        '05' => 'Asia/Riyadh',
        '06' => 'Asia/Riyadh',
        '08' => 'Asia/Riyadh',
        '10' => 'Asia/Riyadh',
        '11' => 'Asia/Riyadh',
        '13' => 'Asia/Riyadh',
        '14' => 'Asia/Riyadh',
        '15' => 'Asia/Riyadh',
        '16' => 'Asia/Riyadh',
        '17' => 'Asia/Riyadh',
        '19' => 'Asia/Riyadh',
        '20' => 'Asia/Riyadh',
      ],
      'SB' => [
        '03' => 'Pacific/Guadalcanal',
        '06' => 'Pacific/Guadalcanal',
        '07' => 'Pacific/Guadalcanal',
        '08' => 'Pacific/Guadalcanal',
        '09' => 'Pacific/Guadalcanal',
        '10' => 'Pacific/Guadalcanal',
        '11' => 'Pacific/Guadalcanal',
        '12' => 'Pacific/Guadalcanal',
        '13' => 'Pacific/Guadalcanal',
      ],
      'SC' => [
        '01' => 'Indian/Mahe',
        '02' => 'Indian/Mahe',
        '03' => 'Indian/Mahe',
        '04' => 'Indian/Mahe',
        '05' => 'Indian/Mahe',
        '06' => 'Indian/Mahe',
        '07' => 'Indian/Mahe',
        '08' => 'Indian/Mahe',
        '09' => 'Indian/Mahe',
        '10' => 'Indian/Mahe',
        '11' => 'Indian/Mahe',
        '12' => 'Indian/Mahe',
        '13' => 'Indian/Mahe',
        '14' => 'Indian/Mahe',
        '15' => 'Indian/Mahe',
        '16' => 'Indian/Mahe',
        '17' => 'Indian/Mahe',
        '18' => 'Indian/Mahe',
        '19' => 'Indian/Mahe',
        '20' => 'Indian/Mahe',
        '21' => 'Indian/Mahe',
        '22' => 'Indian/Mahe',
        '23' => 'Indian/Mahe',
      ],
      'SD' => [
        '27' => 'Africa/Khartoum',
        '28' => 'Africa/Khartoum',
        '29' => 'Africa/Khartoum',
        '30' => 'Africa/Khartoum',
        '31' => 'Africa/Khartoum',
        '32' => 'Africa/Khartoum',
        '33' => 'Africa/Khartoum',
        '34' => 'Africa/Khartoum',
        '35' => 'Africa/Khartoum',
        '40' => 'Africa/Khartoum',
        '44' => 'Africa/Khartoum',
        '49' => 'Africa/Khartoum',
        '50' => 'Africa/Khartoum',
        '52' => 'Africa/Khartoum',
        '53' => 'Africa/Khartoum',
        '55' => 'Africa/Khartoum',
      ],
      'SE' => [
        '02' => 'Europe/Stockholm',
        '03' => 'Europe/Stockholm',
        '05' => 'Europe/Stockholm',
        '06' => 'Europe/Stockholm',
        '07' => 'Europe/Stockholm',
        '08' => 'Europe/Stockholm',
        '09' => 'Europe/Stockholm',
        '10' => 'Europe/Stockholm',
        '12' => 'Europe/Stockholm',
        '14' => 'Europe/Stockholm',
        '15' => 'Europe/Stockholm',
        '16' => 'Europe/Stockholm',
        '18' => 'Europe/Stockholm',
        '21' => 'Europe/Stockholm',
        '22' => 'Europe/Stockholm',
        '23' => 'Europe/Stockholm',
        '24' => 'Europe/Stockholm',
        '25' => 'Europe/Stockholm',
        '26' => 'Europe/Stockholm',
        '27' => 'Europe/Stockholm',
        '28' => 'Europe/Stockholm',
      ],
      'SH' => [
        '01' => 'Atlantic/St_Helena',
        '02' => 'Atlantic/St_Helena',
        '03' => 'Atlantic/St_Helena',
      ],
      'SI' => [
        '01' => 'Europe/Ljubljana',
        '02' => 'Europe/Ljubljana',
        '03' => 'Europe/Ljubljana',
        '04' => 'Europe/Ljubljana',
        '05' => 'Europe/Ljubljana',
        '06' => 'Europe/Ljubljana',
        '07' => 'Europe/Ljubljana',
        '08' => 'Europe/Ljubljana',
        '09' => 'Europe/Ljubljana',
        '11' => 'Europe/Ljubljana',
        '12' => 'Europe/Ljubljana',
        '13' => 'Europe/Ljubljana',
        '14' => 'Europe/Ljubljana',
        '15' => 'Europe/Ljubljana',
        '16' => 'Europe/Ljubljana',
        '17' => 'Europe/Ljubljana',
        '19' => 'Europe/Ljubljana',
        '20' => 'Europe/Ljubljana',
        '22' => 'Europe/Ljubljana',
        '24' => 'Europe/Ljubljana',
        '25' => 'Europe/Ljubljana',
        '26' => 'Europe/Ljubljana',
        '27' => 'Europe/Ljubljana',
        '28' => 'Europe/Ljubljana',
        '29' => 'Europe/Ljubljana',
        '30' => 'Europe/Ljubljana',
        '31' => 'Europe/Ljubljana',
        '32' => 'Europe/Ljubljana',
        '34' => 'Europe/Ljubljana',
        '35' => 'Europe/Ljubljana',
        '36' => 'Europe/Ljubljana',
        '37' => 'Europe/Ljubljana',
        '38' => 'Europe/Ljubljana',
        '39' => 'Europe/Ljubljana',
        '40' => 'Europe/Ljubljana',
        '42' => 'Europe/Ljubljana',
        '44' => 'Europe/Ljubljana',
        '45' => 'Europe/Ljubljana',
        '46' => 'Europe/Ljubljana',
        '47' => 'Europe/Ljubljana',
        '49' => 'Europe/Ljubljana',
        '50' => 'Europe/Ljubljana',
        '51' => 'Europe/Ljubljana',
        '52' => 'Europe/Ljubljana',
        '53' => 'Europe/Ljubljana',
        '54' => 'Europe/Ljubljana',
        '55' => 'Europe/Ljubljana',
        '57' => 'Europe/Ljubljana',
        '61' => 'Europe/Ljubljana',
        '62' => 'Europe/Ljubljana',
        '64' => 'Europe/Ljubljana',
        '66' => 'Europe/Ljubljana',
        '68' => 'Europe/Ljubljana',
        '71' => 'Europe/Ljubljana',
        '72' => 'Europe/Ljubljana',
        '73' => 'Europe/Ljubljana',
        '74' => 'Europe/Ljubljana',
        '76' => 'Europe/Ljubljana',
        '77' => 'Europe/Ljubljana',
        '78' => 'Europe/Ljubljana',
        '79' => 'Europe/Ljubljana',
        '80' => 'Europe/Ljubljana',
        '81' => 'Europe/Ljubljana',
        '82' => 'Europe/Ljubljana',
        '83' => 'Europe/Ljubljana',
        '84' => 'Europe/Ljubljana',
        '86' => 'Europe/Ljubljana',
        '87' => 'Europe/Ljubljana',
        '88' => 'Europe/Ljubljana',
        '89' => 'Europe/Ljubljana',
        '91' => 'Europe/Ljubljana',
        '92' => 'Europe/Ljubljana',
        '94' => 'Europe/Ljubljana',
        '97' => 'Europe/Ljubljana',
        '98' => 'Europe/Ljubljana',
        '99' => 'Europe/Ljubljana',
        'A1' => 'Europe/Ljubljana',
        'A2' => 'Europe/Ljubljana',
        'A3' => 'Europe/Ljubljana',
        'A6' => 'Europe/Ljubljana',
        'A7' => 'Europe/Ljubljana',
        'A8' => 'Europe/Ljubljana',
        'B1' => 'Europe/Ljubljana',
        'B2' => 'Europe/Ljubljana',
        'B3' => 'Europe/Ljubljana',
        'B4' => 'Europe/Ljubljana',
        'B6' => 'Europe/Ljubljana',
        'B7' => 'Europe/Ljubljana',
        'B8' => 'Europe/Ljubljana',
        'B9' => 'Europe/Ljubljana',
        'C1' => 'Europe/Ljubljana',
        'C2' => 'Europe/Ljubljana',
        'C4' => 'Europe/Ljubljana',
        'C5' => 'Europe/Ljubljana',
        'C6' => 'Europe/Ljubljana',
        'C7' => 'Europe/Ljubljana',
        'C8' => 'Europe/Ljubljana',
        'C9' => 'Europe/Ljubljana',
        'D1' => 'Europe/Ljubljana',
        'D2' => 'Europe/Ljubljana',
        'D3' => 'Europe/Ljubljana',
        'D4' => 'Europe/Ljubljana',
        'D5' => 'Europe/Ljubljana',
        'D6' => 'Europe/Ljubljana',
        'D7' => 'Europe/Ljubljana',
        'D8' => 'Europe/Ljubljana',
        'E1' => 'Europe/Ljubljana',
        'E2' => 'Europe/Ljubljana',
        'E3' => 'Europe/Ljubljana',
        'E5' => 'Europe/Ljubljana',
        'E6' => 'Europe/Ljubljana',
        'E7' => 'Europe/Ljubljana',
        'E9' => 'Europe/Ljubljana',
        'F1' => 'Europe/Ljubljana',
        'F2' => 'Europe/Ljubljana',
        'F3' => 'Europe/Ljubljana',
        'F4' => 'Europe/Ljubljana',
        'F5' => 'Europe/Ljubljana',
        'F6' => 'Europe/Ljubljana',
        'F7' => 'Europe/Ljubljana',
        'F8' => 'Europe/Ljubljana',
        'F9' => 'Europe/Ljubljana',
        'G1' => 'Europe/Ljubljana',
        'G2' => 'Europe/Ljubljana',
        'G3' => 'Europe/Ljubljana',
        'G4' => 'Europe/Ljubljana',
        'G5' => 'Europe/Ljubljana',
        'G6' => 'Europe/Ljubljana',
        'G7' => 'Europe/Ljubljana',
        'G8' => 'Europe/Ljubljana',
        'G9' => 'Europe/Ljubljana',
        'H1' => 'Europe/Ljubljana',
        'H2' => 'Europe/Ljubljana',
        'H3' => 'Europe/Ljubljana',
        'H4' => 'Europe/Ljubljana',
        'H5' => 'Europe/Ljubljana',
        'H6' => 'Europe/Ljubljana',
        'H7' => 'Europe/Ljubljana',
        'H8' => 'Europe/Ljubljana',
        'H9' => 'Europe/Ljubljana',
        'I1' => 'Europe/Ljubljana',
        'I2' => 'Europe/Ljubljana',
        'I3' => 'Europe/Ljubljana',
        'I4' => 'Europe/Ljubljana',
        'I5' => 'Europe/Ljubljana',
        'I6' => 'Europe/Ljubljana',
        'I7' => 'Europe/Ljubljana',
        'I8' => 'Europe/Ljubljana',
        'I9' => 'Europe/Ljubljana',
        'J1' => 'Europe/Ljubljana',
        'J2' => 'Europe/Ljubljana',
        'J3' => 'Europe/Ljubljana',
        'J4' => 'Europe/Ljubljana',
        'J5' => 'Europe/Ljubljana',
        'J6' => 'Europe/Ljubljana',
        'J7' => 'Europe/Ljubljana',
        'J8' => 'Europe/Ljubljana',
        'J9' => 'Europe/Ljubljana',
        'K1' => 'Europe/Ljubljana',
        'K2' => 'Europe/Ljubljana',
        'K3' => 'Europe/Ljubljana',
        'K4' => 'Europe/Ljubljana',
        'K5' => 'Europe/Ljubljana',
        'K6' => 'Europe/Ljubljana',
        'K7' => 'Europe/Ljubljana',
        'K8' => 'Europe/Ljubljana',
        'K9' => 'Europe/Ljubljana',
        'L1' => 'Europe/Ljubljana',
        'L2' => 'Europe/Ljubljana',
        'L3' => 'Europe/Ljubljana',
        'L4' => 'Europe/Ljubljana',
        'L5' => 'Europe/Ljubljana',
        'L6' => 'Europe/Ljubljana',
        'L7' => 'Europe/Ljubljana',
        'L8' => 'Europe/Ljubljana',
        'L9' => 'Europe/Ljubljana',
        'M1' => 'Europe/Ljubljana',
        'M2' => 'Europe/Ljubljana',
        'M3' => 'Europe/Ljubljana',
        'M4' => 'Europe/Ljubljana',
        'M5' => 'Europe/Ljubljana',
        'M6' => 'Europe/Ljubljana',
        'M7' => 'Europe/Ljubljana',
        'M8' => 'Europe/Ljubljana',
        'M9' => 'Europe/Ljubljana',
        'N1' => 'Europe/Ljubljana',
        'N2' => 'Europe/Ljubljana',
        'N3' => 'Europe/Ljubljana',
        'N4' => 'Europe/Ljubljana',
        'N5' => 'Europe/Ljubljana',
        'N6' => 'Europe/Ljubljana',
        'N7' => 'Europe/Ljubljana',
        'N8' => 'Europe/Ljubljana',
        'N9' => 'Europe/Ljubljana',
        'O1' => 'Europe/Ljubljana',
        'O2' => 'Europe/Ljubljana',
        'O3' => 'Europe/Ljubljana',
        'O4' => 'Europe/Ljubljana',
        'O5' => 'Europe/Ljubljana',
        'O6' => 'Europe/Ljubljana',
        'O7' => 'Europe/Ljubljana',
        'O8' => 'Europe/Ljubljana',
        'O9' => 'Europe/Ljubljana',
        'P1' => 'Europe/Ljubljana',
        'P2' => 'Europe/Ljubljana',
        'P3' => 'Europe/Ljubljana',
        'P4' => 'Europe/Ljubljana',
        'P5' => 'Europe/Ljubljana',
        'P7' => 'Europe/Ljubljana',
      ],
      'SK' => [
        '01' => 'Europe/Bratislava',
        '02' => 'Europe/Bratislava',
        '03' => 'Europe/Bratislava',
        '04' => 'Europe/Bratislava',
        '05' => 'Europe/Bratislava',
        '06' => 'Europe/Bratislava',
        '07' => 'Europe/Bratislava',
        '08' => 'Europe/Bratislava',
      ],
      'SL' => [
        '01' => 'Africa/Freetown',
        '02' => 'Africa/Freetown',
        '03' => 'Africa/Freetown',
        '04' => 'Africa/Freetown',
      ],
      'SM' => [
        '01' => 'Europe/San_Marino',
        '02' => 'Europe/San_Marino',
        '03' => 'Europe/San_Marino',
        '04' => 'Europe/San_Marino',
        '05' => 'Europe/San_Marino',
        '06' => 'Europe/San_Marino',
        '07' => 'Europe/San_Marino',
        '08' => 'Europe/San_Marino',
        '09' => 'Europe/San_Marino',
      ],
      'SN' => [
        '01' => 'Africa/Dakar',
        '03' => 'Africa/Dakar',
        '05' => 'Africa/Dakar',
        '07' => 'Africa/Dakar',
        '09' => 'Africa/Dakar',
        '10' => 'Africa/Dakar',
        '11' => 'Africa/Dakar',
        '12' => 'Africa/Dakar',
        '13' => 'Africa/Dakar',
        '14' => 'Africa/Dakar',
        '15' => 'Africa/Dakar',
      ],
      'SO' => [
        '01' => 'Africa/Mogadishu',
        '02' => 'Africa/Mogadishu',
        '03' => 'Africa/Mogadishu',
        '04' => 'Africa/Mogadishu',
        '05' => 'Africa/Mogadishu',
        '06' => 'Africa/Mogadishu',
        '07' => 'Africa/Mogadishu',
        '08' => 'Africa/Mogadishu',
        '09' => 'Africa/Mogadishu',
        '10' => 'Africa/Mogadishu',
        '11' => 'Africa/Mogadishu',
        '12' => 'Africa/Mogadishu',
        '13' => 'Africa/Mogadishu',
        '14' => 'Africa/Mogadishu',
        '16' => 'Africa/Mogadishu',
        '18' => 'Africa/Mogadishu',
        '19' => 'Africa/Mogadishu',
        '20' => 'Africa/Mogadishu',
        '21' => 'Africa/Mogadishu',
        '22' => 'Africa/Mogadishu',
      ],
      'SR' => [
        '10' => 'America/Paramaribo',
        '11' => 'America/Paramaribo',
        '12' => 'America/Paramaribo',
        '13' => 'America/Paramaribo',
        '14' => 'America/Paramaribo',
        '15' => 'America/Paramaribo',
        '16' => 'America/Paramaribo',
        '17' => 'America/Paramaribo',
        '18' => 'America/Paramaribo',
        '19' => 'America/Paramaribo',
      ],
      'SS' => [
        '01' => 'Africa/Juba',
        '02' => 'Africa/Juba',
        '03' => 'Africa/Juba',
        '04' => 'Africa/Juba',
        '05' => 'Africa/Juba',
        '06' => 'Africa/Juba',
        '07' => 'Africa/Juba',
        '08' => 'Africa/Juba',
        '09' => 'Africa/Juba',
        '10' => 'Africa/Juba',
      ],
      'ST' => [
        '01' => 'Africa/Sao_Tome',
        '02' => 'Africa/Sao_Tome',
      ],
      'SV' => [
        '01' => 'America/El_Salvador',
        '02' => 'America/El_Salvador',
        '03' => 'America/El_Salvador',
        '04' => 'America/El_Salvador',
        '05' => 'America/El_Salvador',
        '06' => 'America/El_Salvador',
        '07' => 'America/El_Salvador',
        '08' => 'America/El_Salvador',
        '09' => 'America/El_Salvador',
        '10' => 'America/El_Salvador',
        '11' => 'America/El_Salvador',
        '12' => 'America/El_Salvador',
        '13' => 'America/El_Salvador',
        '14' => 'America/El_Salvador',
      ],
      'SY' => [
        '01' => 'Asia/Damascus',
        '02' => 'Asia/Damascus',
        '03' => 'Asia/Damascus',
        '04' => 'Asia/Damascus',
        '05' => 'Asia/Damascus',
        '06' => 'Asia/Damascus',
        '07' => 'Asia/Damascus',
        '08' => 'Asia/Damascus',
        '09' => 'Asia/Damascus',
        '10' => 'Asia/Damascus',
        '11' => 'Asia/Damascus',
        '12' => 'Asia/Damascus',
        '13' => 'Asia/Damascus',
        '14' => 'Asia/Damascus',
      ],
      'SZ' => [
        '01' => 'Africa/Mbabane',
        '02' => 'Africa/Mbabane',
        '03' => 'Africa/Mbabane',
        '04' => 'Africa/Mbabane',
        '05' => 'Africa/Mbabane',
      ],
      'TD' => [
        '01' => 'Africa/Ndjamena',
        '02' => 'Africa/Ndjamena',
        '03' => 'Africa/Ndjamena',
        '04' => 'Africa/Ndjamena',
        '05' => 'Africa/Ndjamena',
        '06' => 'Africa/Ndjamena',
        '07' => 'Africa/Ndjamena',
        '08' => 'Africa/Ndjamena',
        '09' => 'Africa/Ndjamena',
        '10' => 'Africa/Ndjamena',
        '11' => 'Africa/Ndjamena',
        '12' => 'Africa/Ndjamena',
        '13' => 'Africa/Ndjamena',
        '14' => 'Africa/Ndjamena',
      ],
      'TG' => [
        '22' => 'Africa/Lome',
        '23' => 'Africa/Lome',
        '24' => 'Africa/Lome',
        '25' => 'Africa/Lome',
        '26' => 'Africa/Lome',
      ],
      'TH' => [
        '01' => 'Asia/Bangkok',
        '02' => 'Asia/Bangkok',
        '03' => 'Asia/Bangkok',
        '04' => 'Asia/Bangkok',
        '05' => 'Asia/Bangkok',
        '06' => 'Asia/Bangkok',
        '07' => 'Asia/Bangkok',
        '08' => 'Asia/Bangkok',
        '09' => 'Asia/Bangkok',
        '10' => 'Asia/Bangkok',
        '11' => 'Asia/Bangkok',
        '12' => 'Asia/Bangkok',
        '13' => 'Asia/Bangkok',
        '14' => 'Asia/Bangkok',
        '15' => 'Asia/Bangkok',
        '16' => 'Asia/Bangkok',
        '17' => 'Asia/Bangkok',
        '18' => 'Asia/Bangkok',
        '20' => 'Asia/Bangkok',
        '21' => 'Asia/Bangkok',
        '22' => 'Asia/Bangkok',
        '23' => 'Asia/Bangkok',
        '24' => 'Asia/Bangkok',
        '25' => 'Asia/Bangkok',
        '26' => 'Asia/Bangkok',
        '27' => 'Asia/Bangkok',
        '28' => 'Asia/Bangkok',
        '29' => 'Asia/Bangkok',
        '30' => 'Asia/Bangkok',
        '31' => 'Asia/Bangkok',
        '32' => 'Asia/Bangkok',
        '33' => 'Asia/Bangkok',
        '34' => 'Asia/Bangkok',
        '35' => 'Asia/Bangkok',
        '36' => 'Asia/Bangkok',
        '37' => 'Asia/Bangkok',
        '38' => 'Asia/Bangkok',
        '39' => 'Asia/Bangkok',
        '40' => 'Asia/Bangkok',
        '41' => 'Asia/Bangkok',
        '42' => 'Asia/Bangkok',
        '43' => 'Asia/Bangkok',
        '44' => 'Asia/Bangkok',
        '45' => 'Asia/Bangkok',
        '46' => 'Asia/Bangkok',
        '47' => 'Asia/Bangkok',
        '48' => 'Asia/Bangkok',
        '49' => 'Asia/Bangkok',
        '50' => 'Asia/Bangkok',
        '51' => 'Asia/Bangkok',
        '52' => 'Asia/Bangkok',
        '53' => 'Asia/Bangkok',
        '54' => 'Asia/Bangkok',
        '55' => 'Asia/Bangkok',
        '56' => 'Asia/Bangkok',
        '57' => 'Asia/Bangkok',
        '58' => 'Asia/Bangkok',
        '59' => 'Asia/Bangkok',
        '60' => 'Asia/Bangkok',
        '61' => 'Asia/Bangkok',
        '62' => 'Asia/Bangkok',
        '63' => 'Asia/Bangkok',
        '64' => 'Asia/Bangkok',
        '65' => 'Asia/Bangkok',
        '66' => 'Asia/Bangkok',
        '67' => 'Asia/Bangkok',
        '68' => 'Asia/Bangkok',
        '69' => 'Asia/Bangkok',
        '70' => 'Asia/Bangkok',
        '71' => 'Asia/Bangkok',
        '72' => 'Asia/Bangkok',
        '73' => 'Asia/Bangkok',
        '74' => 'Asia/Bangkok',
        '75' => 'Asia/Bangkok',
        '76' => 'Asia/Bangkok',
        '77' => 'Asia/Bangkok',
        '78' => 'Asia/Bangkok',
        '79' => 'Asia/Bangkok',
        '80' => 'Asia/Bangkok',
        '81' => 'Asia/Bangkok',
      ],
      'TJ' => [
        '01' => 'Asia/Dushanbe',
        '02' => 'Asia/Dushanbe',
        '03' => 'Asia/Dushanbe',
        '04' => 'Asia/Dushanbe',
        '05' => 'Asia/Dushanbe',
      ],
      'TL' => [
        '06' => 'Asia/Dili',
      ],
      'TM' => [
        '01' => 'Asia/Ashgabat',
        '02' => 'Asia/Ashgabat',
        '03' => 'Asia/Ashgabat',
        '04' => 'Asia/Ashgabat',
        '05' => 'Asia/Ashgabat',
      ],
      'TN' => [
        '02' => 'Africa/Tunis',
        '03' => 'Africa/Tunis',
        '06' => 'Africa/Tunis',
        '10' => 'Africa/Tunis',
        '14' => 'Africa/Tunis',
        '15' => 'Africa/Tunis',
        '16' => 'Africa/Tunis',
        '17' => 'Africa/Tunis',
        '18' => 'Africa/Tunis',
        '19' => 'Africa/Tunis',
        '22' => 'Africa/Tunis',
        '23' => 'Africa/Tunis',
        '27' => 'Africa/Tunis',
        '28' => 'Africa/Tunis',
        '29' => 'Africa/Tunis',
        '31' => 'Africa/Tunis',
        '32' => 'Africa/Tunis',
        '33' => 'Africa/Tunis',
        '34' => 'Africa/Tunis',
        '35' => 'Africa/Tunis',
        '36' => 'Africa/Tunis',
        '37' => 'Africa/Tunis',
        '38' => 'Africa/Tunis',
        '39' => 'Africa/Tunis',
      ],
      'TO' => [
        '01' => 'Pacific/Tongatapu',
        '02' => 'Pacific/Tongatapu',
        '03' => 'Pacific/Tongatapu',
      ],
      'TR' => [
        '02' => 'Asia/Istanbul',
        '03' => 'Asia/Istanbul',
        '04' => 'Asia/Istanbul',
        '05' => 'Asia/Istanbul',
        '07' => 'Asia/Istanbul',
        '08' => 'Asia/Istanbul',
        '09' => 'Asia/Istanbul',
        '10' => 'Asia/Istanbul',
        '11' => 'Asia/Istanbul',
        '12' => 'Asia/Istanbul',
        '13' => 'Asia/Istanbul',
        '14' => 'Asia/Istanbul',
        '15' => 'Asia/Istanbul',
        '16' => 'Asia/Istanbul',
        '17' => 'Asia/Istanbul',
        '19' => 'Asia/Istanbul',
        '20' => 'Asia/Istanbul',
        '21' => 'Asia/Istanbul',
        '22' => 'Asia/Istanbul',
        '23' => 'Asia/Istanbul',
        '24' => 'Asia/Istanbul',
        '25' => 'Asia/Istanbul',
        '26' => 'Asia/Istanbul',
        '28' => 'Asia/Istanbul',
        '31' => 'Asia/Istanbul',
        '32' => 'Asia/Istanbul',
        '33' => 'Asia/Istanbul',
        '34' => 'Asia/Istanbul',
        '35' => 'Asia/Istanbul',
        '37' => 'Asia/Istanbul',
        '38' => 'Asia/Istanbul',
        '39' => 'Asia/Istanbul',
        '40' => 'Asia/Istanbul',
        '41' => 'Asia/Istanbul',
        '43' => 'Asia/Istanbul',
        '44' => 'Asia/Istanbul',
        '45' => 'Asia/Istanbul',
        '46' => 'Asia/Istanbul',
        '48' => 'Asia/Istanbul',
        '49' => 'Asia/Istanbul',
        '50' => 'Asia/Istanbul',
        '52' => 'Asia/Istanbul',
        '53' => 'Asia/Istanbul',
        '54' => 'Asia/Istanbul',
        '55' => 'Asia/Istanbul',
        '57' => 'Asia/Istanbul',
        '58' => 'Asia/Istanbul',
        '59' => 'Asia/Istanbul',
        '60' => 'Asia/Istanbul',
        '61' => 'Asia/Istanbul',
        '62' => 'Asia/Istanbul',
        '63' => 'Asia/Istanbul',
        '64' => 'Asia/Istanbul',
        '65' => 'Asia/Istanbul',
        '66' => 'Asia/Istanbul',
        '68' => 'Asia/Istanbul',
        '69' => 'Asia/Istanbul',
        '70' => 'Asia/Istanbul',
        '71' => 'Asia/Istanbul',
        '72' => 'Asia/Istanbul',
        '73' => 'Asia/Istanbul',
        '74' => 'Asia/Istanbul',
        '75' => 'Asia/Istanbul',
        '76' => 'Asia/Istanbul',
        '77' => 'Asia/Istanbul',
        '78' => 'Asia/Istanbul',
        '79' => 'Asia/Istanbul',
        '80' => 'Asia/Istanbul',
        '81' => 'Asia/Istanbul',
        '82' => 'Asia/Istanbul',
        '83' => 'Asia/Istanbul',
        '84' => 'Asia/Istanbul',
        '85' => 'Asia/Istanbul',
        '86' => 'Asia/Istanbul',
        '87' => 'Asia/Istanbul',
        '88' => 'Asia/Istanbul',
        '89' => 'Asia/Istanbul',
        '90' => 'Asia/Istanbul',
        '91' => 'Asia/Istanbul',
        '92' => 'Asia/Istanbul',
        '93' => 'Asia/Istanbul',
      ],
      'TT' => [
        '01' => 'America/Port_of_Spain',
        '02' => 'America/Port_of_Spain',
        '03' => 'America/Port_of_Spain',
        '04' => 'America/Port_of_Spain',
        '05' => 'America/Port_of_Spain',
        '06' => 'America/Port_of_Spain',
        '07' => 'America/Port_of_Spain',
        '08' => 'America/Port_of_Spain',
        '09' => 'America/Port_of_Spain',
        '10' => 'America/Port_of_Spain',
        '11' => 'America/Port_of_Spain',
        '12' => 'America/Port_of_Spain',
      ],
      'TW' => [
        '01' => 'Asia/Taipei',
        '02' => 'Asia/Taipei',
        '03' => 'Asia/Taipei',
        '04' => 'Asia/Taipei',
      ],
      'TZ' => [
        '02' => 'Africa/Dar_es_Salaam',
        '03' => 'Africa/Dar_es_Salaam',
        '04' => 'Africa/Dar_es_Salaam',
        '05' => 'Africa/Dar_es_Salaam',
        '06' => 'Africa/Dar_es_Salaam',
        '07' => 'Africa/Dar_es_Salaam',
        '08' => 'Africa/Dar_es_Salaam',
        '09' => 'Africa/Dar_es_Salaam',
        '10' => 'Africa/Dar_es_Salaam',
        '11' => 'Africa/Dar_es_Salaam',
        '12' => 'Africa/Dar_es_Salaam',
        '13' => 'Africa/Dar_es_Salaam',
        '14' => 'Africa/Dar_es_Salaam',
        '15' => 'Africa/Dar_es_Salaam',
        '16' => 'Africa/Dar_es_Salaam',
        '17' => 'Africa/Dar_es_Salaam',
        '18' => 'Africa/Dar_es_Salaam',
        '19' => 'Africa/Dar_es_Salaam',
        '20' => 'Africa/Dar_es_Salaam',
        '21' => 'Africa/Dar_es_Salaam',
        '22' => 'Africa/Dar_es_Salaam',
        '23' => 'Africa/Dar_es_Salaam',
        '24' => 'Africa/Dar_es_Salaam',
        '25' => 'Africa/Dar_es_Salaam',
        '26' => 'Africa/Dar_es_Salaam',
        '27' => 'Africa/Dar_es_Salaam',
      ],
      'UA' => [
        '01' => 'Europe/Kiev',
        '02' => 'Europe/Kiev',
        '03' => 'Europe/Uzhgorod',
        '04' => 'Europe/Zaporozhye',
        '05' => 'Europe/Zaporozhye',
        '06' => 'Europe/Uzhgorod',
        '07' => 'Europe/Zaporozhye',
        '08' => 'Europe/Simferopol',
        '09' => 'Europe/Kiev',
        '10' => 'Europe/Zaporozhye',
        '11' => 'Europe/Simferopol',
        '12' => 'Europe/Kiev',
        '13' => 'Europe/Kiev',
        '14' => 'Europe/Zaporozhye',
        '15' => 'Europe/Uzhgorod',
        '16' => 'Europe/Zaporozhye',
        '17' => 'Europe/Simferopol',
        '18' => 'Europe/Zaporozhye',
        '19' => 'Europe/Kiev',
        '20' => 'Europe/Simferopol',
        '21' => 'Europe/Kiev',
        '22' => 'Europe/Uzhgorod',
        '23' => 'Europe/Kiev',
        '24' => 'Europe/Uzhgorod',
        '25' => 'Europe/Uzhgorod',
        '26' => 'Europe/Zaporozhye',
        '27' => 'Europe/Kiev',
      ],
      'UG' => [
        '26' => 'Africa/Kampala',
        '28' => 'Africa/Kampala',
        '29' => 'Africa/Kampala',
        '30' => 'Africa/Kampala',
        '31' => 'Africa/Kampala',
        '33' => 'Africa/Kampala',
        '36' => 'Africa/Kampala',
        '37' => 'Africa/Kampala',
        '38' => 'Africa/Kampala',
        '39' => 'Africa/Kampala',
        '40' => 'Africa/Kampala',
        '41' => 'Africa/Kampala',
        '42' => 'Africa/Kampala',
        '43' => 'Africa/Kampala',
        '45' => 'Africa/Kampala',
        '46' => 'Africa/Kampala',
        '47' => 'Africa/Kampala',
        '50' => 'Africa/Kampala',
        '52' => 'Africa/Kampala',
        '56' => 'Africa/Kampala',
        '58' => 'Africa/Kampala',
        '59' => 'Africa/Kampala',
        '60' => 'Africa/Kampala',
        '61' => 'Africa/Kampala',
        '65' => 'Africa/Kampala',
        '66' => 'Africa/Kampala',
        '67' => 'Africa/Kampala',
        '69' => 'Africa/Kampala',
        '70' => 'Africa/Kampala',
        '71' => 'Africa/Kampala',
        '72' => 'Africa/Kampala',
        '73' => 'Africa/Kampala',
        '74' => 'Africa/Kampala',
        '76' => 'Africa/Kampala',
        '77' => 'Africa/Kampala',
        '78' => 'Africa/Kampala',
        '79' => 'Africa/Kampala',
        '80' => 'Africa/Kampala',
        '81' => 'Africa/Kampala',
        '82' => 'Africa/Kampala',
        '83' => 'Africa/Kampala',
        '84' => 'Africa/Kampala',
        '85' => 'Africa/Kampala',
        '86' => 'Africa/Kampala',
        '87' => 'Africa/Kampala',
        '88' => 'Africa/Kampala',
        '89' => 'Africa/Kampala',
        '90' => 'Africa/Kampala',
        '91' => 'Africa/Kampala',
        '92' => 'Africa/Kampala',
        '93' => 'Africa/Kampala',
        '94' => 'Africa/Kampala',
        '95' => 'Africa/Kampala',
        '96' => 'Africa/Kampala',
        '97' => 'Africa/Kampala',
      ],
      'US' => [
        'AA' => '',
        'AE' => '',
        'AK' => 'America/Anchorage',
        'AL' => 'America/Chicago',
        'AP' => '',
        'AR' => 'America/Chicago',
        'AS' => 'Pacific/Pago_Pago',
        'AZ' => 'America/Phoenix',
        'CA' => 'America/Los_Angeles',
        'CO' => 'America/Denver',
        'CT' => 'America/New_York',
        'DC' => 'America/New_York',
        'DE' => 'America/New_York',
        'FL' => 'America/New_York',
        'FM' => 'Pacific/Pohnpei',
        'GA' => 'America/New_York',
        'GU' => 'Pacific/Guam',
        'HI' => 'Pacific/Honolulu',
        'IA' => 'America/Chicago',
        'ID' => 'America/Denver',
        'IL' => 'America/Chicago',
        'IN' => 'America/Indiana/Indianapolis',
        'KS' => 'America/Chicago',
        'KY' => 'America/New_York',
        'LA' => 'America/Chicago',
        'MA' => 'America/New_York',
        'MD' => 'America/New_York',
        'ME' => 'America/New_York',
        'MH' => 'Pacific/Kwajalei',
        'MI' => 'America/New_York',
        'MN' => 'America/Chicago',
        'MO' => 'America/Chicago',
        'MP' => 'Pacific/Saipan',
        'MS' => 'America/Chicago',
        'MT' => 'America/Denver',
        'NC' => 'America/New_York',
        'ND' => 'America/Chicago',
        'NE' => 'America/Chicago',
        'NH' => 'America/New_York',
        'NJ' => 'America/New_York',
        'NM' => 'America/Denver',
        'NV' => 'America/Los_Angeles',
        'NY' => 'America/New_York',
        'OH' => 'America/New_York',
        'OK' => 'America/Chicago',
        'OR' => 'America/Los_Angeles',
        'PA' => 'America/New_York',
        'PW' => 'Pacific/Palau',
        'RI' => 'America/New_York',
        'SC' => 'America/New_York',
        'SD' => 'America/Chicago',
        'TN' => 'America/Chicago',
        'TX' => 'America/Chicago',
        'UT' => 'America/Denver',
        'VA' => 'America/New_York',
        'VI' => 'America/St_Thomas',
        'VT' => 'America/New_York',
        'WA' => 'America/Los_Angeles',
        'WI' => 'America/Chicago',
        'WV' => 'America/New_York',
        'WY' => 'America/Denver',
      ],
      'UY' => [
        '01' => 'America/Montevideo',
        '02' => 'America/Montevideo',
        '03' => 'America/Montevideo',
        '04' => 'America/Montevideo',
        '05' => 'America/Montevideo',
        '06' => 'America/Montevideo',
        '07' => 'America/Montevideo',
        '08' => 'America/Montevideo',
        '09' => 'America/Montevideo',
        '10' => 'America/Montevideo',
        '11' => 'America/Montevideo',
        '12' => 'America/Montevideo',
        '13' => 'America/Montevideo',
        '14' => 'America/Montevideo',
        '15' => 'America/Montevideo',
        '16' => 'America/Montevideo',
        '17' => 'America/Montevideo',
        '18' => 'America/Montevideo',
        '19' => 'America/Montevideo',
      ],
      'UZ' => [
        '01' => 'Asia/Tashkent',
        '02' => 'Asia/Samarkand',
        '03' => 'Asia/Tashkent',
        '04' => 'Asia/Samarkand',
        '05' => 'Asia/Samarkand',
        '06' => 'Asia/Tashkent',
        '07' => 'Asia/Samarkand',
        '08' => 'Asia/Samarkand',
        '09' => 'Asia/Samarkand',
        '10' => 'Asia/Samarkand',
        '11' => 'Asia/Tashkent',
        '12' => 'Asia/Samarkand',
        '13' => 'Asia/Tashkent',
        '14' => 'Asia/Tashkent',
        '15' => 'Asia/Samarkand',
      ],
      'VC' => [
        '01' => 'America/St_Vincent',
        '02' => 'America/St_Vincent',
        '03' => 'America/St_Vincent',
        '04' => 'America/St_Vincent',
        '05' => 'America/St_Vincent',
        '06' => 'America/St_Vincent',
      ],
      'VE' => [
        '01' => 'America/Caracas',
        '02' => 'America/Caracas',
        '03' => 'America/Caracas',
        '04' => 'America/Caracas',
        '05' => 'America/Caracas',
        '06' => 'America/Caracas',
        '07' => 'America/Caracas',
        '08' => 'America/Caracas',
        '09' => 'America/Caracas',
        '11' => 'America/Caracas',
        '12' => 'America/Caracas',
        '13' => 'America/Caracas',
        '14' => 'America/Caracas',
        '15' => 'America/Caracas',
        '16' => 'America/Caracas',
        '17' => 'America/Caracas',
        '18' => 'America/Caracas',
        '19' => 'America/Caracas',
        '20' => 'America/Caracas',
        '21' => 'America/Caracas',
        '22' => 'America/Caracas',
        '23' => 'America/Caracas',
        '24' => 'America/Caracas',
        '25' => 'America/Caracas',
        '26' => 'America/Caracas',
      ],
      'VN' => [
        '01' => 'Asia/Phnom_Penh',
        '03' => 'Asia/Phnom_Penh',
        '05' => 'Asia/Phnom_Penh',
        '09' => 'Asia/Phnom_Penh',
        '13' => 'Asia/Phnom_Penh',
        '20' => 'Asia/Phnom_Penh',
        '21' => 'Asia/Phnom_Penh',
        '23' => 'Asia/Phnom_Penh',
        '24' => 'Asia/Phnom_Penh',
        '30' => 'Asia/Phnom_Penh',
        '32' => 'Asia/Phnom_Penh',
        '33' => 'Asia/Phnom_Penh',
        '34' => 'Asia/Phnom_Penh',
        '35' => 'Asia/Phnom_Penh',
        '37' => 'Asia/Phnom_Penh',
        '39' => 'Asia/Phnom_Penh',
        '43' => 'Asia/Phnom_Penh',
        '44' => 'Asia/Phnom_Penh',
        '45' => 'Asia/Phnom_Penh',
        '46' => 'Asia/Phnom_Penh',
        '47' => 'Asia/Phnom_Penh',
        '49' => 'Asia/Phnom_Penh',
        '50' => 'Asia/Phnom_Penh',
        '52' => 'Asia/Phnom_Penh',
        '53' => 'Asia/Phnom_Penh',
        '54' => 'Asia/Phnom_Penh',
        '55' => 'Asia/Phnom_Penh',
        '58' => 'Asia/Phnom_Penh',
        '59' => 'Asia/Phnom_Penh',
        '60' => 'Asia/Phnom_Penh',
        '61' => 'Asia/Phnom_Penh',
        '62' => 'Asia/Phnom_Penh',
        '63' => 'Asia/Phnom_Penh',
        '64' => 'Asia/Phnom_Penh',
        '65' => 'Asia/Phnom_Penh',
        '66' => 'Asia/Phnom_Penh',
        '67' => 'Asia/Phnom_Penh',
        '68' => 'Asia/Phnom_Penh',
        '69' => 'Asia/Phnom_Penh',
        '70' => 'Asia/Phnom_Penh',
        '71' => 'Asia/Phnom_Penh',
        '72' => 'Asia/Phnom_Penh',
        '73' => 'Asia/Phnom_Penh',
        '74' => 'Asia/Phnom_Penh',
        '75' => 'Asia/Phnom_Penh',
        '76' => 'Asia/Phnom_Penh',
        '77' => 'Asia/Phnom_Penh',
        '78' => 'Asia/Phnom_Penh',
        '79' => 'Asia/Phnom_Penh',
        '80' => 'Asia/Phnom_Penh',
        '81' => 'Asia/Phnom_Penh',
        '82' => 'Asia/Phnom_Penh',
        '83' => 'Asia/Phnom_Penh',
        '84' => 'Asia/Phnom_Penh',
        '85' => 'Asia/Phnom_Penh',
        '86' => 'Asia/Phnom_Penh',
        '87' => 'Asia/Phnom_Penh',
        '88' => 'Asia/Phnom_Penh',
        '89' => 'Asia/Phnom_Penh',
        '90' => 'Asia/Phnom_Penh',
        '91' => 'Asia/Phnom_Penh',
        '92' => 'Asia/Phnom_Penh',
        '93' => 'Asia/Phnom_Penh',
      ],
      'VU' => [
        '05' => 'Pacific/Efate',
        '06' => 'Pacific/Efate',
        '07' => 'Pacific/Efate',
        '08' => 'Pacific/Efate',
        '09' => 'Pacific/Efate',
        '10' => 'Pacific/Efate',
        '11' => 'Pacific/Efate',
        '12' => 'Pacific/Efate',
        '13' => 'Pacific/Efate',
        '14' => 'Pacific/Efate',
        '15' => 'Pacific/Efate',
        '16' => 'Pacific/Efate',
        '17' => 'Pacific/Efate',
        '18' => 'Pacific/Efate',
      ],
      'WS' => [
        '02' => 'Pacific/Pago_Pago',
        '03' => 'Pacific/Pago_Pago',
        '04' => 'Pacific/Pago_Pago',
        '05' => 'Pacific/Pago_Pago',
        '06' => 'Pacific/Pago_Pago',
        '07' => 'Pacific/Pago_Pago',
        '08' => 'Pacific/Pago_Pago',
        '09' => 'Pacific/Pago_Pago',
        '10' => 'Pacific/Pago_Pago',
        '11' => 'Pacific/Pago_Pago',
      ],
      'YE' => [
        '01' => 'Asia/Aden',
        '02' => 'Asia/Aden',
        '03' => 'Asia/Aden',
        '04' => 'Asia/Aden',
        '05' => 'Asia/Aden',
        '06' => 'Asia/Aden',
        '07' => 'Asia/Aden',
        '08' => 'Asia/Aden',
        '09' => 'Asia/Aden',
        '10' => 'Asia/Aden',
        '11' => 'Asia/Aden',
        '12' => 'Asia/Aden',
        '13' => 'Asia/Aden',
        '14' => 'Asia/Aden',
        '15' => 'Asia/Aden',
        '16' => 'Asia/Aden',
        '17' => 'Asia/Aden',
        '18' => 'Asia/Aden',
        '19' => 'Asia/Aden',
        '20' => 'Asia/Aden',
        '21' => 'Asia/Aden',
        '22' => 'Asia/Aden',
        '23' => 'Asia/Aden',
        '24' => 'Asia/Aden',
        '25' => 'Asia/Aden',
      ],
      'ZA' => [
        '01' => 'Africa/Johannesburg',
        '02' => 'Africa/Johannesburg',
        '03' => 'Africa/Johannesburg',
        '05' => 'Africa/Johannesburg',
        '06' => 'Africa/Johannesburg',
        '07' => 'Africa/Johannesburg',
        '08' => 'Africa/Johannesburg',
        '09' => 'Africa/Johannesburg',
        '10' => 'Africa/Johannesburg',
        '11' => 'Africa/Johannesburg',
      ],
      'ZM' => [
        '01' => 'Africa/Lusaka',
        '02' => 'Africa/Lusaka',
        '03' => 'Africa/Lusaka',
        '04' => 'Africa/Lusaka',
        '05' => 'Africa/Lusaka',
        '06' => 'Africa/Lusaka',
        '07' => 'Africa/Lusaka',
        '08' => 'Africa/Lusaka',
        '09' => 'Africa/Lusaka',
      ],
      'ZW' => [
        '01' => 'Africa/Harare',
        '02' => 'Africa/Harare',
        '03' => 'Africa/Harare',
        '04' => 'Africa/Harare',
        '05' => 'Africa/Harare',
        '06' => 'Africa/Harare',
        '07' => 'Africa/Harare',
        '08' => 'Africa/Harare',
        '09' => 'Africa/Harare',
        '10' => 'Africa/Harare',
      ],
    ];
  }
}
